@@ -1,12 +1,12 @@
 from ..util import verify_dynamic_loading_support
 from .actions import (
-    CloudNotificationAction,
     EmailAction,
     MicrosoftTeamsNotificationAction,
     NoOpAction,
     OpsgenieAlertAction,
     PagerdutyAlertAction,
     SlackNotificationAction,
+    SNSNotificationAction,
     StoreEvaluationParametersAction,
     StoreMetricsAction,
     StoreValidationResultAction,
