@@ -1,8 +1,9 @@
-from typing import List, Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, List, Optional
 
 import click
 
-from great_expectations import DataContext
 from great_expectations.cli import toolkit
 from great_expectations.cli.build_docs import build_docs
 from great_expectations.cli.pretty_printing import cli_message, cli_message_list
@@ -10,6 +11,11 @@ from great_expectations.core.usage_statistics.events import UsageStatsEvents
 from great_expectations.core.usage_statistics.util import send_usage_message
 from great_expectations.exceptions import DataContextError
 
+if TYPE_CHECKING:
+    from great_expectations.data_context.data_context.file_data_context import (
+        FileDataContext,
+    )
+
 
 @click.group()
 @click.pass_context
@@ -17,13 +23,18 @@ def docs(ctx: click.Context) -> None:
     """Data Docs operations"""
     ctx.obj.data_context = ctx.obj.get_data_context_from_config_file()
 
+    invoked_subcommand = ctx.invoked_subcommand
+    assert (
+        invoked_subcommand
+    ), "Proper registration of subcommand has not occurred; please review parent Click context"
+
     cli_event_noun: str = "docs"
     (
         begin_event_name,
         end_event_name,
     ) = UsageStatsEvents.get_cli_begin_and_end_event_names(
         noun=cli_event_noun,
-        verb=ctx.invoked_subcommand,
+        verb=invoked_subcommand,
     )
     send_usage_message(
         data_context=ctx.obj.data_context,
@@ -52,7 +63,7 @@ def docs_build(
     ctx: click.Context, site_name: Optional[str] = None, no_view: bool = False
 ) -> None:
     """Build Data Docs for a project."""
-    context: DataContext = ctx.obj.data_context
+    context: FileDataContext = ctx.obj.data_context
     usage_event_end: str = ctx.obj.usage_event_end
 
     if site_name is not None and site_name not in context.get_site_names():
