@@ -4,8 +4,7 @@ import warnings
 
 import click
 
-from great_expectations import DataContext
-from great_expectations import exceptions as ge_exceptions
+from great_expectations import exceptions as gx_exceptions
 from great_expectations.cli import toolkit
 from great_expectations.cli.cli_messages import (
     COMPLETE_ONBOARDING_PROMPT,
@@ -21,6 +20,9 @@ from great_expectations.cli.cli_messages import (
 from great_expectations.cli.pretty_printing import cli_message
 from great_expectations.core.usage_statistics.events import UsageStatsEvents
 from great_expectations.core.usage_statistics.util import send_usage_message
+from great_expectations.data_context.data_context.file_data_context import (
+    FileDataContext,
+)
 from great_expectations.exceptions import (
     DataContextError,
     DatasourceInitializationError,
@@ -31,7 +33,7 @@ try:
 except ImportError:
     # We'll redefine this error in code below to catch ProfilerError, which is caught above, so SA errors will
     # just fall through
-    SQLAlchemyError = ge_exceptions.ProfilerError
+    SQLAlchemyError = gx_exceptions.ProfilerError
 
 
 @click.command()
@@ -60,16 +62,14 @@ def init(ctx: click.Context, usage_stats: bool) -> None:
     ge_dir = _get_full_path_to_ge_dir(target_directory)
     cli_message(GREETING)
 
-    if DataContext.does_config_exist_on_disk(ge_dir):
-        message = (
-            f"""Warning. An existing `{DataContext.GE_YML}` was found here: {ge_dir}."""
-        )
+    if FileDataContext.does_config_exist_on_disk(ge_dir):
+        message = f"""Warning. An existing `{FileDataContext.GX_YML}` was found here: {ge_dir}."""
         warnings.warn(message)
         try:
             project_file_structure_exists = (
-                DataContext.does_config_exist_on_disk(ge_dir)
-                and DataContext.all_uncommitted_directories_exist(ge_dir)
-                and DataContext.config_variables_yml_exist(ge_dir)
+                FileDataContext.does_config_exist_on_disk(ge_dir)
+                and FileDataContext.all_uncommitted_directories_exist(ge_dir)
+                and FileDataContext.config_variables_yml_exist(ge_dir)
             )
             if project_file_structure_exists:
                 cli_message(PROJECT_IS_COMPLETE)
@@ -86,7 +86,9 @@ def init(ctx: click.Context, usage_stats: bool) -> None:
             sys.exit(1)
 
         try:
-            DataContext.create(target_directory, usage_statistics_enabled=usage_stats)
+            FileDataContext.create(
+                target_directory, usage_statistics_enabled=usage_stats
+            )
             cli_message(ONBOARDING_COMPLETE)
 
         except DataContextError as e:
@@ -100,12 +102,12 @@ def init(ctx: click.Context, usage_stats: bool) -> None:
                 exit(0)
 
         try:
-            context = DataContext.create(
+            context = FileDataContext.create(
                 target_directory, usage_statistics_enabled=usage_stats
             )
             send_usage_message(
                 data_context=context,
-                event=UsageStatsEvents.CLI_INIT_CREATE.value,
+                event=UsageStatsEvents.CLI_INIT_CREATE,
                 success=True,
             )
         except DataContextError as e:
@@ -119,4 +121,4 @@ def init(ctx: click.Context, usage_stats: bool) -> None:
 
 
 def _get_full_path_to_ge_dir(target_directory: str) -> str:
-    return os.path.abspath(os.path.join(target_directory, DataContext.GE_DIR))
+    return os.path.abspath(os.path.join(target_directory, FileDataContext.GX_DIR))
