@@ -226,7 +226,7 @@ def load_expectation_suite(  # type: ignore[return] # sys.exit if no suite
         )
     except gx_exceptions.DataContextError:
         if create_if_not_exist:
-            suite = data_context.create_expectation_suite(
+            suite = data_context.add_expectation_suite(
                 expectation_suite_name=expectation_suite_name
             )
 
@@ -1041,7 +1041,7 @@ def add_citation_with_batch_request(
             comment="Created suite added via CLI",
             batch_request=batch_request,  # type: ignore[arg-type] # values union
         )
-        data_context.save_expectation_suite(expectation_suite=expectation_suite)
+        data_context.update_expectation_suite(expectation_suite=expectation_suite)
 
 
 def get_batch_request_from_json_file(
@@ -1113,5 +1113,8 @@ def get_batch_request_using_datasource_name(
         datasource=datasource,  # type: ignore[arg-type] # could be LegacyDatasource
         additional_batch_request_args=additional_batch_request_args,
     )
+    if "data_asset_name" not in batch_request:
+        # Some datasources don't always provide this (`RuntimeDataConnector`)
+        batch_request["data_asset_name"] = "default_data_asset_name"
 
     return batch_request
