@@ -8,13 +8,17 @@ import textwrap
 
 import click
 
+from great_expectations.data_context.data_context.file_data_context import (
+    FileDataContext,
+)
+
 try:
-    from pybigquery.parse_url import parse_url as parse_bigquery_url
+    from sqlalchemy_bigquery.parse_url import parse_url as parse_bigquery_url
 except (ImportError, ModuleNotFoundError):
     parse_bigquery_url = None
 
-import great_expectations.exceptions as ge_exceptions
-from great_expectations import DataContext, rtd_url_ge_version
+import great_expectations.exceptions as gx_exceptions
+from great_expectations import rtd_url_ge_version
 from great_expectations.cli.v012 import toolkit
 from great_expectations.cli.v012.cli_messages import NO_DATASOURCES_FOUND
 from great_expectations.cli.v012.docs import build_docs
@@ -43,7 +47,7 @@ from great_expectations.exceptions import (
     BatchKwargsError,
     DatasourceInitializationError,
 )
-from great_expectations.execution_engine.sqlalchemy_dialect import GESqlDialect
+from great_expectations.execution_engine.sqlalchemy_dialect import GXSqlDialect
 from great_expectations.validator.validator import BridgeValidator
 
 logger = logging.getLogger(__name__)
@@ -428,7 +432,7 @@ def _add_pandas_datasource(
         configuration["module_name"] = "great_expectations.datasource"
         errors = DatasourceConfigSchema().validate(configuration)
         if len(errors) != 0:
-            raise ge_exceptions.GreatExpectationsError(
+            raise gx_exceptions.GreatExpectationsError(
                 f"Invalid Datasource configuration: {errors:s}"
             )
 
@@ -452,7 +456,10 @@ Great Expectations will now add a new Datasource '{:s}' to your deployment, by a
     return datasource_name
 
 
-def _add_sqlalchemy_datasource(context, prompt_for_datasource_name=True):
+def _add_sqlalchemy_datasource(  # noqa: C901 - 21
+    context,
+    prompt_for_datasource_name=True,
+):
 
     msg_success_database = (
         "\n<green>Great Expectations connected to your database!</green>"
@@ -498,7 +505,7 @@ def _add_sqlalchemy_datasource(context, prompt_for_datasource_name=True):
     # with the datasource's name as the variable name.
     # The value of the datasource's "credentials" key in the config file (great_expectations.yml) will
     # be ${datasource name}.
-    # GE will replace the ${datasource name} with the value from the credentials file in runtime.
+    # GX will replace the ${datasource name} with the value from the credentials file in runtime.
 
     while True:
         cli_message(msg_db_config.format(datasource_name))
@@ -558,7 +565,7 @@ def _add_sqlalchemy_datasource(context, prompt_for_datasource_name=True):
             configuration["module_name"] = "great_expectations.datasource"
             errors = DatasourceConfigSchema().validate(configuration)
             if len(errors) != 0:
-                raise ge_exceptions.GreatExpectationsError(
+                raise gx_exceptions.GreatExpectationsError(
                     f"Invalid Datasource configuration: {errors:s}"
                 )
 
@@ -606,7 +613,7 @@ After you connect to the datasource, run great_expectations init to continue.
 
 """.format(
                         datasource_name,
-                        DataContext.GE_YML,
+                        FileDataContext.GX_YML,
                         context.get_config()["config_variables_file_path"],
                         rtd_url_ge_version,
                         selected_database.value.lower(),
@@ -922,7 +929,7 @@ def _add_spark_datasource(
         configuration["module_name"] = "great_expectations.datasource"
         errors = DatasourceConfigSchema().validate(configuration)
         if len(errors) != 0:
-            raise ge_exceptions.GreatExpectationsError(
+            raise gx_exceptions.GreatExpectationsError(
                 f"Invalid Datasource configuration: {errors:s}"
             )
 
@@ -1066,7 +1073,7 @@ def get_batch_kwargs(
         )
 
     else:
-        raise ge_exceptions.DataContextError(
+        raise gx_exceptions.DataContextError(
             "Datasource {:s} is expected to be a PandasDatasource or SparkDFDatasource, but is {:s}".format(
                 datasource_name, str(type(context.get_datasource(datasource_name)))
             )
@@ -1075,7 +1082,7 @@ def get_batch_kwargs(
     return (datasource_name, batch_kwargs_generator_name, data_asset_name, batch_kwargs)
 
 
-def _get_batch_kwargs_from_generator_or_from_file_path(
+def _get_batch_kwargs_from_generator_or_from_file_path(  # noqa: C901 - 26
     context,
     datasource_name,
     batch_kwargs_generator_name=None,
@@ -1227,7 +1234,7 @@ We could not determine the format of the file. What is it?
                             "\nDoes this file contain a header row?", default=True
                         )
                         batch_kwargs["reader_options"] = {"header": header_row}
-                    batch = datasource.get_batch(batch_kwargs=batch_kwargs)
+                    _ = datasource.get_batch(batch_kwargs=batch_kwargs)
                     break
         else:
             try:
@@ -1243,7 +1250,7 @@ We could not determine the format of the file. What is it?
                         "\nDoes this file contain a header row?", default=True
                     )
                     batch_kwargs["reader_options"] = {"header": header_row}
-                batch = datasource.get_batch(batch_kwargs=batch_kwargs)
+                _ = datasource.get_batch(batch_kwargs=batch_kwargs)
                 break
             except Exception as e:
                 file_load_error_message = """
@@ -1368,7 +1375,7 @@ Would you like to continue?"""
     temp_table_kwargs = {}
     datasource = context.get_datasource(datasource_name)
 
-    if datasource.engine.dialect.name.lower() == GESqlDialect.BIGQUERY:
+    if datasource.engine.dialect.name.lower() == GXSqlDialect.BIGQUERY:
         # bigquery table needs to contain the project id if it differs from the credentials project
         if len(data_asset_name.split(".")) < 3:
             project_id, _, _, _, _, _ = parse_bigquery_url(datasource.engine.url)
@@ -1441,17 +1448,12 @@ def _verify_snowflake_dependent_modules() -> bool:
 
 
 def _verify_bigquery_dependent_modules() -> bool:
-    pybigquery_ok = verify_library_dependent_modules(
-        python_import_name="pybigquery.sqlalchemy_bigquery",
-        pip_library_name="pybigquery",
-        module_names_to_reload=CLI_ONLY_SQLALCHEMY_ORDERED_DEPENDENCY_MODULE_NAMES,
-    )
     sqlalchemy_bigquery_ok = verify_library_dependent_modules(
         python_import_name="sqlalchemy_bigquery",
         pip_library_name="sqlalchemy_bigquery",
         module_names_to_reload=CLI_ONLY_SQLALCHEMY_ORDERED_DEPENDENCY_MODULE_NAMES,
     )
-    return pybigquery_ok or sqlalchemy_bigquery_ok
+    return sqlalchemy_bigquery_ok
 
 
 def _verify_pyspark_dependent_modules() -> bool:
@@ -1565,7 +1567,7 @@ Great Expectations is building Data Docs from the data you just profiled!"""
         while not do_exit:
             if (
                 profiling_results["error"]["code"]
-                == DataContext.PROFILING_ERROR_CODE_SPECIFIED_DATA_ASSETS_NOT_FOUND
+                == FileDataContext.PROFILING_ERROR_CODE_SPECIFIED_DATA_ASSETS_NOT_FOUND
             ):
                 cli_message(
                     msg_some_data_assets_not_found.format(
@@ -1574,7 +1576,7 @@ Great Expectations is building Data Docs from the data you just profiled!"""
                 )
             elif (
                 profiling_results["error"]["code"]
-                == DataContext.PROFILING_ERROR_CODE_TOO_MANY_DATA_ASSETS
+                == FileDataContext.PROFILING_ERROR_CODE_TOO_MANY_DATA_ASSETS
             ):
                 cli_message(
                     msg_too_many_data_assets.format(
@@ -1583,13 +1585,13 @@ Great Expectations is building Data Docs from the data you just profiled!"""
                 )
             elif (
                 profiling_results["error"]["code"]
-                == DataContext.PROFILING_ERROR_CODE_MULTIPLE_BATCH_KWARGS_GENERATORS_FOUND
+                == FileDataContext.PROFILING_ERROR_CODE_MULTIPLE_BATCH_KWARGS_GENERATORS_FOUND
             ):
                 cli_message(msg_error_multiple_generators_found.format(datasource_name))
                 sys.exit(1)
             elif (
                 profiling_results["error"]["code"]
-                == DataContext.PROFILING_ERROR_CODE_NO_BATCH_KWARGS_GENERATORS_FOUND
+                == FileDataContext.PROFILING_ERROR_CODE_NO_BATCH_KWARGS_GENERATORS_FOUND
             ):
                 cli_message(msg_error_no_generators_found.format(datasource_name))
                 sys.exit(1)
