@@ -3,13 +3,13 @@ from abc import ABC, abstractmethod
 from enum import Enum
 from typing import Union
 
-from great_expectations.data_context.types.base import BaseYamlConfig
+from great_expectations.data_context.types.base import BaseYamlConfig  # noqa: TCH001
 from great_expectations.util import filter_properties_dict
 
 logger = logging.getLogger(__name__)
 
 
-class ConfigOutputModes(Enum):
+class ConfigOutputModes(str, Enum):
     TYPED = "typed"
     COMMENTED_MAP = "commented_map"
     YAML = "yaml"
@@ -17,9 +17,6 @@ class ConfigOutputModes(Enum):
     JSON_DICT = "json_dict"
 
 
-ConfigOutputModeType = Union[ConfigOutputModes, str]
-
-
 class ConfigPeer(ABC):
     """
     A ConfigPeer is an object, whose subclasses can be instantiated using instantiate_class_from_config() (located in
@@ -44,7 +41,7 @@ class ConfigPeer(ABC):
 
     def get_config(
         self,
-        mode: ConfigOutputModeType = ConfigOutputModes.TYPED,
+        mode: ConfigOutputModes = ConfigOutputModes.TYPED,
         **kwargs,
     ) -> Union[BaseYamlConfig, dict, str]:
         if isinstance(mode, str):
