@@ -2,16 +2,17 @@
 from abc import ABC
 from typing import Optional
 
-from great_expectations.marshmallow__shade.decorators import post_dump
-from great_expectations.marshmallow__shade.schema import Schema
+from marshmallow.decorators import post_dump
+from marshmallow.schema import Schema
+
 from great_expectations.types import SerializableDictDot
 
 
 class AbstractConfig(ABC, SerializableDictDot):
     """Abstract base class for Config objects. Sets the fields that must be included on a Config."""
 
-    def __init__(self, id_: Optional[str] = None, name: Optional[str] = None) -> None:
-        self.id_ = id_
+    def __init__(self, id: Optional[str] = None, name: Optional[str] = None) -> None:
+        self.id = id
         self.name = name
         super().__init__()
 
@@ -20,7 +21,7 @@ class AbstractConfig(ABC, SerializableDictDot):
         """
         Round trip a dictionary with a schema so that validation and serialization logic is applied.
 
-        Example: Loading a config with a `_id` field but serializing it as `id`.
+        Example: Loading a config with a `id_` field but serializing it as `id`.
         """
         _loaded = schema.load(target)
         _config = cls(**_loaded)
