@@ -1,17 +1,30 @@
 import datetime
 import json
 import warnings
+from typing import Dict, Optional, Union
 
 from dateutil.parser import parse
 from marshmallow import Schema, fields, post_load
 
+from great_expectations.alias_types import JSONValues  # noqa: TCH001
+from great_expectations.core._docs_decorators import public_api
 from great_expectations.core.data_context_key import DataContextKey
 
 
+@public_api
 class RunIdentifier(DataContextKey):
-    """A RunIdentifier identifies a run (collection of validations) by run_name and run_time."""
+    """A RunIdentifier identifies a run (collection of validations) by run_name and run_time.
 
-    def __init__(self, run_name=None, run_time=None) -> None:
+    Args:
+        run_name: a string or None.
+        run_time: a Datetime.datetime instance, a string, or None.
+    """
+
+    def __init__(
+        self,
+        run_name: Optional[str] = None,
+        run_time: Optional[Union[datetime.datetime, str]] = None,
+    ) -> None:
         super().__init__()
         assert run_name is None or isinstance(
             run_name, str
@@ -72,7 +85,13 @@ class RunIdentifier(DataContextKey):
     def __str__(self):
         return json.dumps(self.to_json_dict(), indent=2)
 
-    def to_json_dict(self):
+    @public_api
+    def to_json_dict(self) -> Dict[str, JSONValues]:
+        """Returns a JSON-serializable dict representation of this RunIdentifier.
+
+        Returns:
+            A JSON-serializable dict representation of this RunIdentifier.
+        """
         myself = runIdentifierSchema.dump(self)
         return myself
 
