@@ -2,7 +2,7 @@
 # These schemas are used to ensure that we *never* take unexpected usage stats message and provide full transparency
 # about usage statistics. Please reach out to the Great Expectations with any questions!
 ###
-
+from typing import List
 
 from great_expectations.core.usage_statistics.anonymizers.types.base import (
     CLISuiteInteractiveFlagCombinations,
@@ -14,7 +14,8 @@ from great_expectations.core.usage_statistics.execution_environment import (
     InstallEnvironment,
 )
 
-SCHEMA: str = "http://json-schema.org/draft-04/schema#"
+SCHEMA: str = "https://json-schema.org/draft/2020-12/schema"
+ALLOWED_VERSIONS: List[str] = ["1.0.0", "1.0.1"]
 
 anonymized_string_schema = {
     "$schema": SCHEMA,
@@ -297,7 +298,7 @@ anonymized_init_payload_schema = {
     },
     "type": "object",
     "properties": {
-        "version": {"enum": ["1.0.0"]},
+        "version": {"enum": ALLOWED_VERSIONS},
         "platform.system": {"type": "string", "maxLength": 256},
         "platform.release": {"type": "string", "maxLength": 256},
         "version_info": {"type": "string", "maxLength": 256},
@@ -960,7 +961,7 @@ anonymized_usage_statistics_record_schema = {
     },
     "type": "object",
     "properties": {
-        "version": {"enum": ["1.0.0"]},
+        "version": {"enum": ALLOWED_VERSIONS},
         "ge_version": {"type": "string", "maxLength": 32},
         "data_context_id": {"type": "string", "format": "uuid"},
         "data_context_instance_id": {"type": "string", "format": "uuid"},
@@ -1136,7 +1137,7 @@ anonymized_usage_statistics_record_schema = {
         {
             "type": "object",
             "properties": {
-                "event": {"enum": [UsageStatsEvents.CLOUD_MIGRATE.value]},
+                "event": {"enum": [UsageStatsEvents.CLOUD_MIGRATE]},
                 "event_payload": {"$ref": "#/definitions/cloud_migrate"},
             },
         },
