@@ -2,7 +2,18 @@ from __future__ import annotations
 
 import logging
 import os
-from typing import TYPE_CHECKING, Dict, List, Mapping, Optional, Tuple, Union, cast
+import warnings
+from typing import (
+    TYPE_CHECKING,
+    Callable,
+    Dict,
+    List,
+    Mapping,
+    Optional,
+    Tuple,
+    Union,
+    cast,
+)
 
 import requests
 
@@ -466,6 +477,12 @@ class CloudDataContext(SerializableDataContext):
         Returns:
             A new (empty) expectation suite.
         """
+        # deprecated-v0.15.48
+        warnings.warn(
+            "create_expectation_suite is deprecated as of v0.15.49 and will be removed in v0.18. "
+            "Please use add_expectation_suite or add_or_update_expectation_suite instead.",
+            DeprecationWarning,
+        )
         if not isinstance(overwrite_existing, bool):
             raise ValueError("Parameter overwrite_existing must be of type BOOL")
 
@@ -762,3 +779,33 @@ class CloudDataContext(SerializableDataContext):
         assert cloud_config is not None
         config = cls.retrieve_data_context_config_from_cloud(cloud_config=cloud_config)
         return config
+
+    def _persist_suite_with_store(
+        self,
+        expectation_suite: ExpectationSuite,
+        overwrite_existing: bool,
+        **kwargs,
+    ) -> ExpectationSuite:
+        cloud_id: str | None
+        if expectation_suite.ge_cloud_id:
+            cloud_id = str(expectation_suite.ge_cloud_id)
+        else:
+            cloud_id = None
+
+        key = GXCloudIdentifier(
+            resource_type=GXCloudRESTResource.EXPECTATION_SUITE,
+            resource_name=expectation_suite.expectation_suite_name,
+            cloud_id=cloud_id,
+        )
+
+        persistence_fn: Callable
+        if overwrite_existing:
+            persistence_fn = self.expectations_store.add_or_update
+        else:
+            persistence_fn = self.expectations_store.add
+
+        response = persistence_fn(key=key, value=expectation_suite, **kwargs)
+        if isinstance(response, GXCloudResourceRef):
+            expectation_suite.ge_cloud_id = response.cloud_id
+
+        return expectation_suite
