@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import logging
 import pathlib
 from typing import TYPE_CHECKING, Any, List, Optional, Tuple
@@ -13,7 +15,10 @@ from great_expectations.exceptions.exceptions import StoreBackendError
 from great_expectations.util import filter_properties_dict
 
 if TYPE_CHECKING:
-    from great_expectations.data_context import DataContext
+    from great_expectations.data_context.data_context.file_data_context import (
+        FileDataContext,
+    )
+
 
 logger = logging.getLogger(__name__)
 
@@ -38,7 +43,7 @@ class InlineStoreBackend(StoreBackend):
 
     def __init__(
         self,
-        data_context: "DataContext",
+        data_context: FileDataContext,
         resource_type: DataContextVariableSchema,
         runtime_environment: Optional[dict] = None,
         fixed_length_key: bool = False,
@@ -188,7 +193,7 @@ class InlineStoreBackend(StoreBackend):
 
     def _save_changes(self) -> None:
         context = self._data_context
-        config_filepath = pathlib.Path(context.root_directory) / context.GE_YML  # type: ignore[arg-type]
+        config_filepath = pathlib.Path(context.root_directory) / context.GX_YML  # type: ignore[arg-type]
 
         try:
             with open(config_filepath, "w") as outfile:
