@@ -596,35 +596,15 @@ class TupleS3StoreBackend(TupleStoreBackend):
 
     def list_keys(self, prefix: Tuple = ()) -> List[Tuple]:
         # Note that the prefix arg is only included to maintain consistency with the parent class signature
-        s3 = self._create_client()
-        paginator = s3.get_paginator("list_objects_v2")
-
-        if self.prefix:
-            page_iterator = paginator.paginate(Bucket=self.bucket, Prefix=self.prefix)
-        else:
-            page_iterator = paginator.paginate(Bucket=self.bucket)
-
-        objects: list = []
-
-        for page in page_iterator:
-            current_page_contents = page.get("Contents")
-            # On first iteration check for "CommonPrefixes"
-            if (
-                current_page_contents is None
-                and objects == []
-                and "CommonPrefixes" in page
-            ):
-                logger.warning(
-                    "TupleS3StoreBackend returned CommonPrefixes, but delimiter should not have been set."
-                )
-                objects = []
-                break
-            if current_page_contents is not None:
-                objects.extend(current_page_contents)
-
+        s3r = self._create_resource()
+        bucket = s3r.Bucket(self.bucket)
         key_list = []
-        for s3_object_info in objects:
-            s3_object_key = s3_object_info["Key"]
+        if self.prefix:
+            objects_list = bucket.objects.filter(Prefix=self.prefix)
+        else:
+            objects_list = bucket.objects.all()
+        for s3_object_info in objects_list:
+            s3_object_key = s3_object_info.key
             if self.platform_specific_separator:
                 s3_object_key = os.path.relpath(s3_object_key, self.prefix)
             else:
@@ -859,7 +839,7 @@ class TupleGCSStoreBackend(TupleStoreBackend):
         return gcs_object_key
 
     def _move(self, source_key, dest_key, **kwargs) -> None:
-        from google.cloud import storage  # type: ignore
+        from google.cloud import storage
 
         gcs = storage.Client(project=self.project)
         bucket = gcs.bucket(self.bucket)
@@ -878,7 +858,7 @@ class TupleGCSStoreBackend(TupleStoreBackend):
         # Note that the prefix arg is only included to maintain consistency with the parent class signature
         key_list = []
 
-        from google.cloud import storage  # type: ignore
+        from google.cloud import storage
 
         gcs = storage.Client(self.project)
 
@@ -1002,7 +982,7 @@ class TupleAzureBlobStoreBackend(TupleStoreBackend):
         self.container = container
         self.account_url = account_url or os.environ.get("AZURE_STORAGE_ACCOUNT_URL")
 
-    @property  # type: ignore[misc] # Decorated property not supported
+    @property
     @functools.lru_cache()
     def _container_client(self) -> Any:
 
