@@ -9,7 +9,7 @@ from great_expectations.datasource.batch_kwargs_generator.batch_kwargs_generator
 )
 from great_expectations.datasource.types import SqlAlchemyDatasourceTableBatchKwargs
 from great_expectations.exceptions import BatchKwargsError, GreatExpectationsError
-from great_expectations.execution_engine.sqlalchemy_dialect import GESqlDialect
+from great_expectations.execution_engine.sqlalchemy_dialect import GXSqlDialect
 
 logger = logging.getLogger(__name__)
 
@@ -150,7 +150,7 @@ class TableBatchKwargsGenerator(BatchKwargsGenerator):
             split_data_asset_name = data_asset_name.split(".")
             if len(split_data_asset_name) == 2:
                 schema_name = split_data_asset_name[0]
-                if self.engine.dialect.name.lower() == GESqlDialect.BIGQUERY:
+                if self.engine.dialect.name.lower() == GXSqlDialect.BIGQUERY:
                     table_name = data_asset_name
                 else:
                     table_name = split_data_asset_name[1]
@@ -160,14 +160,14 @@ class TableBatchKwargsGenerator(BatchKwargsGenerator):
 
             elif (
                 len(split_data_asset_name) == 3
-                and self.engine.dialect.name.lower() == GESqlDialect.BIGQUERY
+                and self.engine.dialect.name.lower() == GXSqlDialect.BIGQUERY
             ):
                 project_id = split_data_asset_name[0]  # noqa: F841
                 schema_name = split_data_asset_name[1]
                 table_name = data_asset_name
             else:
                 shape = "[SCHEMA.]TABLE"
-                if self.engine.dialect.name.lower() == GESqlDialect.BIGQUERY:
+                if self.engine.dialect.name.lower() == GXSqlDialect.BIGQUERY:
                     shape = f"[PROJECT_ID.]{shape}"
 
                 raise ValueError(
@@ -226,7 +226,7 @@ class TableBatchKwargsGenerator(BatchKwargsGenerator):
                 if schema_name in known_information_schemas:
                     continue
 
-                if self.engine.dialect.name.lower() == GESqlDialect.BIGQUERY:
+                if self.engine.dialect.name.lower() == GXSqlDialect.BIGQUERY:
                     tables.extend(
                         [
                             (table_name, "table")
@@ -238,7 +238,7 @@ class TableBatchKwargsGenerator(BatchKwargsGenerator):
                     )
                 else:
                     # set default_schema_name
-                    if self.engine.dialect.name.lower() == GESqlDialect.SQLITE:
+                    if self.engine.dialect.name.lower() == GXSqlDialect.SQLITE:
                         # Workaround for compatibility with sqlalchemy < 1.4.0 and is described in issue #2641
                         default_schema_name = None
                     else:
