@@ -2,31 +2,40 @@ import logging
 from copy import deepcopy
 from typing import Dict, List, Optional, Union
 
-from great_expectations.core.batch import BatchDefinition
-from great_expectations.core.batch_spec import PathBatchSpec
-from great_expectations.datasource.data_connector.asset.asset import Asset
+from great_expectations.core._docs_decorators import public_api
+from great_expectations.core.batch import BatchDefinition  # noqa: TCH001
+from great_expectations.core.batch_spec import PathBatchSpec  # noqa: TCH001
+from great_expectations.datasource.data_connector.asset.asset import (
+    Asset,  # noqa: TCH001
+)
 from great_expectations.datasource.data_connector.file_path_data_connector import (
     FilePathDataConnector,
 )
 from great_expectations.datasource.data_connector.util import _build_asset_from_config
-from great_expectations.execution_engine import ExecutionEngine
+from great_expectations.execution_engine import ExecutionEngine  # noqa: TCH001
 
 logger = logging.getLogger(__name__)
 
 
+@public_api
 class ConfiguredAssetFilePathDataConnector(FilePathDataConnector):
     """
     The ConfiguredAssetFilePathDataConnector is one of two classes (InferredAssetFilePathDataConnector being the
     other) designed for connecting to filesystem-like data. This includes files on disk, but also things
     like S3 object stores, etc:
 
-    A ConfiguredAssetFilePathDataConnector requires an explicit listing of each DataAsset you want to connect to.
-    This allows more fine-tuning, but also requires more setup.
-
-    *Note*: ConfiguredAssetFilePathDataConnector is not meant to be used on its own, but extended. Currently
-    ConfiguredAssetFilesystemDataConnector, ConfiguredAssetS3DataConnector, ConfiguredAssetAzureDataConnector, and
-    ConfiguredAssetGCSDataConnector are subclasses of ConfiguredAssetFilePathDataConnector.
+    Being a Configured Asset Data Connector, it requires an explicit list of each Data Asset it can
+    connect to. While this allows for fine-grained control over which Data Assets may be accessed,
+    it requires more setup.
 
+    Args:
+        name (str): name of ConfiguredAssetFilePathDataConnector
+        datasource_name (str): Name of datasource that this DataConnector is connected to
+        assets (dict): configured assets as a dictionary. These can each have their own regex and sorters
+        execution_engine (ExecutionEngine): Execution Engine object to actually read the data
+        default_regex (dict): Optional dict the filter and organize the data_references.
+        sorters (list): Optional list if you want to sort the data_references
+        batch_spec_passthrough (dict): dictionary with keys that will be added directly to batch_spec
     """
 
     def __init__(
@@ -40,20 +49,7 @@ class ConfiguredAssetFilePathDataConnector(FilePathDataConnector):
         batch_spec_passthrough: Optional[dict] = None,
         id: Optional[str] = None,
     ) -> None:
-        """
-        Base class for DataConnectors that connect to filesystem-like data by taking in
-        configured `assets` as a dictionary. This class supports the configuration of default_regex and
-        sorters for filtering and sorting data_references.
 
-        Args:
-            name (str): name of ConfiguredAssetFilePathDataConnector
-            datasource_name (str): Name of datasource that this DataConnector is connected to
-            assets (dict): configured assets as a dictionary. These can each have their own regex and sorters
-            execution_engine (ExecutionEngine): Execution Engine object to actually read the data
-            default_regex (dict): Optional dict the filter and organize the data_references.
-            sorters (list): Optional list if you want to sort the data_references
-            batch_spec_passthrough (dict): dictionary with keys that will be added directly to batch_spec
-        """
         logger.debug(f'Constructing ConfiguredAssetFilePathDataConnector "{name}".')
         super().__init__(
             name=name,
@@ -67,6 +63,7 @@ class ConfiguredAssetFilePathDataConnector(FilePathDataConnector):
 
         if assets is None:
             assets = {}
+
         _assets: Dict[str, Union[dict, Asset]] = assets
         self._assets = _assets
         self._build_assets_from_config(config=assets)
@@ -86,9 +83,9 @@ class ConfiguredAssetFilePathDataConnector(FilePathDataConnector):
             )
             self.assets[name] = new_asset
 
+    @public_api
     def get_available_data_asset_names(self) -> List[str]:
-        """
-        Return the list of asset names known by this DataConnector.
+        """Return the list of asset names known by this DataConnector.
 
         Returns:
             A list of available names
@@ -96,7 +93,6 @@ class ConfiguredAssetFilePathDataConnector(FilePathDataConnector):
         return list(self.assets.keys())
 
     def _refresh_data_references_cache(self) -> None:
-
         # Map data_references to batch_definitions
         self._data_references_cache = {}
 
@@ -127,7 +123,7 @@ class ConfiguredAssetFilePathDataConnector(FilePathDataConnector):
         path_list: List[str] = self._get_data_reference_list_for_asset(asset=asset)
         return path_list
 
-    def get_data_reference_list_count(self) -> int:
+    def get_data_reference_count(self) -> int:
         """
         Returns the list of data_references known by this DataConnector by looping over all data_asset_names in
         _data_references_cache
@@ -176,6 +172,7 @@ class ConfiguredAssetFilePathDataConnector(FilePathDataConnector):
         asset: Optional[Asset] = None
         if data_asset_name:
             asset = self._get_asset(data_asset_name=data_asset_name)
+
         return self._get_full_file_path_for_asset(path=path, asset=asset)
 
     def _get_regex_config(self, data_asset_name: Optional[str] = None) -> dict:
@@ -183,12 +180,14 @@ class ConfiguredAssetFilePathDataConnector(FilePathDataConnector):
         asset: Optional[Asset] = None
         if data_asset_name:
             asset = self._get_asset(data_asset_name=data_asset_name)
+
         if asset is not None:
             # Override the defaults
             if asset.pattern:
                 regex_config["pattern"] = asset.pattern
             if asset.group_names:
                 regex_config["group_names"] = asset.group_names
+
         return regex_config
 
     def _get_asset(self, data_asset_name: Optional[str]) -> Union[Asset, None]:
@@ -199,6 +198,7 @@ class ConfiguredAssetFilePathDataConnector(FilePathDataConnector):
             and data_asset_name in self.assets
         ):
             asset = self.assets[data_asset_name]  # type: ignore[assignment]
+
         return asset
 
     def _get_data_reference_list_for_asset(self, asset: Optional[Asset]) -> List[str]:
