@@ -1,14 +1,15 @@
 import logging
 from typing import List, Optional
 
-from great_expectations.core.batch import BatchDefinition
+from great_expectations.core._docs_decorators import public_api
+from great_expectations.core.batch import BatchDefinition  # noqa: TCH001
 from great_expectations.core.batch_spec import GCSBatchSpec, PathBatchSpec
-from great_expectations.datasource.data_connector.asset import Asset
+from great_expectations.datasource.data_connector.asset import Asset  # noqa: TCH001
 from great_expectations.datasource.data_connector.configured_asset_file_path_data_connector import (
     ConfiguredAssetFilePathDataConnector,
 )
 from great_expectations.datasource.data_connector.util import list_gcs_keys
-from great_expectations.execution_engine import ExecutionEngine
+from great_expectations.execution_engine import ExecutionEngine  # noqa: TCH001
 
 logger = logging.getLogger(__name__)
 
@@ -23,17 +24,9 @@ except ImportError:
     )
 
 
+@public_api
 class ConfiguredAssetGCSDataConnector(ConfiguredAssetFilePathDataConnector):
-    """
-    Extension of ConfiguredAssetFilePathDataConnector used to connect to GCS
-
-    DataConnectors produce identifying information, called "batch_spec" that ExecutionEngines
-    can use to get individual batches of data. They add flexibility in how to obtain data
-    such as with time-based partitioning, splitting and sampling, or other techniques appropriate
-    for obtaining batches of data.
-
-    The ConfiguredAssetGCSDataConnector is one of two classes (InferredAssetGCSDataConnector being the
-    other one) designed for connecting to data on GCS.
+    """Extension of ConfiguredAssetFilePathDataConnector used to connect to GCS.
 
     A ConfiguredAssetGCSDataConnector requires an explicit specification of each DataAsset you want to connect to.
     This allows more fine-tuning, but also requires more setup. Please note that in order to maintain consistency
@@ -45,9 +38,19 @@ class ConfiguredAssetGCSDataConnector(ConfiguredAssetFilePathDataConnector):
         2. Manual creation of credentials from google.oauth2.service_account.Credentials.from_service_account_file
         3. Manual creation of credentials from google.oauth2.service_account.Credentials.from_service_account_info
 
-    As much of the interaction with the SDK is done through a GCS Storage Client, please refer to the official
-    docs if a greater understanding of the supported authentication methods and general functionality is desired.
-    Source: https://googleapis.dev/python/google-api-core/latest/auth.html
+    Args:
+        name (str): required name for DataConnector
+        datasource_name (str): required name for datasource
+        bucket_or_name (str): bucket name for Google Cloud Storage
+        assets (dict): dict of asset configuration (required for ConfiguredAssetDataConnector)
+        execution_engine (ExecutionEngine): optional reference to ExecutionEngine
+        default_regex (dict): optional regex configuration for filtering data_references
+        sorters (list): optional list of sorters for sorting data_references
+        prefix (str): GCS prefix
+        delimiter (str): GCS delimiter
+        max_results (int): max blob filepaths to return
+        gcs_options (dict): wrapper object for optional GCS `**kwargs`
+        batch_spec_passthrough (dict): dictionary with keys that will be added directly to batch_spec
     """
 
     def __init__(
@@ -66,23 +69,7 @@ class ConfiguredAssetGCSDataConnector(ConfiguredAssetFilePathDataConnector):
         batch_spec_passthrough: Optional[dict] = None,
         id: Optional[str] = None,
     ) -> None:
-        """
-        ConfiguredAssetDataConnector for connecting to GCS.
 
-        Args:
-            name (str): required name for DataConnector
-            datasource_name (str): required name for datasource
-            bucket_or_name (str): bucket name for Google Cloud Storage
-            assets (dict): dict of asset configuration (required for ConfiguredAssetDataConnector)
-            execution_engine (ExecutionEngine): optional reference to ExecutionEngine
-            default_regex (dict): optional regex configuration for filtering data_references
-            sorters (list): optional list of sorters for sorting data_references
-            prefix (str): GCS prefix
-            delimiter (str): GCS delimiter
-            max_results (int): max blob filepaths to return
-            gcs_options (dict): wrapper object for optional GCS **kwargs
-            batch_spec_passthrough (dict): dictionary with keys that will be added directly to batch_spec
-        """
         logger.debug(f'Constructing ConfiguredAssetGCSDataConnector "{name}".')
 
         super().__init__(
@@ -173,7 +160,4 @@ class ConfiguredAssetGCSDataConnector(ConfiguredAssetFilePathDataConnector):
             "bucket_or_name": self._bucket_or_name,
             "path": path,
         }
-        return self.execution_engine.resolve_data_reference(
-            data_connector_name=self.__class__.__name__,
-            template_arguments=template_arguments,
-        )
+        return self.resolve_data_reference(template_arguments=template_arguments)
