@@ -1,13 +1,14 @@
 import logging
 from typing import List, Optional
 
-from great_expectations.core.batch import BatchDefinition
+from great_expectations.core._docs_decorators import public_api
+from great_expectations.core.batch import BatchDefinition  # noqa: TCH001
 from great_expectations.core.batch_spec import GCSBatchSpec, PathBatchSpec
 from great_expectations.datasource.data_connector.inferred_asset_file_path_data_connector import (
     InferredAssetFilePathDataConnector,
 )
 from great_expectations.datasource.data_connector.util import list_gcs_keys
-from great_expectations.execution_engine import ExecutionEngine
+from great_expectations.execution_engine import ExecutionEngine  # noqa: TCH001
 
 logger = logging.getLogger(__name__)
 
@@ -22,21 +23,13 @@ except ImportError:
     )
 
 
+@public_api
 class InferredAssetGCSDataConnector(InferredAssetFilePathDataConnector):
-    """
-    Extension of ConfiguredAssetFilePathDataConnector used to connect to GCS
+    """An Inferred Asset Data Connector used to connect to Google Cloud Storage (GCS).
 
-    DataConnectors produce identifying information, called "batch_spec" that ExecutionEngines
-    can use to get individual batches of data. They add flexibility in how to obtain data
-    such as with time-based partitioning, splitting and sampling, or other techniques appropriate
-    for obtaining batches of data.
-
-    The InferredAssetGCSDataConnector is one of two classes (ConfiguredAssetGCSDataConnector being the
-    other one) designed for connecting to data on GCS.
-
-    An InferredAssetGCSDataConnector uses regular expressions to traverse through GCS buckets and implicitly
-    determine `data_asset_names`.  Please note that in order to maintain consistency with Google's official SDK,
-    we utilize terms like "bucket_or_name" and "max_results". Since we convert these keys from YAML to Python and
+    This Data Connector uses regular expressions to traverse through GCS buckets and implicitly
+    determine Data Asset name. Please note that in order to maintain consistency with Google's official SDK,
+    we utilize parameter names `bucket_or_name` and `max_results`. Since we convert these keys from YAML to Python and
     directly pass them in to the GCS connection object, maintaining consistency is necessary for proper usage.
 
     This DataConnector supports the following methods of authentication:
@@ -44,9 +37,24 @@ class InferredAssetGCSDataConnector(InferredAssetFilePathDataConnector):
         2. Manual creation of credentials from google.oauth2.service_account.Credentials.from_service_account_file
         3. Manual creation of credentials from google.oauth2.service_account.Credentials.from_service_account_info
 
-    As much of the interaction with the SDK is done through a GCS Storage Client, please refer to the official
-    docs if a greater understanding of the supported authentication methods and general functionality is desired.
-    Source: https://googleapis.dev/python/google-api-core/latest/auth.html
+    Much of the interaction is performed using a GCS Storage Client. Please refer to
+    the `official Google documentation <https://googleapis.dev/python/google-api-core/latest/auth.html>`_ for more
+    information.
+
+    Args:
+        name: The name of the Data Connector.
+        datasource_name: The name of this Data Connector's Datasource.
+        bucket_or_name: Bucket name for Google Cloud Storage.
+        execution_engine: The Execution Engine object to used by this Data Connector to read the data.
+        default_regex: A regex configuration for filtering data references. The dict can include a regex `pattern` and
+            a list of `group_names` for capture groups.
+        sorters: A list of sorters for sorting data references.
+        prefix: Infer as Data Assets only blobs that begin with this prefix.
+        delimiter: When included, will remove any prefix up to the delimiter from the inferred Data Asset names.
+        max_results: Max blob filepaths to return.
+        gcs_options: Options passed to the GCS Storage Client.
+        batch_spec_passthrough: Dictionary with keys that will be added directly to the batch spec.
+        id: The unique identifier for this Data Connector used when running in cloud mode.
     """
 
     def __init__(
@@ -64,22 +72,6 @@ class InferredAssetGCSDataConnector(InferredAssetFilePathDataConnector):
         batch_spec_passthrough: Optional[dict] = None,
         id: Optional[str] = None,
     ) -> None:
-        """
-        InferredAssetDataConnector for connecting to GCS.
-
-        Args:
-            name (str): required name for DataConnector
-            datasource_name (str): required name for datasource
-            bucket_or_name (str): container name for Google Cloud Storage
-            execution_engine (ExecutionEngine): optional reference to ExecutionEngine
-            default_regex (dict): optional regex configuration for filtering data_references
-            sorters (list): optional list of sorters for sorting data_references
-            prefix (str): GCS prefix
-            delimiter (str): GCS delimiter
-            max_results (int): max blob filepaths to return
-            gcs_options (dict): wrapper object for optional GCS **kwargs
-            batch_spec_passthrough (dict): dictionary with keys that will be added directly to batch_spec
-        """
         logger.debug(f'Constructing InferredAssetGCSDataConnector "{name}".')
 
         super().__init__(
@@ -162,7 +154,4 @@ class InferredAssetGCSDataConnector(InferredAssetFilePathDataConnector):
             "bucket_or_name": self._bucket_or_name,
             "path": path,
         }
-        return self.execution_engine.resolve_data_reference(
-            data_connector_name=self.__class__.__name__,
-            template_arguments=template_arguments,
-        )
+        return self.resolve_data_reference(template_arguments=template_arguments)
