@@ -1,7 +1,8 @@
 import logging
 from typing import Any, Dict, List, Optional, Tuple, Union
 
-import great_expectations.exceptions as ge_exceptions
+import great_expectations.exceptions as gx_exceptions
+from great_expectations.core._docs_decorators import public_api
 from great_expectations.core.batch import BatchDefinition, RuntimeBatchRequest
 from great_expectations.core.batch_spec import (
     AzureBatchSpec,
@@ -13,26 +14,31 @@ from great_expectations.core.batch_spec import (
     S3BatchSpec,
 )
 from great_expectations.core.id_dict import IDDict
-from great_expectations.datasource.data_connector.asset import Asset
+from great_expectations.datasource.data_connector.asset import Asset  # noqa: TCH001
 from great_expectations.datasource.data_connector.data_connector import DataConnector
 from great_expectations.datasource.data_connector.util import _build_asset_from_config
-from great_expectations.execution_engine import ExecutionEngine
+from great_expectations.execution_engine import ExecutionEngine  # noqa: TCH001
 
 logger = logging.getLogger(__name__)
 
 DEFAULT_DELIMITER: str = "-"
 
 
+@public_api
 class RuntimeDataConnector(DataConnector):
-    """
-    A DataConnector that allows users to specify a Batch's data directly using a RuntimeBatchRequest that contains
-    either an in-memory Pandas or Spark DataFrame, a filesystem or S3 path, or an arbitrary SQL query
+    """A Data Connector that allows users to specify a Batch's data directly using a Runtime Batch Request.
+
+    A Runtime Batch Request contains either an in-memory Pandas or Spark DataFrame, a filesystem or S3 path,
+    or an arbitrary SQL query.
+
     Args:
-        name (str): The name of this DataConnector
-        datasource_name (str): The name of the Datasource that contains it
-        execution_engine (ExecutionEngine): An ExecutionEngine
-        batch_identifiers (list): a list of keys that must be defined in the batch_identifiers dict of RuntimeBatchRequest
-        batch_spec_passthrough (dict): dictionary with keys that will be added directly to batch_spec
+        name: The name of the Data Connector.
+        datasource_name: The name of this Data Connector's Datasource.
+        execution_engine: The Execution Engine object to used by this Data Connector to read the data.
+        batch_identifiers: A list of keys that must be defined in the batch identifiers dict of the Runtime Batch
+            Request.
+        batch_spec_passthrough: Dictionary with keys that will be added directly to the batch spec.
+        id: The unique identifier for this Data Connector used when running in cloud mode.
     """
 
     def __init__(
@@ -120,13 +126,13 @@ class RuntimeDataConnector(DataConnector):
         """
         if data_asset_name:
             if not batch_identifiers:
-                raise ge_exceptions.DataConnectorError(
+                raise gx_exceptions.DataConnectorError(
                     f"""RuntimeDataConnector "{self.name}" requires batch_identifiers to be configured when specifying Assets."""
                 )
             self._batch_identifiers[data_asset_name] = batch_identifiers
         else:
             if not batch_identifiers and len(self.assets) == 0:
-                raise ge_exceptions.DataConnectorError(
+                raise gx_exceptions.DataConnectorError(
                     f"""RuntimeDataConnector "{self.name}" requires batch_identifiers to be configured, either at the DataConnector or Asset-level."""
                 )
             if batch_identifiers:
@@ -156,7 +162,7 @@ class RuntimeDataConnector(DataConnector):
             ]
             return data_reference_list  # type: ignore[return-value] # could be list of lists
 
-    def get_data_reference_list_count(self) -> int:
+    def get_data_reference_count(self) -> int:
         """
         Get number of data_references corresponding to all data_asset_names in cache. In cases where the
         RuntimeDataConnector has been passed a BatchRequest with the same data_asset_name but different
@@ -182,6 +188,7 @@ class RuntimeDataConnector(DataConnector):
     def get_unmatched_data_references(self) -> List[str]:
         return []
 
+    @public_api
     def get_available_data_asset_names(self) -> List[str]:
         """Returns a list of data_assets that are both defined at runtime, and defined in DataConnector configuration"""
         defined_assets: List[str] = list(self.assets.keys())
@@ -244,7 +251,7 @@ class RuntimeDataConnector(DataConnector):
             batch_identifiers = batch_request.batch_identifiers
 
         if not batch_identifiers:
-            ge_exceptions.DataConnectorError(
+            raise gx_exceptions.DataConnectorError(
                 "Passed in a RuntimeBatchRequest with no batch_identifiers"
             )
 
@@ -253,14 +260,14 @@ class RuntimeDataConnector(DataConnector):
             datasource_name=self.datasource_name,
             data_connector_name=self.name,
             data_asset_name=batch_request.data_asset_name,
-            batch_identifiers=IDDict(batch_identifiers),  # type: ignore[arg-type]
+            batch_identifiers=IDDict(batch_identifiers),
             batch_spec_passthrough=batch_request.batch_spec_passthrough,
         )
         batch_definition_list = [batch_definition]
         self._update_data_references_cache(
             batch_request.data_asset_name,
             batch_definition_list,
-            IDDict(batch_identifiers),  # type: ignore[arg-type]
+            IDDict(batch_identifiers),
         )
         return batch_definition_list
 
@@ -351,7 +358,7 @@ class RuntimeDataConnector(DataConnector):
             if val is not None and key in ["batch_data", "query", "path"]
         ]
         if len(keys_present) != 1:
-            raise ge_exceptions.InvalidBatchRequestError(
+            raise gx_exceptions.InvalidBatchRequestError(
                 "The runtime_parameters dict must have one (and only one) of the following keys: 'batch_data', "
                 "'query', 'path'."
             )
@@ -366,7 +373,7 @@ class RuntimeDataConnector(DataConnector):
             (not runtime_parameters and not batch_identifiers)
             or (runtime_parameters and batch_identifiers)
         ):
-            raise ge_exceptions.DataConnectorError(
+            raise gx_exceptions.DataConnectorError(
                 f"""RuntimeDataConnector "{self.name}" requires runtime_parameters and batch_identifiers to be both
                 present and non-empty or
                 both absent in the batch_request parameter.
@@ -416,7 +423,7 @@ class RuntimeDataConnector(DataConnector):
         asset: Asset = self.assets[data_asset_name]
         batch_identifiers_keys: List[str] = list(batch_identifiers.keys())
         if not set(batch_identifiers_keys) == set(asset.batch_identifiers):  # type: ignore[arg-type]
-            raise ge_exceptions.DataConnectorError(
+            raise gx_exceptions.DataConnectorError(
                 f"""
                 Data Asset {data_asset_name} was invoked with one or more batch_identifiers
                 that were not configured for the asset.
@@ -434,7 +441,7 @@ class RuntimeDataConnector(DataConnector):
         """
         batch_identifiers_keys: List[str] = list(batch_identifiers.keys())
         if not set(batch_identifiers_keys) <= set(self._batch_identifiers[self.name]):
-            raise ge_exceptions.DataConnectorError(
+            raise gx_exceptions.DataConnectorError(
                 f"""RuntimeDataConnector {self.name} was invoked with one or more batch identifiers that do not
         appear among the configured batch identifiers.
 
