@@ -1,22 +1,38 @@
+from __future__ import annotations
+
 import copy
 import datetime
 import logging
-import uuid
 import warnings
 from functools import reduce
-from typing import Any, Callable, Dict, Iterable, List, Optional, Tuple, Union
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Tuple,
+    Union,
+    cast,
+    overload,
+)
 
 from dateutil.parser import parse
 
+from great_expectations.core._docs_decorators import public_api
 from great_expectations.core.batch import BatchMarkers
 from great_expectations.core.batch_spec import (
     AzureBatchSpec,
     BatchSpec,
+    GlueDataCatalogBatchSpec,
     PathBatchSpec,
     RuntimeDataBatchSpec,
 )
 from great_expectations.core.id_dict import IDDict
-from great_expectations.core.metric_domain_types import MetricDomainTypes
+from great_expectations.core.metric_domain_types import (
+    MetricDomainTypes,  # noqa: TCH001
+)
 from great_expectations.core.util import (
     AzureUrl,
     convert_to_json_serializable,
@@ -28,10 +44,11 @@ from great_expectations.exceptions import (
     GreatExpectationsError,
     ValidationError,
 )
-from great_expectations.exceptions import exceptions as ge_exceptions
+from great_expectations.exceptions import exceptions as gx_exceptions
 from great_expectations.execution_engine import ExecutionEngine
-from great_expectations.execution_engine.bundled_metric_configuration import (
-    BundledMetricConfiguration,
+from great_expectations.execution_engine.execution_engine import (
+    MetricComputationConfiguration,  # noqa: TCH001
+    SplitDomainKwargs,  # noqa: TCH001
 )
 from great_expectations.execution_engine.sparkdf_batch_data import SparkDFBatchData
 from great_expectations.execution_engine.split_and_sample.sparkdf_data_sampler import (
@@ -45,7 +62,10 @@ from great_expectations.expectations.row_conditions import (
     RowConditionParserType,
     parse_condition_to_spark,
 )
-from great_expectations.validator.metric_configuration import MetricConfiguration
+from great_expectations.validator.computed_metric import MetricValue  # noqa: TCH001
+from great_expectations.validator.metric_configuration import (
+    MetricConfiguration,  # noqa: TCH001
+)
 
 logger = logging.getLogger(__name__)
 
@@ -82,10 +102,33 @@ def apply_dateutil_parse(column):
     return column.withColumn(col_name, _udf(col_name))
 
 
+@public_api
 class SparkDFExecutionEngine(ExecutionEngine):
-    """
+    """SparkDFExecutionEngine instantiates the ExecutionEngine API to support computations using Spark platform.
+
     This class holds an attribute `spark_df` which is a spark.sql.DataFrame.
 
+    Constructor builds a SparkDFExecutionEngine, using provided configuration parameters.
+
+    Args:
+        *args: Positional arguments for configuring SparkDFExecutionEngine
+        persist: If True (default), then creation of the Spark DataFrame is done outside this class
+        spark_config: Dictionary of Spark configuration options
+        force_reuse_spark_context: If True then utilize existing SparkSession if it exists and is active
+        **kwargs: Keyword arguments for configuring SparkDFExecutionEngine
+
+    For example:
+    ```python
+        name: str = "great_expectations-ee-config"
+        spark_config: Dict[str, str] = {
+        "spark.app.name": name,
+        "spark.sql.catalogImplementation": "hive",
+        "spark.executor.memory": "512m",
+        }
+        execution_engine = SparkDFExecutionEngine(spark_config=spark_config)
+        spark_session: SparkSession = execution_engine.spark
+    ```
+
     --ge-feature-maturity-info--
 
         id: validation_engine_pyspark_self_managed
@@ -170,7 +213,6 @@ class SparkDFExecutionEngine(ExecutionEngine):
         force_reuse_spark_context=False,
         **kwargs,
     ) -> None:
-        # Creation of the Spark DataFrame is done outside this class
         self._persist = persist
 
         if spark_config is None:
@@ -204,24 +246,25 @@ class SparkDFExecutionEngine(ExecutionEngine):
         self._data_sampler = SparkDataSampler()
 
     @property
-    def dataframe(self):
+    def dataframe(self) -> DataFrame:
         """If a batch has been loaded, returns a Spark Dataframe containing the data within the loaded batch"""
-        if not self.active_batch_data:
+        if self.batch_manager.active_batch_data is None:
             raise ValueError(
                 "Batch has not been loaded - please run load_batch() to load a batch."
             )
 
-        return self.active_batch_data.dataframe
+        return cast(SparkDFBatchData, self.batch_manager.active_batch_data).dataframe
 
-    def load_batch_data(self, batch_id: str, batch_data: Any) -> None:
+    def load_batch_data(
+        self, batch_id: str, batch_data: Union[SparkDFBatchData, DataFrame]
+    ) -> None:
         if isinstance(batch_data, DataFrame):
             batch_data = SparkDFBatchData(self, batch_data)
-        elif isinstance(batch_data, SparkDFBatchData):
-            pass
-        else:
+        elif not isinstance(batch_data, SparkDFBatchData):
             raise GreatExpectationsError(
                 "SparkDFExecutionEngine requires batch data that is either a DataFrame or a SparkDFBatchData object"
             )
+
         super().load_batch_data(batch_id=batch_id, batch_data=batch_data)
 
     def get_batch_data_and_markers(
@@ -241,24 +284,30 @@ class SparkDFExecutionEngine(ExecutionEngine):
         formats for accessing Azure Blob Storage service.  However, Pandas and Spark execution engines utilize identical
         path formats for accessing all other supported cloud storage services (AWS S3 and Google Cloud Storage).
         Moreover, these formats (encapsulated in S3BatchSpec and GCSBatchSpec) extend PathBatchSpec (common to them).
-        Therefore, at the present time, all cases with the exception of Azure Blob Storage , are handled generically.
+        Therefore, at the present time, all cases with the exception of Azure Blob Storage, are handled generically.
         """
 
         batch_data: Any
+        reader_method: str
+        reader_options: dict
+        path: str
+        schema: Optional[Union[pyspark.sql.types.StructType, dict, str]]
+        reader: DataFrameReader
+        reader_fn: Callable
         if isinstance(batch_spec, RuntimeDataBatchSpec):
             # batch_data != None is already checked when RuntimeDataBatchSpec is instantiated
             batch_data = batch_spec.batch_data
             if isinstance(batch_data, str):
-                raise ge_exceptions.ExecutionEngineError(
-                    f"""SparkDFExecutionEngine has been passed a string type batch_data, "{batch_data}", which is illegal.
-Please check your config."""
+                raise gx_exceptions.ExecutionEngineError(
+                    f"""SparkDFExecutionEngine has been passed a string type batch_data, "{batch_data}", which is \
+illegal.  Please check your config."""
                 )
             batch_spec.batch_data = "SparkDataFrame"
 
         elif isinstance(batch_spec, AzureBatchSpec):
-            reader_method: str = batch_spec.reader_method
-            reader_options: dict = batch_spec.reader_options or {}
-            path: str = batch_spec.path
+            reader_method = batch_spec.reader_method
+            reader_options = batch_spec.reader_options or {}
+            path = batch_spec.path
             azure_url = AzureUrl(path)
             # TODO <WILL> 202209 - Add `schema` definition to Azure like PathBatchSpec below (GREAT-1224)
             try:
@@ -272,8 +321,8 @@ Please check your config."""
                     self.spark.conf.set(
                         f"fs.azure.account.key.{storage_account_url}", credential
                     )
-                reader: DataFrameReader = self.spark.read.options(**reader_options)
-                reader_fn: Callable = self._get_reader_fn(
+                reader = self.spark.read.options(**reader_options)
+                reader_fn = self._get_reader_fn(
                     reader=reader,
                     reader_method=reader_method,
                     path=path,
@@ -286,38 +335,34 @@ Please check your config."""
                     """
                 )
 
-        elif isinstance(batch_spec, PathBatchSpec):
-            reader_method: str = batch_spec.reader_method
-            reader_options: dict = batch_spec.reader_options or {}
-            path: str = batch_spec.path
-            schema: Optional[
-                Union[pyspark.sql.types.StructType, dict, str]
-            ] = reader_options.get("schema")
+        elif isinstance(batch_spec, (PathBatchSpec, GlueDataCatalogBatchSpec)):
+            reader_method = batch_spec.reader_method
+            reader_options = batch_spec.reader_options or {}
+            path = batch_spec.path
+            schema = reader_options.get("schema")
 
             # schema can be a dict if it has been through serialization step,
             # either as part of the datasource configuration, or checkpoint config
             if isinstance(schema, dict):
-                schema: pyspark.sql.types.StructType = sparktypes.StructType.fromJson(
-                    schema
-                )
+                schema = sparktypes.StructType.fromJson(schema)
 
             # this can happen if we have not converted schema into json at Datasource-config level
             elif isinstance(schema, str):
-                raise ge_exceptions.ExecutionEngineError(
-                    f"""
-                                Spark schema was not properly serialized.
-                                Please run the .jsonValue() method on the schema object before loading into GE.
-                                schema: your_schema.jsonValue()
-                                """
+                raise gx_exceptions.ExecutionEngineError(
+                    """
+                    Spark schema was not properly serialized.
+                    Please run the .jsonValue() method on the schema object before loading into GX.
+                    schema: your_schema.jsonValue()
+                    """
                 )
+            # noinspection PyUnresolvedReferences
             try:
                 if schema:
-                    reader: DataFrameReader = self.spark.read.schema(schema).options(
-                        **reader_options
-                    )
+                    reader = self.spark.read.schema(schema).options(**reader_options)
                 else:
-                    reader: DataFrameReader = self.spark.read.options(**reader_options)
-                reader_fn: Callable = self._get_reader_fn(
+                    reader = self.spark.read.options(**reader_options)
+
+                reader_fn = self._get_reader_fn(
                     reader=reader,
                     reader_method=reader_method,
                     path=path,
@@ -348,6 +393,14 @@ Please check your config."""
         return typed_batch_data, batch_markers
 
     def _apply_splitting_and_sampling_methods(self, batch_spec, batch_data):
+        # Note this is to get a batch from tables in AWS Glue Data Catalog by its partitions
+        partitions: Optional[List[str]] = batch_spec.get("partitions")
+        if partitions:
+            batch_data = self._data_splitter.split_on_multi_column_values(
+                df=batch_data,
+                column_names=partitions,
+                batch_identifiers=batch_spec.get("batch_identifiers"),
+            )
 
         splitter_method_name: Optional[str] = batch_spec.get("splitter_method")
         if splitter_method_name:
@@ -368,8 +421,9 @@ Please check your config."""
 
     # TODO: <Alex>Similar to Abe's note in PandasExecutionEngine: Any reason this shouldn't be a private method?</Alex>
     @staticmethod
-    def guess_reader_method_from_path(path):
-        """Based on a given filepath, decides a reader method. Currently supports tsv, csv, and parquet. If none of these
+    def guess_reader_method_from_path(path: str):
+        """
+        Based on a given filepath, decides a reader method. Currently supports tsv, csv, and parquet. If none of these
         file extensions are used, returns ExecutionEngineError stating that it is unable to determine the current path.
 
         Args:
@@ -379,6 +433,7 @@ Please check your config."""
             A dictionary entry of format {'reader_method': reader_method}
 
         """
+        path = path.lower()
         if path.endswith(".csv") or path.endswith(".tsv"):
             return "csv"
         elif (
@@ -390,7 +445,19 @@ Please check your config."""
             f"Unable to determine reader method from path: {path}"
         )
 
-    def _get_reader_fn(self, reader, reader_method=None, path=None):
+    @overload
+    def _get_reader_fn(
+        self, reader, reader_method: str = ..., path: Optional[str] = ...
+    ) -> Callable:
+        ...
+
+    @overload
+    def _get_reader_fn(
+        self, reader, reader_method: None = ..., path: str = ...
+    ) -> Callable:
+        ...
+
+    def _get_reader_fn(self, reader, reader_method=None, path=None) -> Callable:
         """Static helper for providing reader_fn
 
         Args:
@@ -420,19 +487,18 @@ Please check your config."""
                 f"Unable to find reader_method {reader_method} in spark.",
             )
 
-    def get_domain_records(
+    @public_api
+    def get_domain_records(  # noqa: C901 - 18
         self,
         domain_kwargs: dict,
     ) -> DataFrame:
-        """
-        Uses the given domain kwargs (which include row_condition, condition_parser, and ignore_row_if directives) to
-        obtain and/or query a batch. Returns in the format of a Spark DataFrame.
+        """Uses the given Domain kwargs (which include row_condition, condition_parser, and ignore_row_if directives) to obtain and/or query a batch.
 
         Args:
-            domain_kwargs (dict) - A dictionary consisting of the domain kwargs specifying which data to obtain
+            domain_kwargs (dict) - A dictionary consisting of the Domain kwargs specifying which data to obtain
 
         Returns:
-            A DataFrame (the data on which to compute)
+            A DataFrame (the data on which to compute returned in the format of a Spark DataFrame)
         """
         table = domain_kwargs.get("table", None)
         if table:
@@ -443,15 +509,19 @@ Please check your config."""
         batch_id = domain_kwargs.get("batch_id")
         if batch_id is None:
             # We allow no batch id specified if there is only one batch
-            if self.active_batch_data:
-                data = self.active_batch_data.dataframe
+            if self.batch_manager.active_batch_data:
+                data = cast(
+                    SparkDFBatchData, self.batch_manager.active_batch_data
+                ).dataframe
             else:
                 raise ValidationError(
                     "No batch is specified, but could not identify a loaded batch."
                 )
         else:
-            if batch_id in self.loaded_batch_data_dict:
-                data = self.loaded_batch_data_dict[batch_id].dataframe
+            if batch_id in self.batch_manager.batch_data_cache:
+                data = cast(
+                    SparkDFBatchData, self.batch_manager.batch_data_cache[batch_id]
+                ).dataframe
             else:
                 raise ValidationError(f"Unable to find batch with batch_id {batch_id}")
 
@@ -512,7 +582,8 @@ Please check your config."""
                     # deprecated-v0.13.29
                     warnings.warn(
                         f"""The correct "no-action" value of the "ignore_row_if" directive for the column pair case is \
-"neither" (the use of "{ignore_row_if}" is deprecated as of v0.13.29 and will be removed in v0.16).  Please use "neither" moving forward.
+"neither" (the use of "{ignore_row_if}" is deprecated as of v0.13.29 and will be removed in v0.16).  Please use \
+"neither" moving forward.
 """,
                         DeprecationWarning,
                     )
@@ -570,40 +641,43 @@ Please check your config."""
             condition=joined_condition, condition_type=RowConditionParserType.SPARK_SQL
         )
 
+    @public_api
     def get_compute_domain(
         self,
         domain_kwargs: dict,
         domain_type: Union[str, MetricDomainTypes],
         accessor_keys: Optional[Iterable[str]] = None,
     ) -> Tuple[DataFrame, dict, dict]:
-        """Uses a given batch dictionary and domain kwargs (which include a row condition and a condition parser)
-        to obtain and/or query a batch. Returns in the format of a Spark DataFrame.
+        """Uses a DataFrame and Domain kwargs (which include a row condition and a condition parser) to obtain and/or query a Batch of data.
+
+        Returns in the format of a Spark DataFrame along with Domain arguments required for computing.  If the Domain \
+        is a single column, this is added to 'accessor Domain kwargs' and used for later access.
 
         Args:
-            domain_kwargs (dict) - A dictionary consisting of the domain kwargs specifying which data to obtain
-            domain_type (str or MetricDomainTypes) - an Enum value indicating which metric domain the user would
-            like to be using, or a corresponding string value representing it. String types include "identity",
-            "column", "column_pair", "table" and "other". Enum types include capitalized versions of these from the
-            class MetricDomainTypes.
-            accessor_keys (str iterable) - keys that are part of the compute domain but should be ignored when
-            describing the domain and simply transferred with their associated values into accessor_domain_kwargs.
+            domain_kwargs (dict): a dictionary consisting of the Domain kwargs specifying which data to obtain
+            domain_type (str or MetricDomainTypes): an Enum value indicating which metric Domain the user would like \
+            to be using, or a corresponding string value representing it.  String types include "identity", "column", \
+            "column_pair", "table" and "other".  Enum types include capitalized versions of these from the class \
+            MetricDomainTypes.
+            accessor_keys (str iterable): keys that are part of the compute Domain but should be ignored when \
+            describing the Domain and simply transferred with their associated values into accessor_domain_kwargs.
 
         Returns:
             A tuple including:
               - a DataFrame (the data on which to compute)
               - a dictionary of compute_domain_kwargs, describing the DataFrame
               - a dictionary of accessor_domain_kwargs, describing any accessors needed to
-                identify the domain within the compute domain
+                identify the Domain within the compute domain
         """
-        data = self.get_domain_records(domain_kwargs)
-
-        table = domain_kwargs.get("table", None)
+        table: str = domain_kwargs.get("table", None)
         if table:
             raise ValueError(
                 "SparkDFExecutionEngine does not currently support multiple named tables."
             )
 
-        split_domain_kwargs = self._split_domain_kwargs(
+        data: DataFrame = self.get_domain_records(domain_kwargs=domain_kwargs)
+
+        split_domain_kwargs: SplitDomainKwargs = self._split_domain_kwargs(
             domain_kwargs, domain_type, accessor_keys
         )
 
@@ -648,92 +722,76 @@ Please check your config."""
 
     def resolve_metric_bundle(
         self,
-        metric_fn_bundle: Iterable[BundledMetricConfiguration],
-    ) -> Dict[Tuple[str, str, str], Any]:
+        metric_fn_bundle: Iterable[MetricComputationConfiguration],
+    ) -> Dict[Tuple[str, str, str], MetricValue]:
         """For every metric in a set of Metrics to resolve, obtains necessary metric keyword arguments and builds
         bundles of the metrics into one large query dictionary so that they are all executed simultaneously. Will fail
         if bundling the metrics together is not possible.
 
             Args:
-                metric_fn_bundle (Iterable[BundledMetricConfiguration]): \
-                    "BundledMetricConfiguration" contains MetricProvider's MetricConfiguration (its unique identifier),
+                metric_fn_bundle (Iterable[MetricComputationConfiguration]): \
+                    "MetricComputationConfiguration" contains MetricProvider's MetricConfiguration (its unique identifier),
                     its metric provider function (the function that actually executes the metric), and arguments to pass
                     to metric provider function (dictionary of metrics defined in registry and corresponding arguments).
 
             Returns:
                 A dictionary of "MetricConfiguration" IDs and their corresponding fully resolved values for domains.
         """
-        resolved_metrics: Dict[Tuple[str, str, str], Any] = {}
+        resolved_metrics: Dict[Tuple[str, str, str], MetricValue] = {}
 
         res: List[Row]
 
-        aggregates: Dict[Tuple, dict] = {}
+        aggregates: Dict[Tuple[str, str, str], dict] = {}
 
         aggregate: dict
 
         domain_id: Tuple[str, str, str]
 
-        bundled_metric_configuration: BundledMetricConfiguration
+        bundled_metric_configuration: MetricComputationConfiguration
         for bundled_metric_configuration in metric_fn_bundle:
-            bundled_metric_configuration: BundledMetricConfiguration
             metric_to_resolve: MetricConfiguration = (
                 bundled_metric_configuration.metric_configuration
             )
             metric_fn: Any = bundled_metric_configuration.metric_fn
             compute_domain_kwargs: dict = (
-                bundled_metric_configuration.compute_domain_kwargs
+                bundled_metric_configuration.compute_domain_kwargs or {}
             )
-
             if not isinstance(compute_domain_kwargs, IDDict):
                 compute_domain_kwargs = IDDict(compute_domain_kwargs)
 
-            domain_id = IDDict.convert_dictionary_to_id_dict(
-                data=convert_to_json_serializable(data=compute_domain_kwargs)
-            ).to_id()
+            domain_id = compute_domain_kwargs.to_id()
             if domain_id not in aggregates:
                 aggregates[domain_id] = {
                     "column_aggregates": [],
-                    "ids": [],
+                    "metric_ids": [],
                     "domain_kwargs": compute_domain_kwargs,
                 }
 
             aggregates[domain_id]["column_aggregates"].append(metric_fn)
-            aggregates[domain_id]["ids"].append(metric_to_resolve.id)
+            aggregates[domain_id]["metric_ids"].append(metric_to_resolve.id)
 
         for aggregate in aggregates.values():
             domain_kwargs: dict = aggregate["domain_kwargs"]
-            df: Optional[DataFrame] = self.get_domain_records(
-                domain_kwargs=domain_kwargs,
-            )
+            df: DataFrame = self.get_domain_records(domain_kwargs=domain_kwargs)
 
-            assert len(aggregate["column_aggregates"]) == len(aggregate["ids"])
+            assert len(aggregate["column_aggregates"]) == len(aggregate["metric_ids"])
 
-            condition_ids: List[str] = []
-            aggregate_cols: List[str] = []
-
-            idx: int
-            for idx in range(len(aggregate["column_aggregates"])):
-                column_aggregate: Any = aggregate["column_aggregates"][idx]
-                aggregate_id: str = str(uuid.uuid4())
-                condition_ids.append(aggregate_id)
-                aggregate_cols.append(column_aggregate)
-
-            res = df.agg(*aggregate_cols).collect()
+            res = df.agg(*aggregate["column_aggregates"]).collect()
 
             logger.debug(
-                f"SparkDFExecutionEngine computed {len(res[0])} metrics on domain_id {IDDict.convert_dictionary_to_id_dict(data=convert_to_json_serializable(data=domain_kwargs)).to_id()}"
+                f"SparkDFExecutionEngine computed {len(res[0])} metrics on domain_id {IDDict(domain_kwargs).to_id()}"
             )
 
             assert (
                 len(res) == 1
             ), "all bundle-computed metrics must be single-value statistics"
-            assert len(aggregate["ids"]) == len(
+            assert len(aggregate["metric_ids"]) == len(
                 res[0]
             ), "unexpected number of metrics returned"
 
             idx: int
             metric_id: Tuple[str, str, str]
-            for idx, metric_id in enumerate(aggregate["ids"]):
+            for idx, metric_id in enumerate(aggregate["metric_ids"]):
                 # Converting DataFrame.collect() results into JSON-serializable format produces simple data types,
                 # amenable for subsequent post-processing by higher-level "Metric" and "Expectation" layers.
                 resolved_metrics[metric_id] = convert_to_json_serializable(
