@@ -1,19 +1,37 @@
-from typing import Dict, List, Optional
+from numbers import Number
+from typing import TYPE_CHECKING, Dict, List, Optional, Union
 
 import numpy as np
 
-from great_expectations.core import ExpectationConfiguration
+from great_expectations.core import (
+    ExpectationConfiguration,  # noqa: TCH001
+    ExpectationValidationResult,  # noqa: TCH001
+)
+from great_expectations.core._docs_decorators import public_api
 from great_expectations.exceptions import InvalidExpectationConfigurationError
-from great_expectations.execution_engine import ExecutionEngine
-from great_expectations.expectations.expectation import ColumnExpectation
-from great_expectations.expectations.util import render_evaluation_parameter_string
-from great_expectations.render.renderer.renderer import renderer
-from great_expectations.render.types import (
+from great_expectations.execution_engine import ExecutionEngine  # noqa: TCH001
+from great_expectations.expectations.expectation import (
+    ColumnExpectation,
+    render_evaluation_parameter_string,
+)
+from great_expectations.render import (
+    AtomicDiagnosticRendererType,
+    AtomicPrescriptiveRendererType,
+    LegacyDescriptiveRendererType,
+    LegacyDiagnosticRendererType,
+    LegacyRendererType,
     RenderedAtomicContent,
     RenderedStringTemplateContent,
     RenderedTableContent,
     renderedAtomicValueSchema,
 )
+from great_expectations.render.renderer.renderer import renderer
+from great_expectations.render.renderer_configuration import (
+    RendererConfiguration,
+    RendererSchema,
+    RendererTableValue,
+    RendererValueType,
+)
 from great_expectations.render.util import (
     parse_row_condition_string_pandas_engine,
     substitute_none_for_missing,
@@ -31,106 +49,91 @@ from great_expectations.rule_based_profiler.parameter_container import (
     VARIABLES_KEY,
 )
 from great_expectations.util import isclose
+from great_expectations.validator.validator import (
+    ValidationDependencies,  # noqa: TCH001
+)
+
+if TYPE_CHECKING:
+    from great_expectations.render.renderer_configuration import AddParamArgs
 
 
 class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
     # noinspection PyUnresolvedReferences
-    """Expect specific provided column quantiles to be between provided minimum and maximum values.
+    """Expect the specific provided column quantiles to be between a minimum value and a maximum value.
 
-           ``quantile_ranges`` must be a dictionary with two keys:
+    expect_column_quantile_values_to_be_between is a \
+    [Column Aggregate Expectation](https://docs.greatexpectations.io/docs/guides/expectations/creating_custom_expectations/how_to_create_custom_column_aggregate_expectations).
 
-               * ``quantiles``: (list of float) increasing ordered list of desired quantile values
+    For example:
+    ::
 
-               * ``value_ranges``: (list of lists): Each element in this list consists of a list with two values, a lower \
-                 and upper bound (inclusive) for the corresponding quantile. These values must be [min, max] ordered.
+        # my_df.my_col = [1,2,2,3,3,3,4]
+        >>> my_df.expect_column_quantile_values_to_be_between(
+            "my_col",
+            {
+                "quantiles": [0., 0.333, 0.6667, 1.],
+                "value_ranges": [[0,1], [2,3], [3,4], [4,5]]
+            }
+        )
+        {
+          "success": True,
+            "result": {
+              "observed_value": {
+                "quantiles: [0., 0.333, 0.6667, 1.],
+                "values": [1, 2, 3, 4],
+              }
+              "element_count": 7,
+              "missing_count": 0,
+              "missing_percent": 0.0,
+              "details": {
+                "success_details": [true, true, true, true]
+              }
+            }
+          }
+        }
 
+    expect_column_quantile_values_to_be_between can be computationally intensive for large datasets.
 
-           For each provided range:
+    Args:
+        column (str): \
+            The column name.
+        quantile_ranges (dictionary with keys 'quantiles' and 'value_ranges'): \
+            Key 'quantiles' is an increasingly ordered list of desired quantile values (floats). \
+            Key 'value_ranges' is a list of 2-value lists that specify a lower and upper bound (inclusive) \
+            for the corresponding quantile (with [min, max] ordering). The length of the 'quantiles' list \
+            and the 'value_ranges' list must be equal.
+        allow_relative_error (boolean or string): \
+            Whether to allow relative error in quantile communications on backends that support or require it.
 
-               * min_value and max_value are both inclusive.
-               * If min_value is None, then max_value is treated as an upper bound only
-               * If max_value is None, then min_value is treated as a lower bound only
+    Other Parameters:
+        result_format (str or None): \
+            Which output mode to use: BOOLEAN_ONLY, BASIC, COMPLETE, or SUMMARY. \
+            For more detail, see [result_format](https://docs.greatexpectations.io/docs/reference/expectations/result_format).
+        include_config (boolean): \
+            If True, then include the expectation config as part of the result object.
+        catch_exceptions (boolean or None): \
+            If True, then catch exceptions and include them as part of the result object. \
+            For more detail, see [catch_exceptions](https://docs.greatexpectations.io/docs/reference/expectations/standard_arguments/#catch_exceptions).
+        meta (dict or None): \
+            A JSON-serializable dictionary (nesting allowed) that will be included in the output without \
+            modification. For more detail, see [meta](https://docs.greatexpectations.io/docs/reference/expectations/standard_arguments/#meta).
 
-           The length of the quantiles list and quantile_values list must be equal.
+    Returns:
+        An [ExpectationSuiteValidationResult](https://docs.greatexpectations.io/docs/terms/validation_result)
 
-           For example:
-           ::
+        Exact fields vary depending on the values passed to result_format, include_config, catch_exceptions, and meta.
 
-               # my_df.my_col = [1,2,2,3,3,3,4]
-               >>> my_df.expect_column_quantile_values_to_be_between(
-                   "my_col",
-                   {
-                       "quantiles": [0., 0.333, 0.6667, 1.],
-                       "value_ranges": [[0,1], [2,3], [3,4], [4,5]]
-                   }
-               )
-               {
-                 "success": True,
-                   "result": {
-                     "observed_value": {
-                       "quantiles: [0., 0.333, 0.6667, 1.],
-                       "values": [1, 2, 3, 4],
-                     }
-                     "element_count": 7,
-                     "missing_count": 0,
-                     "missing_percent": 0.0,
-                     "details": {
-                       "success_details": [true, true, true, true]
-                     }
-                   }
-                 }
-               }
+    Notes:
+        * min_value and max_value are both inclusive.
+        * If min_value is None, then max_value is treated as an upper bound only
+        * If max_value is None, then min_value is treated as a lower bound only
+        * details.success_details field in the result object is customized for this expectation
 
-           `expect_column_quantile_values_to_be_between` can be computationally intensive for large datasets.
-
-           expect_column_quantile_values_to_be_between is a \
-           :func:`column_aggregate_expectation
-           <great_expectations.execution_engine.MetaExecutionEngine.column_aggregate_expectation>`.
-
-           Args:
-               column (str): \
-                   The column name.
-               quantile_ranges (dictionary): \
-                   Quantiles and associated value ranges for the column. See above for details.
-               allow_relative_error (boolean or string): \
-                   Whether to allow relative error in quantile communications on backends that support or require it.
-
-           Other Parameters:
-               result_format (str or None): \
-                   Which output mode to use: `BOOLEAN_ONLY`, `BASIC`, `COMPLETE`, or `SUMMARY`.
-                   For more detail, see :ref:`result_format <result_format>`.
-               include_config (boolean): \
-                   If True, then include the expectation config as part of the result object. \
-                   For more detail, see :ref:`include_config`.
-               catch_exceptions (boolean or None): \
-                   If True, then catch exceptions and include them as part of the result object. \
-                   For more detail, see :ref:`catch_exceptions`.
-               meta (dict or None): \
-                   A JSON-serializable dictionary (nesting allowed) that will be included in the output without \
-                   modification. For more detail, see :ref:`meta`.
-
-           Returns:
-               An ExpectationSuiteValidationResult
-
-               Exact fields vary depending on the values passed to :ref:`result_format <result_format>` and
-               :ref:`include_config`, :ref:`catch_exceptions`, and :ref:`meta`.
-
-           Notes:
-               These fields in the result object are customized for this expectation:
-               ::
-               details.success_details
-
-           See Also:
-               :func:`expect_column_min_to_be_between \
-               <great_expectations.execution_engine.execution_engine.ExecutionEngine.expect_column_min_to_be_between>`
-
-               :func:`expect_column_max_to_be_between \
-               <great_expectations.execution_engine.execution_engine.ExecutionEngine.expect_column_max_to_be_between>`
-
-               :func:`expect_column_median_to_be_between \
-               <great_expectations.execution_engine.execution_engine.ExecutionEngine.expect_column_median_to_be_between>`
-
-           """
+    See Also:
+        [expect_column_min_to_be_between](https://greatexpectations.io/expectations/expect_column_min_to_be_between)
+        [expect_column_max_to_be_between](https://greatexpectations.io/expectations/expect_column_max_to_be_between)
+        [expect_column_median_to_be_between](https://greatexpectations.io/expectations/expect_column_median_to_be_between)
+    """
 
     # This dictionary contains metadata for display in the public gallery
     library_metadata = {
@@ -138,6 +141,8 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
         "tags": ["core expectation", "column aggregate expectation"],
         "contributors": ["@great_expectations"],
         "requirements": [],
+        "has_full_test_suite": True,
+        "manually_reviewed_code": True,
     }
 
     metric_dependencies = ("column.quantile_values",)
@@ -241,10 +246,30 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
         "allow_relative_error",
     )
 
+    @public_api
     def validate_configuration(
-        self, configuration: Optional[ExpectationConfiguration]
+        self, configuration: Optional[ExpectationConfiguration] = None
     ) -> None:
+        """Validates the configuration of an Expectation.
+
+        For `expect_column_quantile_values_to_be_between` it is required that the `configuration.kwargs` contain a
+        `quantile_ranges` key that is a `dict`. Also, `quantile_ranges` must contain a `value_ranges` key that is a
+        list of ordered pairs, as well as a `quantiles` key that is a list of the same length as `values_ranges`.
+
+        The configuration will also be validated using each of the `validate_configuration` methods in its Expectation
+        superclass hierarchy.
+
+        Args:
+            configuration: An `ExpectationConfiguration` to validate. If no configuration is provided, it will be pulled
+                from the configuration attribute of the Expectation instance.
+
+        Raises:
+            InvalidExpectationConfigurationError: The configuration does not contain the values required by the
+                Expectation.
+            ValueError: `value_ranges` and `quantiles` are not the same length.
+        """
         super().validate_configuration(configuration)
+        configuration = configuration or self.configuration
         try:
             assert (
                 "quantile_ranges" in configuration.kwargs
@@ -274,173 +299,139 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
             )
 
     @classmethod
-    def _atomic_prescriptive_template(
+    def _prescriptive_template(
         cls,
-        configuration=None,
-        result=None,
-        language=None,
-        runtime_configuration=None,
-        **kwargs,
-    ):
-        runtime_configuration = runtime_configuration or {}
-        include_column_name = runtime_configuration.get("include_column_name", True)
-        include_column_name = (
-            include_column_name if include_column_name is not None else True
+        renderer_configuration: RendererConfiguration,
+    ) -> RendererConfiguration:
+        add_param_args: AddParamArgs = (
+            ("column", RendererValueType.STRING),
+            ("mostly", RendererValueType.NUMBER),
         )
-        styling = runtime_configuration.get("styling")
-        params = substitute_none_for_missing(
-            configuration["kwargs"],
-            ["column", "quantile_ranges", "row_condition", "condition_parser"],
+        for name, param_type in add_param_args:
+            renderer_configuration.add_param(name=name, param_type=param_type)
+
+        template_str = "quantiles must be within the following value ranges."
+
+        if renderer_configuration.include_column_name:
+            template_str = f"$column {template_str}"
+
+        renderer_configuration.template_str = template_str
+
+        quantiles: list = renderer_configuration.kwargs.get("quantile_ranges", {}).get(
+            "quantiles", []
         )
+        value_ranges: list = renderer_configuration.kwargs.get(
+            "quantile_ranges", {}
+        ).get("value_ranges", [])
 
-        header_params_with_json_schema = {
-            "column": {"schema": {"type": "string"}, "value": params.get("column")},
-            "mostly": {"schema": {"type": "number"}, "value": params.get("mostly")},
-            "row_condition": {
-                "schema": {"type": "string"},
-                "value": params.get("row_condition"),
-            },
-            "condition_parser": {
-                "schema": {"type": "string"},
-                "value": params.get("condition_parser"),
-            },
-        }
-
-        header_template_str = "quantiles must be within the following value ranges."
-
-        if include_column_name:
-            header_template_str = f"$column {header_template_str}"
-
-        if params["row_condition"] is not None:
-            (
-                conditional_template_str,
-                conditional_params,
-            ) = parse_row_condition_string_pandas_engine(
-                params["row_condition"], with_schema=True
-            )
-            header_template_str = (
-                conditional_template_str
-                + ", then "
-                + header_template_str[0].lower()
-                + header_template_str[1:]
-            )
-            header_params_with_json_schema.update(conditional_params)
-
-        quantile_ranges = (
-            params.get("quantile_ranges") if params.get("quantile_ranges") else {}
-        )
-        quantiles = (
-            quantile_ranges.get("quantiles") if quantile_ranges.get("quantiles") else []
-        )
-        value_ranges = (
-            quantile_ranges.get("value_ranges")
-            if quantile_ranges.get("value_ranges")
-            else []
-        )
-
-        table_header_row = [
-            {"schema": {"type": "string"}, "value": "Quantile"},
-            {"schema": {"type": "string"}, "value": "Min Value"},
-            {"schema": {"type": "string"}, "value": "Max Value"},
+        header_row = [
+            RendererTableValue(
+                schema=RendererSchema(type=RendererValueType.STRING), value="Quantile"
+            ),
+            RendererTableValue(
+                schema=RendererSchema(type=RendererValueType.STRING), value="Min Value"
+            ),
+            RendererTableValue(
+                schema=RendererSchema(type=RendererValueType.STRING), value="Max Value"
+            ),
         ]
-        table_rows = []
 
+        renderer_configuration.header_row = header_row
+
+        table = []
         quantile_strings = {0.25: "Q1", 0.75: "Q3", 0.50: "Median"}
-
         for quantile, value_range in zip(quantiles, value_ranges):
             quantile_string = quantile_strings.get(quantile, f"{quantile:3.2f}")
-            table_rows.append(
+            value_range_lower: Union[Number, str] = (
+                value_range[0] if value_range[0] else "Any"
+            )
+            value_rage_lower_type = (
+                RendererValueType.NUMBER if value_range[0] else RendererValueType.STRING
+            )
+            value_range_upper: Union[Number, str] = (
+                value_range[1] if value_range[1] else "Any"
+            )
+            value_range_upper_type = (
+                RendererValueType.NUMBER if value_range[0] else RendererValueType.STRING
+            )
+            table.append(
                 [
-                    {
-                        "value": quantile_string,
-                        "schema": {"type": "string"},
-                    },
-                    {
-                        "value": value_range[0]
-                        if value_range[0] is not None
-                        else "Any",
-                        "schema": {
-                            "type": "number" if value_range[0] is not None else "string"
-                        },
-                    },
-                    {
-                        "value": value_range[1]
-                        if value_range[1] is not None
-                        else "Any",
-                        "schema": {
-                            "type": "number" if value_range[1] is not None else "string"
-                        },
-                    },
+                    RendererTableValue(
+                        schema=RendererSchema(type=RendererValueType.STRING),
+                        value=quantile_string,
+                    ),
+                    RendererTableValue(
+                        schema=RendererSchema(type=value_rage_lower_type),
+                        value=value_range_lower,
+                    ),
+                    RendererTableValue(
+                        schema=RendererSchema(type=value_range_upper_type),
+                        value=value_range_upper,
+                    ),
                 ]
             )
 
-        return (
-            header_template_str,
-            header_params_with_json_schema,
-            styling,
-            table_header_row,
-            table_rows,
-        )
+        renderer_configuration.table = table
+
+        return renderer_configuration
 
     @classmethod
-    @renderer(renderer_type="atomic.prescriptive.summary")
+    @renderer(renderer_type=AtomicPrescriptiveRendererType.SUMMARY)
     @render_evaluation_parameter_string
     def _prescriptive_summary(
         cls,
-        configuration=None,
-        result=None,
-        language=None,
-        runtime_configuration=None,
-        **kwargs,
-    ):
-        """
-        Rendering function that is utilized by GE Cloud Front-end
-        """
-        (
-            header_template_str,
-            header_params_with_json_schema,
-            _,
-            table_header_row,
-            table_rows,
-        ) = cls._atomic_prescriptive_template(
-            configuration, result, language, runtime_configuration, **kwargs
+        configuration: Optional[ExpectationConfiguration] = None,
+        result: Optional[ExpectationValidationResult] = None,
+        runtime_configuration: Optional[dict] = None,
+    ) -> RenderedAtomicContent:
+        renderer_configuration: RendererConfiguration = RendererConfiguration(
+            configuration=configuration,
+            result=result,
+            runtime_configuration=runtime_configuration,
         )
+        renderer_configuration = cls._prescriptive_template(
+            renderer_configuration=renderer_configuration
+        )
+        header_row = [value.dict() for value in renderer_configuration.header_row]
+        table = []
+        for row in renderer_configuration.table:
+            table.append([value.dict() for value in row])
         value_obj = renderedAtomicValueSchema.load(
             {
                 "header": {
                     "schema": {"type": "StringValueType"},
                     "value": {
-                        "template": header_template_str,
-                        "params": header_params_with_json_schema,
+                        "template": renderer_configuration.template_str,
+                        "params": renderer_configuration.params.dict(),
                     },
                 },
-                "header_row": table_header_row,
-                "table": table_rows,
+                "header_row": header_row,
+                "table": table,
+                "meta_notes": renderer_configuration.meta_notes,
                 "schema": {"type": "TableType"},
             }
         )
-        rendered = RenderedAtomicContent(
-            name="atomic.prescriptive.summary", value=value_obj, value_type="TableType"
+        return RenderedAtomicContent(
+            name=AtomicPrescriptiveRendererType.SUMMARY,
+            value=value_obj,
+            value_type="TableType",
         )
-        return rendered
 
     @classmethod
-    @renderer(renderer_type="renderer.prescriptive")
+    @renderer(renderer_type=LegacyRendererType.PRESCRIPTIVE)
     @render_evaluation_parameter_string
     def _prescriptive_renderer(
         cls,
-        configuration=None,
-        result=None,
-        language=None,
-        runtime_configuration=None,
+        configuration: Optional[ExpectationConfiguration] = None,
+        result: Optional[ExpectationValidationResult] = None,
+        runtime_configuration: Optional[dict] = None,
         **kwargs,
     ):
         runtime_configuration = runtime_configuration or {}
-        include_column_name = runtime_configuration.get("include_column_name", True)
         include_column_name = (
-            include_column_name if include_column_name is not None else True
+            False if runtime_configuration.get("include_column_name") is False else True
         )
-        styling = runtime_configuration.get("styling")
+        _ = runtime_configuration.get("styling")
         params = substitute_none_for_missing(
             configuration["kwargs"],
             ["column", "quantile_ranges", "row_condition", "condition_parser"],
@@ -509,13 +500,12 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
         return [expectation_string_obj, quantile_range_table]
 
     @classmethod
-    @renderer(renderer_type="renderer.diagnostic.observed_value")
+    @renderer(renderer_type=LegacyDiagnosticRendererType.OBSERVED_VALUE)
     def _diagnostic_observed_value_renderer(
         cls,
-        configuration=None,
-        result=None,
-        language=None,
-        runtime_configuration=None,
+        configuration: Optional[ExpectationConfiguration] = None,
+        result: Optional[ExpectationValidationResult] = None,
+        runtime_configuration: Optional[dict] = None,
         **kwargs,
     ):
         if result.result is None or result.result.get("observed_value") is None:
@@ -554,76 +544,73 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
     @classmethod
     def _atomic_diagnostic_observed_value_template(
         cls,
-        configuration=None,
-        result=None,
-        language=None,
-        runtime_configuration=None,
-        **kwargs,
+        renderer_configuration: RendererConfiguration,
     ):
-        template_string = None
-        params_with_json_schema = None
-        table_header_row = None
-        table_rows = None
+        if (
+            renderer_configuration.result.result is None
+            or renderer_configuration.result.result.get("observed_value") is None
+        ):
+            renderer_configuration.template_str = "--"
+            return renderer_configuration
 
-        if result.result is None or result.result.get("observed_value") is None:
-            template_string = "--"
-            params_with_json_schema = {}
-            return (
-                template_string,
-                params_with_json_schema,
-                table_header_row,
-                table_rows,
-            )
+        quantiles = renderer_configuration.result.result.get("observed_value", {}).get(
+            "quantiles", []
+        )
+        value_ranges = renderer_configuration.result.result.get(
+            "observed_value", {}
+        ).get("values", [])
 
-        quantiles = result.result.get("observed_value", {}).get("quantiles", [])
-        value_ranges = result.result.get("observed_value", {}).get("values", [])
-
-        table_header_row = [
-            {"schema": {"type": "string"}, "value": "Quantile"},
-            {"schema": {"type": "string"}, "value": "Value"},
+        header_row = [
+            RendererTableValue(
+                schema=RendererSchema(type=RendererValueType.STRING), value="Quantile"
+            ),
+            RendererTableValue(
+                schema=RendererSchema(type=RendererValueType.STRING), value="Value"
+            ),
         ]
-        table_rows = []
 
+        table = []
         quantile_strings = {0.25: "Q1", 0.75: "Q3", 0.50: "Median"}
-
         for idx, quantile in enumerate(quantiles):
-            quantile_string = quantile_strings.get(quantile)
-            table_rows.append(
+            quantile_string = quantile_strings.get(quantile) or f"{quantile:3.2f}"
+            table.append(
                 [
-                    {
-                        "value": quantile_string
-                        if quantile_string
-                        else f"{quantile:3.2f}",
-                        "schema": {"type": "string"},
-                    },
-                    {"value": value_ranges[idx], "schema": {"type": "number"}},
+                    RendererTableValue(
+                        schema=RendererSchema(type=RendererValueType.STRING),
+                        value=quantile_string,
+                    ),
+                    RendererTableValue(
+                        schema=RendererSchema(type=RendererValueType.NUMBER),
+                        value=value_ranges[idx],
+                    ),
                 ]
             )
 
-        return template_string, params_with_json_schema, table_header_row, table_rows
+        renderer_configuration.header_row = header_row
+        renderer_configuration.table = table
+
+        return renderer_configuration
 
     @classmethod
-    @renderer(renderer_type="atomic.diagnostic.observed_value")
+    @renderer(renderer_type=AtomicDiagnosticRendererType.OBSERVED_VALUE)
     def _atomic_diagnostic_observed_value(
         cls,
-        configuration=None,
-        result=None,
-        language=None,
-        runtime_configuration=None,
-        **kwargs,
+        configuration: Optional[ExpectationConfiguration] = None,
+        result: Optional[ExpectationValidationResult] = None,
+        runtime_configuration: Optional[dict] = None,
     ):
-        (
-            template_string,
-            params_with_json_schema,
-            table_header_row,
-            table_rows,
-        ) = cls._atomic_diagnostic_observed_value_template(
-            configuration, result, language, runtime_configuration, **kwargs
+        renderer_configuration: RendererConfiguration = RendererConfiguration(
+            configuration=configuration,
+            result=result,
+            runtime_configuration=runtime_configuration,
         )
-        if template_string is not None:
+        renderer_configuration = cls._atomic_diagnostic_observed_value_template(
+            renderer_configuration=renderer_configuration,
+        )
+        if renderer_configuration.template_str:
             value_obj = renderedAtomicValueSchema.load(
                 {
-                    "template": template_string,
+                    "template": renderer_configuration.template_str,
                     "params": {},
                     "schema": {"type": "StringValueType"},
                 }
@@ -634,27 +621,30 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
                 value_type="StringValueType",
             )
         else:
+            header_row = [value.dict() for value in renderer_configuration.header_row]
+            table = []
+            for row in renderer_configuration.table:
+                table.append([value.dict() for value in row])
             value_obj = renderedAtomicValueSchema.load(
                 {
-                    "header_row": table_header_row,
-                    "table": table_rows,
+                    "header_row": header_row,
+                    "table": table,
                     "schema": {"type": "TableType"},
                 }
             )
             return RenderedAtomicContent(
-                name="atomic.diagnostic.observed_value",
+                name=AtomicDiagnosticRendererType.OBSERVED_VALUE,
                 value=value_obj,
                 value_type="TableType",
             )
 
     @classmethod
-    @renderer(renderer_type="renderer.descriptive.quantile_table")
+    @renderer(renderer_type=LegacyDescriptiveRendererType.QUANTILE_TABLE)
     def _descriptive_quantile_table_renderer(
         cls,
-        configuration=None,
-        result=None,
-        language=None,
-        runtime_configuration=None,
+        configuration: Optional[ExpectationConfiguration] = None,
+        result: Optional[ExpectationValidationResult] = None,
+        runtime_configuration: Optional[dict] = None,
         **kwargs,
     ):
         assert result, "Must pass in result."
@@ -709,22 +699,26 @@ class ExpectColumnQuantileValuesToBeBetween(ColumnExpectation):
         configuration: Optional[ExpectationConfiguration] = None,
         execution_engine: Optional[ExecutionEngine] = None,
         runtime_configuration: Optional[dict] = None,
-    ):
-        all_dependencies = super().get_validation_dependencies(
-            configuration, execution_engine, runtime_configuration
+    ) -> ValidationDependencies:
+        validation_dependencies: ValidationDependencies = (
+            super().get_validation_dependencies(
+                configuration, execution_engine, runtime_configuration
+            )
         )
         # column.quantile_values expects a "quantiles" key
-        all_dependencies["metrics"]["column.quantile_values"].metric_value_kwargs[
+        validation_dependencies.get_metric_configuration(
+            metric_name="column.quantile_values"
+        ).metric_value_kwargs["quantiles"] = configuration.kwargs["quantile_ranges"][
             "quantiles"
-        ] = configuration.kwargs["quantile_ranges"]["quantiles"]
-        return all_dependencies
+        ]
+        return validation_dependencies
 
     def _validate(
         self,
         configuration: ExpectationConfiguration,
         metrics: Dict,
-        runtime_configuration: dict = None,
-        execution_engine: ExecutionEngine = None,
+        runtime_configuration: Optional[dict] = None,
+        execution_engine: Optional[ExecutionEngine] = None,
     ):
         quantile_vals = metrics.get("column.quantile_values")
         quantile_ranges = configuration.kwargs.get("quantile_ranges")
