@@ -1,16 +1,26 @@
-from typing import List, Optional
+from typing import TYPE_CHECKING, List, Optional, Union
 
-from great_expectations.core.expectation_configuration import ExpectationConfiguration
+from great_expectations.core import (
+    ExpectationConfiguration,  # noqa: TCH001
+    ExpectationValidationResult,  # noqa: TCH001
+)
+from great_expectations.core._docs_decorators import public_api
 from great_expectations.expectations.expectation import (
     ColumnMapExpectation,
     InvalidExpectationConfigurationError,
 )
-from great_expectations.render.renderer.renderer import renderer
-from great_expectations.render.types import (
+from great_expectations.render import (
+    LegacyDescriptiveRendererType,
+    LegacyRendererType,
     RenderedBulletListContent,
     RenderedStringTemplateContent,
     ValueListContent,
 )
+from great_expectations.render.renderer.renderer import renderer
+from great_expectations.render.renderer_configuration import (
+    RendererConfiguration,
+    RendererValueType,
+)
 from great_expectations.render.util import (
     num_to_str,
     parse_row_condition_string_pandas_engine,
@@ -33,11 +43,13 @@ try:
     import sqlalchemy as sa  # noqa: F401
 except ImportError:
     pass
-from great_expectations.expectations.util import (
-    add_values_with_json_schema_from_list_in_params,
+from great_expectations.expectations.expectation import (
     render_evaluation_parameter_string,
 )
 
+if TYPE_CHECKING:
+    from great_expectations.render.renderer_configuration import AddParamArgs
+
 
 class ExpectColumnValuesToBeInSet(ColumnMapExpectation):
     """Expect each column value to be in a given set.
@@ -47,24 +59,23 @@ class ExpectColumnValuesToBeInSet(ColumnMapExpectation):
 
         # my_df.my_col = [1,2,2,3,3,3]
         >>> my_df.expect_column_values_to_be_in_set(
-            "my_col",
-            [2,3]
-        )
+                "my_col",
+                [2,3]
+            )
         {
-          "success": false
-          "result": {
-            "unexpected_count": 1
-            "unexpected_percent": 16.66666666666666666,
-            "unexpected_percent_nonmissing": 16.66666666666666666,
-            "partial_unexpected_list": [
-              1
-            ],
-          },
+            "success": false
+            "result": {
+                "unexpected_count": 1
+                "unexpected_percent": 16.66666666666666666,
+                "unexpected_percent_nonmissing": 16.66666666666666666,
+                "partial_unexpected_list": [
+                    1
+                ],
+            },
         }
 
     expect_column_values_to_be_in_set is a \
-    :func:`column_map_expectation <great_expectations.execution_engine.execution_engine.MetaExecutionEngine
-    .column_map_expectation>`.
+    [Column Map Expectation](https://docs.greatexpectations.io/docs/guides/expectations/creating_custom_expectations/how_to_create_custom_column_map_expectations).
 
     Args:
         column (str): \
@@ -74,36 +85,31 @@ class ExpectColumnValuesToBeInSet(ColumnMapExpectation):
 
     Keyword Args:
         mostly (None or a float between 0 and 1): \
-            Return `"success": True` if at least mostly fraction of values match the expectation. \
-            For more detail, see :ref:`mostly`.
+            Successful if at least mostly fraction of values match the expectation. \
+            For more detail, see [mostly](https://docs.greatexpectations.io/docs/reference/expectations/standard_arguments/#mostly).
         parse_strings_as_datetimes (boolean or None) : If True values provided in value_set will be parsed as \
             datetimes before making comparisons.
 
     Other Parameters:
         result_format (str or None): \
-            Which output mode to use: `BOOLEAN_ONLY`, `BASIC`, `COMPLETE`, or `SUMMARY`.
-            For more detail, see :ref:`result_format <result_format>`.
+            Which output mode to use: BOOLEAN_ONLY, BASIC, COMPLETE, or SUMMARY. \
+            For more detail, see [result_format](https://docs.greatexpectations.io/docs/reference/expectations/result_format).
         include_config (boolean): \
-            If True, then include the expectation config as part of the result object. \
-            For more detail, see :ref:`include_config`.
+            If True, then include the expectation config as part of the result object.
         catch_exceptions (boolean or None): \
             If True, then catch exceptions and include them as part of the result object. \
-            For more detail, see :ref:`catch_exceptions`.
+            For more detail, see [catch_exceptions](https://docs.greatexpectations.io/docs/reference/expectations/standard_arguments/#catch_exceptions).
         meta (dict or None): \
             A JSON-serializable dictionary (nesting allowed) that will be included in the output without \
-            modification. For more detail, see :ref:`meta`.
+            modification. For more detail, see [meta](https://docs.greatexpectations.io/docs/reference/expectations/standard_arguments/#meta).
 
     Returns:
-        An ExpectationSuiteValidationResult
+        An [ExpectationSuiteValidationResult](https://docs.greatexpectations.io/docs/terms/validation_result)
 
-        Exact fields vary depending on the values passed to :ref:`result_format <result_format>` and
-        :ref:`include_config`, :ref:`catch_exceptions`, and :ref:`meta`.
+        Exact fields vary depending on the values passed to result_format, include_config, catch_exceptions, and meta.
 
     See Also:
-        :func:`expect_column_values_to_not_be_in_set \
-        <great_expectations.execution_engine.execution_engine.ExecutionEngine
-        .expect_column_values_to_not_be_in_set>`
-
+        [expect_column_values_to_not_be_in_set](https://greatexpectations.io/expectations/expect_column_values_to_not_be_in_set)
     """
 
     # This dictionary contains metadata for display in the public gallery
@@ -183,120 +189,71 @@ class ExpectColumnValuesToBeInSet(ColumnMapExpectation):
     }
 
     @classmethod
-    def _atomic_prescriptive_template(
+    def _prescriptive_template(
         cls,
-        configuration=None,
-        result=None,
-        language=None,
-        runtime_configuration=None,
-        **kwargs,
-    ):
-        runtime_configuration = runtime_configuration or {}
-        include_column_name = runtime_configuration.get("include_column_name", True)
-        include_column_name = (
-            include_column_name if include_column_name is not None else True
+        renderer_configuration: RendererConfiguration,
+    ) -> RendererConfiguration:
+        add_param_args: AddParamArgs = (
+            ("column", RendererValueType.STRING),
+            ("value_set", RendererValueType.ARRAY),
+            ("mostly", RendererValueType.NUMBER),
+            ("parse_strings_as_datetimes", RendererValueType.BOOLEAN),
         )
-        styling = runtime_configuration.get("styling")
-        params = substitute_none_for_missing(
-            configuration.kwargs,
-            [
-                "column",
-                "value_set",
-                "mostly",
-                "parse_strings_as_datetimes",
-                "row_condition",
-                "condition_parser",
-            ],
-        )
-        params_with_json_schema = {
-            "column": {"schema": {"type": "string"}, "value": params.get("column")},
-            "value_set": {
-                "schema": {"type": "array"},
-                "value": params.get("value_set"),
-            },
-            "mostly": {"schema": {"type": "number"}, "value": params.get("mostly")},
-            "mostly_pct": {
-                "schema": {"type": "string"},
-                "value": params.get("mostly_pct"),
-            },
-            "parse_strings_as_datetimes": {
-                "schema": {"type": "boolean"},
-                "value": params.get("parse_strings_as_datetimes"),
-            },
-            "row_condition": {
-                "schema": {"type": "string"},
-                "value": params.get("row_condition"),
-            },
-            "condition_parser": {
-                "schema": {"type": "string"},
-                "value": params.get("condition_parser"),
-            },
-        }
+        for name, param_type in add_param_args:
+            renderer_configuration.add_param(name=name, param_type=param_type)
 
-        if params["value_set"] is None or len(params["value_set"]) == 0:
-            values_string = "[ ]"
-        else:
-            for i, v in enumerate(params["value_set"]):
-                params[f"v__{str(i)}"] = v
+        params = renderer_configuration.params
+        template_str = ""
 
-            values_string = " ".join(
-                [f"$v__{str(i)}" for i, v in enumerate(params["value_set"])]
+        if params.value_set:
+            array_param_name = "value_set"
+            param_prefix = "v__"
+            renderer_configuration = cls._add_array_params(
+                array_param_name=array_param_name,
+                param_prefix=param_prefix,
+                renderer_configuration=renderer_configuration,
             )
-
-        template_str = f"values must belong to this set: {values_string}"
-
-        if params["mostly"] is not None and params["mostly"] < 1.0:
-            params_with_json_schema["mostly_pct"]["value"] = num_to_str(
-                params["mostly"] * 100, precision=15, no_scientific=True
+            value_set_str: str = cls._get_array_string(
+                array_param_name=array_param_name,
+                param_prefix=param_prefix,
+                renderer_configuration=renderer_configuration,
             )
-            # params["mostly_pct"] = "{:.14f}".format(params["mostly"]*100).rstrip("0").rstrip(".")
-            template_str += ", at least $mostly_pct % of the time."
-        else:
-            template_str += "."
+            template_str += f"values must belong to this set: {value_set_str}"
 
-        if params.get("parse_strings_as_datetimes"):
-            template_str += " Values should be parsed as datetimes."
+            if params.mostly and params.mostly.value < 1.0:
+                renderer_configuration = cls._add_mostly_pct_param(
+                    renderer_configuration=renderer_configuration
+                )
+                template_str += ", at least $mostly_pct % of the time."
+            else:
+                template_str += "."
 
-        if include_column_name:
+            if params.parse_strings_as_datetimes:
+                template_str += " Values should be parsed as datetimes."
+
+        if renderer_configuration.include_column_name:
             template_str = f"$column {template_str}"
 
-        if params["row_condition"] is not None:
-            (
-                conditional_template_str,
-                conditional_params,
-            ) = parse_row_condition_string_pandas_engine(
-                params["row_condition"], with_schema=True
-            )
-            template_str = f"{conditional_template_str}, then {template_str}"
-            params_with_json_schema.update(conditional_params)
+        renderer_configuration.template_str = template_str
 
-        params_with_json_schema = add_values_with_json_schema_from_list_in_params(
-            params=params,
-            params_with_json_schema=params_with_json_schema,
-            param_key_with_list="value_set",
-        )
-
-        return (template_str, params_with_json_schema, styling)
+        return renderer_configuration
 
     @classmethod
-    @renderer(renderer_type="renderer.prescriptive")
+    @renderer(renderer_type=LegacyRendererType.PRESCRIPTIVE)
     @render_evaluation_parameter_string
     def _prescriptive_renderer(
         cls,
-        configuration=None,
-        result=None,
-        language=None,
-        runtime_configuration=None,
-        **kwargs,
-    ):
-        runtime_configuration = runtime_configuration or {}
-        include_column_name = runtime_configuration.get("include_column_name", True)
-        include_column_name = (
-            include_column_name if include_column_name is not None else True
+        configuration: Optional[ExpectationConfiguration] = None,
+        result: Optional[ExpectationValidationResult] = None,
+        runtime_configuration: Optional[dict] = None,
+    ) -> List[RenderedStringTemplateContent]:
+        renderer_configuration: RendererConfiguration = RendererConfiguration(
+            configuration=configuration,
+            result=result,
+            runtime_configuration=runtime_configuration,
         )
-        styling = runtime_configuration.get("styling")
         params = substitute_none_for_missing(
-            configuration.kwargs,
+            renderer_configuration.kwargs,
             [
                 "column",
                 "value_set",
@@ -331,7 +288,7 @@ class ExpectColumnValuesToBeInSet(ColumnMapExpectation):
         if params.get("parse_strings_as_datetimes"):
             template_str += " Values should be parsed as datetimes."
 
-        if include_column_name:
+        if renderer_configuration.include_column_name:
             template_str = f"$column {template_str}"
 
         if params["row_condition"] is not None:
@@ -342,6 +299,10 @@ class ExpectColumnValuesToBeInSet(ColumnMapExpectation):
             template_str = f"{conditional_template_str}, then {template_str}"
             params.update(conditional_params)
 
+        styling = (
+            runtime_configuration.get("styling", {}) if runtime_configuration else {}
+        )
+
         return [
             RenderedStringTemplateContent(
                 **{
@@ -356,15 +317,13 @@ class ExpectColumnValuesToBeInSet(ColumnMapExpectation):
         ]
 
     @classmethod
-    @renderer(renderer_type="renderer.descriptive.example_values_block")
+    @renderer(renderer_type=LegacyDescriptiveRendererType.EXAMPLE_VALUES_BLOCK)
     def _descriptive_example_values_block_renderer(
         cls,
-        configuration=None,
-        result=None,
-        language=None,
-        runtime_configuration=None,
-        **kwargs,
-    ):
+        configuration: Optional[ExpectationConfiguration] = None,
+        result: Optional[ExpectationValidationResult] = None,
+        runtime_configuration: Optional[dict] = None,
+    ) -> Optional[Union[RenderedBulletListContent, ValueListContent]]:
         assert result, "Must pass in result."
         if "partial_unexpected_counts" in result.result:
             partial_unexpected_counts = result.result["partial_unexpected_counts"]
@@ -372,7 +331,7 @@ class ExpectColumnValuesToBeInSet(ColumnMapExpectation):
         elif "partial_unexpected_list" in result.result:
             values = [str(item) for item in result.result["partial_unexpected_list"]]
         else:
-            return
+            return None
 
         classes = ["col-3", "mt-1", "pl-1", "pr-1"]
 
@@ -422,11 +381,36 @@ class ExpectColumnValuesToBeInSet(ColumnMapExpectation):
 
         return new_block
 
+    @public_api
     def validate_configuration(
-        self, configuration: Optional[ExpectationConfiguration]
+        self, configuration: Optional[ExpectationConfiguration] = None
     ) -> None:
+        """Validates the configuration of an Expectation.
+
+        For `expect_column_values_to_be_in_set` it is required that:
+
+        - `value_set` has been provided.
+
+        - `value_set` is one of the following types: `list`, `set`, or `dict`
+
+        - If `value_set` is a `dict`, it is assumed to be an Evaluation Parameter, and therefore the
+          dictionary keys must be `$PARAMETER`.
+
+        The configuration will also be validated using each of the `validate_configuration` methods in its Expectation
+        superclass hierarchy.
+
+        Args:
+            configuration: An `ExpectationConfiguration` to validate. If no configuration is provided, it will be pulled
+                           from the configuration attribute of the Expectation instance.
+
+        Raises:
+            InvalidExpectationConfigurationError: The configuration does not contain the values required by the
+                                                  Expectation.
+        """
         super().validate_configuration(configuration)
-        # supports extensibility by allowing value_set to not be provided in config but captured via child-class default_kwarg_values, e.g. parameterized expectations
+        configuration = configuration or self.configuration
+        # supports extensibility by allowing value_set to not be provided in config but captured via child-class
+        # default_kwarg_values, e.g. parameterized expectations
         value_set = configuration.kwargs.get(
             "value_set"
         ) or self.default_kwarg_values.get("value_set")
