@@ -2,11 +2,9 @@ from .meta_metric_provider import (  # isort:skip
     MetaMetricProvider,
     DeprecatedMetaMetricProvider,
 )
-from .column_aggregate_metric_provider import (
-    ColumnMetricProvider,  # This class name is being deprecated (use "ColumnAggregateMetricProvider" going forward).
-)
 from .column_aggregate_metric_provider import (
     ColumnAggregateMetricProvider,
+    ColumnMetricProvider,  # This class name is being deprecated (use "ColumnAggregateMetricProvider" going forward).
     column_aggregate_partial,
     column_aggregate_value,
 )
@@ -19,14 +17,6 @@ from .map_metric_provider import (
     column_condition_partial,
     column_function_partial,
 )
-from .metric_provider import (
-    MetricDomainTypes,
-    MetricFunctionTypes,
-    MetricPartialFunctionTypes,
-    MetricProvider,
-    metric_partial,
-    metric_value,
-)
 from .multicolumn_map_metrics import *
 from .query_metrics import *
 from .table_metrics import *
