@@ -13,7 +13,7 @@ from great_expectations.execution_engine import (
     SparkDFExecutionEngine,
     SqlAlchemyExecutionEngine,
 )
-from great_expectations.execution_engine.sqlalchemy_dialect import GESqlDialect
+from great_expectations.execution_engine.sqlalchemy_dialect import GXSqlDialect
 from great_expectations.execution_engine.util import get_approximate_percentile_disc_sql
 from great_expectations.expectations.metrics.column_aggregate_metric_provider import (
     ColumnAggregateMetricProvider,
@@ -85,10 +85,10 @@ class ColumnQuantileValues(ColumnAggregateMetricProvider):
     def _sqlalchemy(
         cls,
         execution_engine: SqlAlchemyExecutionEngine,
-        metric_domain_kwargs: Dict,
-        metric_value_kwargs: Dict,
+        metric_domain_kwargs: dict,
+        metric_value_kwargs: dict,
         metrics: Dict[str, Any],
-        runtime_configuration: Dict,
+        runtime_configuration: dict,
     ):
         (
             selectable,
@@ -104,35 +104,35 @@ class ColumnQuantileValues(ColumnAggregateMetricProvider):
         quantiles = metric_value_kwargs["quantiles"]
         allow_relative_error = metric_value_kwargs.get("allow_relative_error", False)
         table_row_count = metrics.get("table.row_count")
-        if dialect.name.lower() == GESqlDialect.MSSQL:
+        if dialect.name.lower() == GXSqlDialect.MSSQL:
             return _get_column_quantiles_mssql(
                 column=column,
                 quantiles=quantiles,
                 selectable=selectable,
                 sqlalchemy_engine=sqlalchemy_engine,
             )
-        elif dialect.name.lower() == GESqlDialect.BIGQUERY:
+        elif dialect.name.lower() == GXSqlDialect.BIGQUERY:
             return _get_column_quantiles_bigquery(
                 column=column,
                 quantiles=quantiles,
                 selectable=selectable,
                 sqlalchemy_engine=sqlalchemy_engine,
             )
-        elif dialect.name.lower() == GESqlDialect.MYSQL:
+        elif dialect.name.lower() == GXSqlDialect.MYSQL:
             return _get_column_quantiles_mysql(
                 column=column,
                 quantiles=quantiles,
                 selectable=selectable,
                 sqlalchemy_engine=sqlalchemy_engine,
             )
-        elif dialect.name.lower() == GESqlDialect.TRINO:
+        elif dialect.name.lower() == GXSqlDialect.TRINO:
             return _get_column_quantiles_trino(
                 column=column,
                 quantiles=quantiles,
                 selectable=selectable,
                 sqlalchemy_engine=sqlalchemy_engine,
             )
-        elif dialect.name.lower() == GESqlDialect.SNOWFLAKE:
+        elif dialect.name.lower() == GXSqlDialect.SNOWFLAKE:
             # NOTE: 20201216 - JPC - snowflake has a representation/precision limitation
             # in its percentile_disc implementation that causes an error when we do
             # not round. It is unclear to me *how* the call to round affects the behavior --
@@ -149,7 +149,7 @@ class ColumnQuantileValues(ColumnAggregateMetricProvider):
                 selectable=selectable,
                 sqlalchemy_engine=sqlalchemy_engine,
             )
-        elif dialect.name.lower() == GESqlDialect.SQLITE:
+        elif dialect.name.lower() == GXSqlDialect.SQLITE:
             return _get_column_quantiles_sqlite(
                 column=column,
                 quantiles=quantiles,
@@ -157,7 +157,7 @@ class ColumnQuantileValues(ColumnAggregateMetricProvider):
                 sqlalchemy_engine=sqlalchemy_engine,
                 table_row_count=table_row_count,
             )
-        elif dialect.name.lower() == GESqlDialect.AWSATHENA:
+        elif dialect.name.lower() == GXSqlDialect.AWSATHENA:
             return _get_column_quantiles_athena(
                 column=column,
                 quantiles=quantiles,
@@ -178,10 +178,10 @@ class ColumnQuantileValues(ColumnAggregateMetricProvider):
     def _spark(
         cls,
         execution_engine: SqlAlchemyExecutionEngine,
-        metric_domain_kwargs: Dict,
-        metric_value_kwargs: Dict,
+        metric_domain_kwargs: dict,
+        metric_value_kwargs: dict,
         metrics: Dict[str, Any],
-        runtime_configuration: Dict,
+        runtime_configuration: dict,
     ):
         (
             df,
