@@ -1,14 +1,17 @@
 import logging
 from typing import Optional
 
-from great_expectations.core import ExpectationConfiguration
+from great_expectations.core import ExpectationConfiguration  # noqa: TCH001
+from great_expectations.core.metric_function_types import (
+    SummarizationMetricNameSuffixes,
+)
 from great_expectations.execution_engine import (
     ExecutionEngine,
     PandasExecutionEngine,
     SparkDFExecutionEngine,
     SqlAlchemyExecutionEngine,
 )
-from great_expectations.execution_engine.sqlalchemy_dialect import GESqlDialect
+from great_expectations.execution_engine.sqlalchemy_dialect import GXSqlDialect
 from great_expectations.expectations.metrics.column_aggregate_metric_provider import (
     ColumnAggregateMetricProvider,
     column_aggregate_partial,
@@ -41,11 +44,13 @@ class ColumnStandardDeviation(ColumnAggregateMetricProvider):
     @column_aggregate_partial(engine=SqlAlchemyExecutionEngine)
     def _sqlalchemy(cls, column, _dialect, _metrics, **kwargs):
         """SqlAlchemy Standard Deviation implementation"""
-        if _dialect.name.lower() == GESqlDialect.MSSQL:
+        if _dialect.name.lower() == GXSqlDialect.MSSQL:
             standard_deviation = sa.func.stdev(column)
-        elif _dialect.name.lower() == GESqlDialect.SQLITE:
+        elif _dialect.name.lower() == GXSqlDialect.SQLITE:
             mean = _metrics["column.mean"]
-            nonnull_row_count = _metrics["column_values.null.unexpected_count"]
+            nonnull_row_count = _metrics[
+                f"column_values.null.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}"
+            ]
             standard_deviation = sa.func.sqrt(
                 sa.func.sum((1.0 * column - mean) * (1.0 * column - mean))
                 / ((1.0 * nonnull_row_count) - 1.0)
@@ -82,13 +87,13 @@ class ColumnStandardDeviation(ColumnAggregateMetricProvider):
                 metric_name="column.mean",
                 metric_domain_kwargs=metric.metric_domain_kwargs,
                 metric_value_kwargs=None,
-                metric_dependencies=None,
             )
-            dependencies["column_values.null.unexpected_count"] = MetricConfiguration(
-                metric_name="column_values.null.unexpected_count",
+            dependencies[
+                f"column_values.null.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}"
+            ] = MetricConfiguration(
+                metric_name=f"column_values.null.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}",
                 metric_domain_kwargs=metric.metric_domain_kwargs,
                 metric_value_kwargs=None,
-                metric_dependencies=None,
             )
 
         return dependencies
