@@ -23,9 +23,9 @@ class ColumnValuesLengthMin(ColumnAggregateMetricProvider):
     @column_aggregate_partial(
         engine=SqlAlchemyExecutionEngine, filter_column_isnull=True
     )
-    def _sqlalchemy(cls, column, **kwargs: dict):  # type: ignore[no-untyped-def]
+    def _sqlalchemy(cls, column, **kwargs: dict):
         return sa.func.min(sa.func.length(column))
 
     @column_aggregate_partial(engine=SparkDFExecutionEngine, filter_column_isnull=True)
-    def _spark(cls, column, **kwargs: dict):  # type: ignore[no-untyped-def]
+    def _spark(cls, column, **kwargs: dict):
         return F.min(F.length(column))
