@@ -1,6 +1,9 @@
 from typing import Optional
 
-from great_expectations.core import ExpectationConfiguration
+from great_expectations.core import ExpectationConfiguration  # noqa: TCH001
+from great_expectations.core.metric_function_types import (
+    SummarizationMetricNameSuffixes,
+)
 from great_expectations.execution_engine import (
     ExecutionEngine,
     PandasExecutionEngine,
@@ -28,7 +31,7 @@ class ColumnValuesNull(ColumnMapMetricProvider):
 
     @column_condition_partial(engine=SqlAlchemyExecutionEngine)
     def _sqlalchemy(cls, column, **kwargs):
-        return column == None
+        return column == None  # noqa: E711
 
     @column_condition_partial(engine=SparkDFExecutionEngine)
     def _spark(cls, column, **kwargs):
@@ -42,15 +45,21 @@ class ColumnValuesNullCount(MetricProvider):
 
     @metric_value(engine=PandasExecutionEngine)
     def _pandas(*, metrics, **kwargs):
-        return metrics["column_values.nonnull.unexpected_count"]
+        return metrics[
+            f"column_values.nonnull.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}"
+        ]
 
     @metric_value(engine=SqlAlchemyExecutionEngine)
     def _sqlalchemy(*, metrics, **kwargs):
-        return metrics["column_values.nonnull.unexpected_count"]
+        return metrics[
+            f"column_values.nonnull.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}"
+        ]
 
     @metric_value(engine=SparkDFExecutionEngine)
     def _spark(*, metrics, **kwargs):
-        return metrics["column_values.nonnull.unexpected_count"]
+        return metrics[
+            f"column_values.nonnull.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}"
+        ]
 
     @classmethod
     def _get_evaluation_dependencies(
@@ -66,8 +75,10 @@ class ColumnValuesNullCount(MetricProvider):
             execution_engine=execution_engine,
             runtime_configuration=runtime_configuration,
         )
-        dependencies["column_values.nonnull.unexpected_count"] = MetricConfiguration(
-            metric_name="column_values.nonnull.unexpected_count",
+        dependencies[
+            f"column_values.nonnull.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}"
+        ] = MetricConfiguration(
+            metric_name=f"column_values.nonnull.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}",
             metric_domain_kwargs=metric.metric_domain_kwargs,
         )
         return dependencies
