@@ -2,11 +2,17 @@ import pathlib
 
 from great_expectations.experimental.datasources.pandas_datasource import (
     PandasDatasource,
+    _PandasDatasource,
+)
+from great_expectations.experimental.datasources.pandas_filesystem_datasource import (
+    PandasFilesystemDatasource,
 )
 from great_expectations.experimental.datasources.postgres_datasource import (
     PostgresDatasource,
 )
-from great_expectations.experimental.datasources.spark_datasource import SparkDatasource
+from great_expectations.experimental.datasources.spark_datasource import (
+    SparkFilesystemDatasource,
+)
 from great_expectations.experimental.datasources.sqlite_datasource import (
     SqliteDatasource,
 )
