@@ -1,11 +1,14 @@
 from __future__ import annotations
 
 import dataclasses
+import functools
 import logging
+import re
 from pprint import pformat as pf
 from typing import (
     TYPE_CHECKING,
     Any,
+    Callable,
     ClassVar,
     Dict,
     Generic,
@@ -24,7 +27,6 @@ from pydantic import Field, StrictBool, StrictInt, root_validator, validate_argu
 from pydantic import dataclasses as pydantic_dc
 from typing_extensions import TypeAlias, TypeGuard
 
-import great_expectations.exceptions as ge_exceptions
 from great_expectations.core.id_dict import BatchSpec  # noqa: TCH001
 from great_expectations.experimental.datasources.constants import _FIELDS_ALWAYS_SET
 from great_expectations.experimental.datasources.experimental_base_model import (
@@ -32,14 +34,18 @@ from great_expectations.experimental.datasources.experimental_base_model import
 )
 from great_expectations.experimental.datasources.metadatasource import MetaDatasource
 from great_expectations.experimental.datasources.sources import _SourceFactories
-from great_expectations.validator.metric_configuration import MetricConfiguration
+from great_expectations.validator.metrics_calculator import MetricsCalculator
 
 logger = logging.getLogger(__name__)
 
 if TYPE_CHECKING:
     # TODO: When the Batch class is moved out of the experimental directory, we should try to import the annotations
     #       from core.batch so we no longer need to call Batch.update_forward_refs() before instantiation.
-    from great_expectations.core.batch import BatchData, BatchDefinition, BatchMarkers
+    from great_expectations.core.batch import (
+        BatchData,
+        BatchDefinition,
+        BatchMarkers,
+    )
 
 try:
     import pyspark
@@ -77,7 +83,7 @@ class BatchSorter:
     reverse: bool = False
 
 
-BatchSortersDefinition: TypeAlias = Union[List[BatchSorter], List[str]]
+BatchSortersDefinition: TypeAlias = List[Union[BatchSorter, str, dict]]
 
 
 def _is_batch_sorter_list(
@@ -94,11 +100,11 @@ def _is_str_sorter_list(sorters: BatchSortersDefinition) -> TypeGuard[list[str]]
     return False
 
 
-def _batch_sorter_from_list(sorters: BatchSortersDefinition) -> List[BatchSorter]:
+def _batch_sorter_from_list(sorters: BatchSortersDefinition) -> list[BatchSorter]:
     if _is_batch_sorter_list(sorters):
         return sorters
 
-    # mypy doesn't successfully type-narrow sorters to a List[str] here, so we use
+    # mypy doesn't successfully type-narrow sorters to a list[str] here, so we use
     # another TypeGuard. We could cast instead which may be slightly faster.
     sring_valued_sorter: str
     if _is_str_sorter_list(sorters):
@@ -124,13 +130,18 @@ def _batch_sorter_from_str(sort_key: str) -> BatchSorter:
     """
     if sort_key[0] == "-":
         return BatchSorter(key=sort_key[1:], reverse=True)
-    elif sort_key[0] == "+":
+
+    if sort_key[0] == "+":
         return BatchSorter(key=sort_key[1:], reverse=False)
-    else:
-        return BatchSorter(key=sort_key, reverse=False)
+
+    return BatchSorter(key=sort_key, reverse=False)
 
 
-class DataAsset(ExperimentalBaseModel):
+# It would be best to bind this to Datasource, but we can't now due to circular dependencies
+_DatasourceT = TypeVar("_DatasourceT")
+
+
+class DataAsset(ExperimentalBaseModel, Generic[_DatasourceT]):
     # To subclass a DataAsset one must define `type` as a Class literal explicitly on the sublass
     # as well as implementing the methods in the `Abstract Methods` section below.
     # Some examples:
@@ -139,23 +150,16 @@ class DataAsset(ExperimentalBaseModel):
     # * type: Literal["csv"] = "csv"
     name: str
     type: str
+
     order_by: List[BatchSorter] = Field(default_factory=list)
 
     # non-field private attributes
-    _datasource: Datasource = pydantic.PrivateAttr()
+    _datasource: _DatasourceT = pydantic.PrivateAttr()
 
     @property
-    def datasource(self) -> Datasource:
+    def datasource(self) -> _DatasourceT:
         return self._datasource
 
-    @datasource.setter
-    # TODO (kilo): remove setter and add custom init for DataAsset to inject datasource in constructor??
-    # This setter is non-functional: https://github.com/pydantic/pydantic/issues/3395
-    # There is some related discussion linked from that ticket which may be a workaround.
-    def datasource(self, ds: Datasource):
-        assert isinstance(ds, Datasource)
-        self._datasource = ds
-
     def test_connection(self) -> None:
         """Test the connection for the DataAsset.
 
@@ -170,10 +174,10 @@ class DataAsset(ExperimentalBaseModel):
     def batch_request_options_template(
         self,
     ) -> BatchRequestOptions:
-        """A BatchRequestOptions template for get_batch_request.
+        """A BatchRequestOptions template for build_batch_request.
 
         Returns:
-            A BatchRequestOptions dictionary with the correct shape that get_batch_request
+            A BatchRequestOptions dictionary with the correct shape that build_batch_request
             will understand. All the option values are defaulted to None.
         """
         raise NotImplementedError
@@ -185,7 +189,7 @@ class DataAsset(ExperimentalBaseModel):
 
     # End Abstract Methods
 
-    def get_batch_request(
+    def build_batch_request(
         self, options: Optional[BatchRequestOptions] = None
     ) -> BatchRequest:
         """A batch request that can be used to obtain batches for this DataAsset.
@@ -199,18 +203,8 @@ class DataAsset(ExperimentalBaseModel):
             A BatchRequest object that can be used to obtain a batch list from a Datasource by calling the
             get_batch_list_from_batch_request method.
         """
-        if options is not None and not self._valid_batch_request_options(options):
-            allowed_keys = set(self.batch_request_options_template().keys())
-            actual_keys = set(options.keys())
-            raise ge_exceptions.InvalidBatchRequestError(
-                "Batch request options should only contain keys from the following set:\n"
-                f"{allowed_keys}\nbut your specified keys contain\n"
-                f"{actual_keys.difference(allowed_keys)}\nwhich is not valid.\n"
-            )
-        return BatchRequest(
-            datasource_name=self.datasource.name,
-            data_asset_name=self.name,
-            options=options or {},
+        raise NotImplementedError(
+            """One must implement "build_batch_request" on a DataAsset subclass."""
         )
 
     def _valid_batch_request_options(self, options: BatchRequestOptions) -> bool:
@@ -224,32 +218,16 @@ class DataAsset(ExperimentalBaseModel):
         Args:
             batch_request: A batch request object to be validated.
         """
-        if not (
-            batch_request.datasource_name == self.datasource.name
-            and batch_request.data_asset_name == self.name
-            and self._valid_batch_request_options(batch_request.options)
-        ):
-            expect_batch_request_form = BatchRequest(
-                datasource_name=self.datasource.name,
-                data_asset_name=self.name,
-                options=self.batch_request_options_template(),
-            )
-            raise ge_exceptions.InvalidBatchRequestError(
-                "BatchRequest should have form:\n"
-                f"{pf(dataclasses.asdict(expect_batch_request_form))}\n"
-                f"but actually has form:\n{pf(dataclasses.asdict(batch_request))}\n"
-            )
+        raise NotImplementedError(
+            """One must implement "_validate_batch_request" on a DataAsset subclass."""
+        )
 
     # Sorter methods
-    @pydantic.validator("order_by", pre=True, each_item=True)
-    def _parse_order_by_sorter(
-        cls, v: Union[str, BatchSorter]
-    ) -> Union[BatchSorter, dict]:
-        if isinstance(v, str):
-            if not v:
-                raise ValueError("empty string")
-            return _batch_sorter_from_str(v)
-        return v
+    @pydantic.validator("order_by", pre=True)
+    def _parse_order_by_sorters(
+        cls, order_by: Optional[List[Union[BatchSorter, str, dict]]] = None
+    ) -> List[BatchSorter]:
+        return Datasource.parse_order_by_sorters(order_by=order_by)
 
     def add_sorters(self: _DataAssetT, sorters: BatchSortersDefinition) -> _DataAssetT:
         """Associates a sorter to this DataAsset
@@ -294,7 +272,9 @@ class DataAsset(ExperimentalBaseModel):
         for sorter in reversed(self.order_by):
             try:
                 batch_list.sort(
-                    key=lambda b: b.metadata[sorter.key],
+                    key=functools.cmp_to_key(
+                        _sort_batches_with_none_metadata_values(sorter.key)
+                    ),
                     reverse=sorter.reverse,
                 )
             except KeyError as e:
@@ -304,6 +284,27 @@ class DataAsset(ExperimentalBaseModel):
                 ) from e
 
 
+def _sort_batches_with_none_metadata_values(
+    key: str,
+) -> Callable[[Batch, Batch], int]:
+    def _compare_function(a: Batch, b: Batch) -> int:
+        if a.metadata[key] is not None and b.metadata[key] is not None:
+            if a.metadata[key] < b.metadata[key]:
+                return -1
+            elif a.metadata[key] > b.metadata[key]:
+                return 1
+            else:
+                return 0
+        elif a.metadata[key] is None and b.metadata[key] is None:
+            return 0
+        elif a.metadata[key] is None:  # b.metadata[key] is not None
+            return -1
+        # b.metadata[key] is None, a.metadata[key] is not None
+        return 0
+
+    return _compare_function
+
+
 # If a Datasource can have more than 1 _DataAssetT, this will need to change.
 _DataAssetT = TypeVar("_DataAssetT", bound=DataAsset)
 
@@ -335,6 +336,7 @@ class Datasource(
         "type",
         "execution_engine",
         "assets",
+        "base_directory",
     }
     # Setting this in a Datasource subclass will override the execution engine type.
     # The primary use case is to inject an execution engine for testing.
@@ -401,7 +403,7 @@ class Datasource(
 
         Args:
             batch_request: A batch request for this asset. Usually obtained by calling
-                get_batch_request on the asset.
+                build_batch_request on the asset.
 
         Returns:
             A list of batches that match the options specified in the batch request.
@@ -435,6 +437,49 @@ class Datasource(
         self.__fields_set__.update(_FIELDS_ALWAYS_SET)
         return asset
 
+    @staticmethod
+    def parse_order_by_sorters(
+        order_by: Optional[List[Union[BatchSorter, str, dict]]] = None
+    ) -> List[BatchSorter]:
+        order_by_sorters: list[BatchSorter] = []
+        if order_by:
+            for idx, sorter in enumerate(order_by):
+                if isinstance(sorter, str):
+                    if not sorter:
+                        raise ValueError(
+                            '"order_by" list cannot contain an empty string'
+                        )
+                    order_by_sorters.append(_batch_sorter_from_str(sorter))
+                elif isinstance(sorter, dict):
+                    key: Optional[Any] = sorter.get("key")
+                    reverse: Optional[Any] = sorter.get("reverse")
+                    if key and reverse:
+                        order_by_sorters.append(BatchSorter(key=key, reverse=reverse))
+                    elif key:
+                        order_by_sorters.append(BatchSorter(key=key))
+                    else:
+                        raise ValueError(
+                            '"order_by" list dict must have a key named "key"'
+                        )
+                else:
+                    order_by_sorters.append(sorter)
+        return order_by_sorters
+
+    @staticmethod
+    def parse_batching_regex_string(
+        batching_regex: Optional[Union[re.Pattern, str]] = None
+    ) -> re.Pattern:
+        pattern: re.Pattern
+        if not batching_regex:
+            pattern = re.compile(".*")
+        elif isinstance(batching_regex, str):
+            pattern = re.compile(batching_regex)
+        elif isinstance(batching_regex, re.Pattern):
+            pattern = batching_regex
+        else:
+            raise ValueError('"batching_regex" must be either re.Pattern, str, or None')
+        return pattern
+
     # Abstract Methods
     @property
     def execution_engine_type(self) -> Type[_ExecutionEngineT]:
@@ -450,7 +495,7 @@ class Datasource(
             test_assets: If assets have been passed to the Datasource, an attempt can be made to test them as well.
 
         Raises:
-            TestConnectionError
+            TestConnectionError: If the connection test fails.
         """
         raise NotImplementedError(
             """One needs to implement "test_connection" on a Datasource subclass."""
@@ -482,7 +527,7 @@ class Batch(ExperimentalBaseModel):
     datasource: Datasource
     data_asset: DataAsset
     batch_request: BatchRequest
-    data: "BatchData"
+    data: BatchData
     id: str = ""
     # metadata is any arbitrary data one wants to associate with a batch. GX will add arbitrary metadata
     # to a batch so developers may want to namespace any custom metadata they add.
@@ -490,9 +535,9 @@ class Batch(ExperimentalBaseModel):
 
     # TODO: These legacy fields are currently required. They are only used in usage stats so we
     #       should figure out a better way to anonymize and delete them.
-    batch_markers: "BatchMarkers" = Field(..., alias="legacy_batch_markers")
+    batch_markers: BatchMarkers = Field(..., alias="legacy_batch_markers")
     batch_spec: BatchSpec = Field(..., alias="legacy_batch_spec")
-    batch_definition: "BatchDefinition" = Field(..., alias="legacy_batch_definition")
+    batch_definition: BatchDefinition = Field(..., alias="legacy_batch_definition")
 
     class Config:
         allow_mutation = False
@@ -502,11 +547,14 @@ class Batch(ExperimentalBaseModel):
     def _set_id(cls, values: dict) -> dict:
         # We need a unique identifier. This will likely change as we get more input.
         options_list = []
-        for k, v in values["batch_request"].options.items():
-            options_list.append(f"{k}_{v}")
+        for key, value in values["batch_request"].options.items():
+            if key != "path":
+                options_list.append(f"{key}_{value}")
+
         values["id"] = "-".join(
             [values["datasource"].name, values["data_asset"].name, *options_list]
         )
+
         return values
 
     @classmethod
@@ -526,7 +574,7 @@ class Batch(ExperimentalBaseModel):
     @validate_arguments
     def head(
         self,
-        n_rows: Optional[StrictInt] = None,
+        n_rows: StrictInt = 5,
         fetch_all: StrictBool = False,
     ) -> HeadData:
         """Return the first n rows of this Batch.
@@ -545,29 +593,13 @@ class Batch(ExperimentalBaseModel):
             HeadData
         """
         self.data.execution_engine.batch_manager.load_batch_list(batch_list=[self])
-        metric = MetricConfiguration(
-            metric_name="table.head",
-            metric_domain_kwargs={"batch_id": self.id},
-            metric_value_kwargs={"n_rows": n_rows, "fetch_all": fetch_all},
+        metrics_calculator = MetricsCalculator(
+            execution_engine=self.data.execution_engine,
+            show_progress_bars=True,
+        )
+        table_head_df: pd.DataFrame = metrics_calculator.head(
+            n_rows=n_rows,
+            domain_kwargs={"batch_id": self.id},
+            fetch_all=fetch_all,
         )
-        table_head_metric_value: pd.DataFrame | list[
-            pyspark_sql_Row
-        ] | pyspark_sql_Row = self.data.execution_engine.resolve_metrics(
-            metrics_to_resolve=(metric,)
-        )[
-            metric.id
-        ]
-        table_head_df: pd.DataFrame
-        if isinstance(table_head_metric_value, pd.DataFrame):
-            # table_head_metric_value is a pd.DataFrame already
-            table_head_df = table_head_metric_value
-        elif isinstance(table_head_metric_value, list):
-            # convert list of pyspark.sql.Row to pd.DataFrame
-            table_head_df = pd.DataFrame(
-                [row.asDict() for row in table_head_metric_value]
-            )
-        else:
-            # otherwise convert pyspark.sql.Row to pd.DataFrame
-            table_head_df = pd.DataFrame(table_head_metric_value.asDict())
-
         return HeadData(data=table_head_df.reset_index(drop=True, inplace=False))
