@@ -1,34 +1,33 @@
 from __future__ import annotations
 
 import copy
-import itertools
-from datetime import datetime
+import dataclasses
+from pprint import pformat as pf
 from typing import (
     TYPE_CHECKING,
     Any,
-    Callable,
     ClassVar,
     Dict,
-    Generic,
     List,
-    NamedTuple,
     Optional,
-    Sequence,
     Type,
-    TypeVar,
     Union,
     cast,
 )
 
 import pydantic
-from pydantic import dataclasses as pydantic_dc
 from typing_extensions import Literal
 
+import great_expectations.exceptions as gx_exceptions
 from great_expectations.core.batch_spec import SqlAlchemyDatasourceBatchSpec
+from great_expectations.experimental.datasources.experimental_base_model import (
+    ExperimentalBaseModel,
+)
 from great_expectations.experimental.datasources.interfaces import (
     Batch,
     BatchRequest,
     BatchRequestOptions,
+    BatchSorter,
     BatchSortersDefinition,
     DataAsset,
     Datasource,
@@ -55,33 +54,76 @@ class SQLDatasourceWarning(UserWarning):
     pass
 
 
-@pydantic_dc.dataclass(frozen=True)
-class ColumnSplitter:
+class _ColumnSplitter(ExperimentalBaseModel):
     column_name: str
     method_name: str
-    param_names: Sequence[str]
 
-    def param_defaults(self, sql_asset: _SQLAsset) -> Dict[str, List]:
+    @property
+    def param_names(self) -> List[str]:
+        """Returns the parameter names that specify a batch derived from this column splitter
+
+        For example, for ColumnSplitterYearMonth this returns ["year", "month"]. For more
+        examples, please see _ColumnSplitter subclasses.
+        """
         raise NotImplementedError
 
-    @pydantic.validator("method_name")
-    def _splitter_method_exists(cls, v: str):
-        """Fail early if the `method_name` does not exist and would fail at runtime."""
-        # NOTE (kilo59): this could be achieved by simply annotating the method_name field
-        # as a `SplitterMethod` enum but we get cyclic imports.
-        # This also adds the enums to the generated json schema.
-        # https://docs.pydantic.dev/usage/types/#enums-and-choices
-        # We could use `update_forward_refs()` but would have to change this to a BaseModel
-        # https://docs.pydantic.dev/usage/postponed_annotations/
-        from great_expectations.execution_engine.split_and_sample.data_splitter import (
-            SplitterMethod,
+    def splitter_method_kwargs(self) -> Dict[str, Any]:
+        """A shim to our sqlalchemy execution engine splitter methods
+
+        We translate any internal _ColumnSplitter state and what is passed in from
+        a batch_request to the splitter_kwargs required by our execution engine
+        data splitters defined in:
+        great_expectations.execution_engine.split_and_sample.sqlalchemy_data_splitter
+
+        Look at _ColumnSplitter subclasses for concrete examples.
+        """
+        raise NotImplementedError
+
+    def batch_batch_request_options_to_batch_spec_kwarg_identifiers(
+        self, options: BatchRequestOptions
+    ) -> Dict[str, Any]:
+        """Translate the batch request options to the dictionary needed to by our execution engine
+
+        Arguments:
+            options: A BatchRequest.options dictionary that specified all the fields necessary
+                     to specify a batch with respect to this column splitter.
+
+        Returns:
+            A dictionary that can be added to batch_spec_kwargs["batch_identifiers"] when we
+            make a SqlAlchemyDatasourceBatchSpec and run execution_engine.get_batch_data_and_markers
+            for a particular batch specified by options.
+        """
+        raise NotImplementedError
+
+    def param_defaults(self, sql_asset: _SQLAsset) -> List[Dict]:
+        from great_expectations.execution_engine.split_and_sample.sqlalchemy_data_splitter import (
+            SqlAlchemyDataSplitter,
         )
 
-        method_members = set(SplitterMethod)
-        if v not in method_members:
-            permitted_values_str = "', '".join([m.value for m in method_members])
-            raise ValueError(f"unexpected value; permitted: '{permitted_values_str}'")
-        return v
+        execution_engine = sql_asset.datasource.get_execution_engine()
+        splitter = SqlAlchemyDataSplitter(execution_engine.dialect_name)
+        batch_identifier_data = splitter.get_data_for_batch_identifiers(
+            execution_engine=execution_engine,
+            selectable=sql_asset.as_selectable(),
+            splitter_method_name=self.method_name,
+            splitter_kwargs=self.splitter_method_kwargs(),
+        )
+        params: List[Dict] = []
+        for identifier_data in batch_identifier_data:
+            # batch_identifiers is a list of dicts that is keyed by the column name. The value is either:
+            #  * A dict whose keys are batch request parameter names and values are the batch values.
+            #  * A single value for the 1 batch request parameter.
+            value = identifier_data[self.column_name]
+            if isinstance(value, dict):
+                params.append(value)
+            elif len(self.param_names) == 1:
+                params.append({self.param_names[0]: value})
+            else:
+                raise SQLDatasourceError(
+                    f"identifier_data is in an unexpected form for {self.__class__} "
+                    f"on column {self.column_name}: {identifier_data}"
+                )
+        return params
 
     def test_connection(self, table_asset: TableAsset) -> None:
         """Test the connection for the ColumnSplitter.
@@ -92,10 +134,8 @@ class ColumnSplitter:
         Raises:
             TestConnectionError: If the connection test fails.
         """
-        # A TypeVar for Datasource would get rid of this assertion,
-        # but circularity between Datasource <-> DataAsset is an issue.
-        assert isinstance(table_asset.datasource, SQLDatasource)
-        engine: sqlalchemy.engine.Engine = table_asset.datasource.get_engine()
+        datasource: SQLDatasource = table_asset.datasource
+        engine: sqlalchemy.engine.Engine = datasource.get_engine()
         inspector: sqlalchemy.engine.Inspector = sqlalchemy.inspect(engine)
 
         columns: list[dict[str, Any]] = inspector.get_columns(
@@ -108,93 +148,174 @@ class ColumnSplitter:
             )
 
 
-_ColumnSplitterT = TypeVar("_ColumnSplitterT", bound=ColumnSplitter)
+class ColumnSplitterYear(_ColumnSplitter):
+    method_name: Literal["split_on_year"] = "split_on_year"
+
+    @property
+    def param_names(self) -> List[str]:
+        return ["year"]
+
+    def splitter_method_kwargs(self) -> Dict[str, Any]:
+        return {"column_name": self.column_name}
+
+    def batch_request_options_to_batch_spec_kwarg_identifiers(
+        self, options: BatchRequestOptions
+    ) -> Dict[str, Any]:
+        return _request_options_to_datetime_batch_spec_kwargs(self, options)
 
 
-class DatetimeRange(NamedTuple):
-    min: datetime
-    max: datetime
-
-
-@pydantic_dc.dataclass(frozen=True)
-class SqlYearMonthSplitter(ColumnSplitter):
+class ColumnSplitterYearAndMonth(_ColumnSplitter):
     method_name: Literal["split_on_year_and_month"] = "split_on_year_and_month"
-    param_names: List[Literal["year", "month"]] = pydantic.Field(
-        default_factory=lambda: ["year", "month"]
-    )
 
-    def param_defaults(self, sql_asset: _SQLAsset) -> Dict[str, List]:
-        """Query sql database to get the years and months to split over.
+    @property
+    def param_names(self) -> List[str]:
+        return ["year", "month"]
 
-        Args:
-            sql_asset: A SQL DataAsset over which we want to split the data.
-        """
-        return _query_for_year_and_month(
-            sql_asset, self.column_name, _get_sql_datetime_range
+    def splitter_method_kwargs(self) -> Dict[str, Any]:
+        return {"column_name": self.column_name}
+
+    def batch_request_options_to_batch_spec_kwarg_identifiers(
+        self, options: BatchRequestOptions
+    ) -> Dict[str, Any]:
+        return _request_options_to_datetime_batch_spec_kwargs(self, options)
+
+
+class ColumnSplitterYearAndMonthAndDay(_ColumnSplitter):
+    method_name: Literal[
+        "split_on_year_and_month_and_day"
+    ] = "split_on_year_and_month_and_day"
+
+    @property
+    def param_names(self) -> List[str]:
+        return ["year", "month", "day"]
+
+    def splitter_method_kwargs(self) -> Dict[str, Any]:
+        return {"column_name": self.column_name}
+
+    def batch_request_options_to_batch_spec_kwarg_identifiers(
+        self, options: BatchRequestOptions
+    ) -> Dict[str, Any]:
+        return _request_options_to_datetime_batch_spec_kwargs(self, options)
+
+
+class ColumnSplitterDatetimePart(_ColumnSplitter):
+    datetime_parts: List[str]
+    column_name: str
+    method_name: Literal["split_on_date_parts"] = "split_on_date_parts"
+
+    @property
+    def param_names(self) -> List[str]:
+        return self.datetime_parts
+
+    def splitter_method_kwargs(self) -> Dict[str, Any]:
+        return {"column_name": self.column_name, "date_parts": self.param_names}
+
+    def batch_request_options_to_batch_spec_kwarg_identifiers(
+        self, options: BatchRequestOptions
+    ) -> Dict[str, Any]:
+        return _request_options_to_datetime_batch_spec_kwargs(self, options)
+
+    @pydantic.validator("datetime_parts", each_item=True)
+    def _check_param_name_allowed(cls, v: str):
+        from great_expectations.execution_engine.split_and_sample.data_splitter import (
+            DatePart,
         )
 
-
-def _query_for_year_and_month(
-    sql_asset: _SQLAsset,
-    column_name: str,
-    query_datetime_range: Callable[
-        [sqlalchemy.engine.base.Connection, sqlalchemy.sql.Selectable, str],
-        DatetimeRange,
-    ],
-) -> Dict[str, List]:
-    execution_engine: SqlAlchemyExecutionEngine = (
-        sql_asset.datasource.get_execution_engine()
-    )
-
-    with execution_engine.engine.connect() as conn:
-        datetimes: DatetimeRange = query_datetime_range(
-            conn,
-            sql_asset.as_selectable(),
-            column_name,
-        )
-    year: List[int] = list(range(datetimes.min.year, datetimes.max.year + 1))
-    month: List[int]
-    if datetimes.min.year == datetimes.max.year:
-        month = list(range(datetimes.min.month, datetimes.max.month + 1))
-    else:
-        month = list(range(1, 13))
-    return {"year": year, "month": month}
+        allowed_date_parts = [part.value for part in DatePart]
+        assert (
+            v in allowed_date_parts
+        ), f"Only the following param_names are allowed: {allowed_date_parts}"
+        return v
 
 
-def _get_sql_datetime_range(
-    conn: sqlalchemy.engine.base.Connection,
-    selectable: sqlalchemy.sql.Selectable,
-    col_name: str,
-) -> DatetimeRange:
-    import sqlalchemy as sa
-
-    column = sa.column(col_name)
-    query = sa.select([sa.func.min(column), sa.func.max(column)]).select_from(
-        selectable
-    )
-    min_max_dt = list(
-        conn.execute(query.compile(compile_kwargs={"literal_binds": True}))
-    )[0]
-    if min_max_dt[0] is None or min_max_dt[1] is None:
-        raise SQLDatasourceError(
-            f"Data date range can not be determined for the query: {query}. The returned range was {min_max_dt}."
-        )
-    return DatetimeRange(min=min_max_dt[0], max=min_max_dt[1])
+DatetimeColumnSplitter = Union[
+    ColumnSplitterYear,
+    ColumnSplitterYearAndMonth,
+    ColumnSplitterYearAndMonthAndDay,
+    ColumnSplitterDatetimePart,
+]
 
 
-class _SQLAsset(DataAsset, Generic[_ColumnSplitterT]):
+def _request_options_to_datetime_batch_spec_kwargs(
+    splitter: DatetimeColumnSplitter, options: BatchRequestOptions
+) -> Dict[str, Any]:
+    identifiers: Dict = {}
+    for part in splitter.param_names:
+        if part not in options:
+            raise ValueError(
+                f"'{part}' must be specified in the batch request options to create a batch identifier"
+            )
+        identifiers[part] = options[part]
+    return {splitter.column_name: identifiers}
+
+
+class ColumnSplitterColumnValue(_ColumnSplitter):
+    method_name: Literal["split_on_column_value"] = "split_on_column_value"
+
+    @property
+    def param_names(self) -> List[str]:
+        return [self.column_name]
+
+    def splitter_method_kwargs(self) -> Dict[str, Any]:
+        return {"column_name": self.column_name}
+
+    def batch_request_options_to_batch_spec_kwarg_identifiers(
+        self, options: BatchRequestOptions
+    ) -> Dict[str, Any]:
+        if self.column_name not in options:
+            raise ValueError(
+                f"'{self.column_name}' must be specified in the batch request options to create a batch identifier"
+            )
+        return {self.column_name: options[self.column_name]}
+
+
+class ColumnSplitterDividedInteger(_ColumnSplitter):
+    divisor: int
+    method_name: Literal["split_on_divided_integer"] = "split_on_divided_integer"
+
+    @property
+    def param_names(self) -> List[str]:
+        return ["quotient"]
+
+    def splitter_method_kwargs(self) -> Dict[str, Any]:
+        return {"column_name": self.column_name, "divisor": self.divisor}
+
+    def batch_request_options_to_batch_spec_kwarg_identifiers(
+        self, options: BatchRequestOptions
+    ) -> Dict[str, Any]:
+        if "quotient" not in options:
+            raise ValueError(
+                "'quotient' must be specified in the batch request options to create a batch identifier"
+            )
+        return {self.column_name: options["quotient"]}
+
+
+ColumnSplitter = Union[
+    ColumnSplitterColumnValue,
+    ColumnSplitterDividedInteger,
+    ColumnSplitterDatetimePart,
+    ColumnSplitterYearAndMonthAndDay,
+    ColumnSplitterYearAndMonth,
+    ColumnSplitterYear,
+]
+
+
+class _SQLAsset(DataAsset):
     # Instance fields
-    type: Literal["_sqlasset"] = "_sqlasset"
-    column_splitter: Optional[_ColumnSplitterT] = None
+    type: str = pydantic.Field("_sql_asset")
+    column_splitter: Optional[ColumnSplitter] = None
     name: str
 
+    # Internal attributes
+    _datasource: SQLDatasource = pydantic.PrivateAttr()
+
     def batch_request_options_template(
         self,
     ) -> BatchRequestOptions:
-        """A BatchRequestOptions template for get_batch_request.
+        """A BatchRequestOptions template for build_batch_request.
 
         Returns:
-            A BatchRequestOptions dictionary with the correct shape that get_batch_request
+            A BatchRequestOptions dictionary with the correct shape that build_batch_request
             will understand. All the option values are defaulted to None.
         """
         template: BatchRequestOptions = {}
@@ -202,73 +323,131 @@ class _SQLAsset(DataAsset, Generic[_ColumnSplitterT]):
             return template
         return {p: None for p in self.column_splitter.param_names}
 
-    # This asset type will support a variety of splitters
-    def add_year_and_month_splitter(
+    def _add_splitter(self, column_splitter: ColumnSplitter):
+        self.column_splitter = column_splitter
+        self.test_column_splitter_connection()
+        return self
+
+    def add_splitter_year(
         self,
         column_name: str,
     ) -> _SQLAsset:
-        """Associates a year month splitter with this _SQLAsset
+        """Associates a year splitter with this sql data asset.
         Args:
             column_name: A column name of the date column where year and month will be parsed out.
         Returns:
-            This _SQLAsset so we can use this method fluently.
+            This sql asset so we can use this method fluently.
         """
-        raise NotImplementedError(
-            """One needs to implement "add_year_and_month_splitter" on a _SQLAsset subclass."""
+        return self._add_splitter(
+            ColumnSplitterYear(method_name="split_on_year", column_name=column_name)
         )
 
-    def _fully_specified_batch_requests(self, batch_request) -> List[BatchRequest]:
+    def add_splitter_year_and_month(
+        self,
+        column_name: str,
+    ) -> _SQLAsset:
+        """Associates a year, month splitter with this sql asset.
+        Args:
+            column_name: A column name of the date column where year and month will be parsed out.
+        Returns:
+            This sql asset so we can use this method fluently.
+        """
+        return self._add_splitter(
+            ColumnSplitterYearAndMonth(
+                method_name="split_on_year_and_month", column_name=column_name
+            )
+        )
+
+    def add_splitter_year_and_month_and_day(
+        self,
+        column_name: str,
+    ) -> _SQLAsset:
+        """Associates a year, month, day splitter with this sql asset.
+        Args:
+            column_name: A column name of the date column where year and month will be parsed out.
+        Returns:
+            This sql asset so we can use this method fluently.
+        """
+        return self._add_splitter(
+            ColumnSplitterYearAndMonthAndDay(
+                method_name="split_on_year_and_month_and_day", column_name=column_name
+            )
+        )
+
+    def add_splitter_datetime_part(
+        self, column_name: str, datetime_parts: List[str]
+    ) -> _SQLAsset:
+        return self._add_splitter(
+            ColumnSplitterDatetimePart(
+                method_name="split_on_date_parts",
+                column_name=column_name,
+                datetime_parts=datetime_parts,
+            )
+        )
+
+    def add_splitter_column_value(self, column_name: str) -> _SQLAsset:
+        return self._add_splitter(
+            ColumnSplitterColumnValue(
+                method_name="split_on_column_value",
+                column_name=column_name,
+            )
+        )
+
+    def add_splitter_divided_integer(self, column_name: str, divisor: int) -> _SQLAsset:
+        return self._add_splitter(
+            ColumnSplitterDividedInteger(
+                method_name="split_on_divided_integer",
+                column_name=column_name,
+                divisor=divisor,
+            )
+        )
+
+    def test_connection(self) -> None:
+        pass
+
+    def test_column_splitter_connection(self) -> None:
+        pass
+
+    @staticmethod
+    def _does_matches_request_options(
+        candidate: Dict, requested_options: BatchRequestOptions
+    ) -> bool:
+        for k, v in requested_options.items():
+            if v is not None and candidate[k] != v:
+                return False
+        return True
+
+    def _fully_specified_batch_requests(
+        self, batch_request: BatchRequest
+    ) -> List[BatchRequest]:
         """Populates a batch requests unspecified params producing a list of batch requests."""
         if self.column_splitter is None:
             # Currently batch_request.options is complete determined by the presence of a
             # column splitter. If column_splitter is None, then there are no specifiable options
-            # so we return early.
+            # so we return early. Since the passed in batch_request is verified, it must be the
+            # empty, ie {}.
             # In the future, if there are options that are not determined by the column splitter
             # this check will have to be generalized.
             return [batch_request]
 
-        # Make a list of the specified and unspecified params in batch_request
-        specified_options = []
-        unspecified_options = []
-        options_template = self.batch_request_options_template()
-        for option_name in options_template.keys():
-            if (
-                option_name in batch_request.options
-                and batch_request.options[option_name] is not None
-            ):
-                specified_options.append(option_name)
-            else:
-                unspecified_options.append(option_name)
-
-        # Make a list of the all possible batch_request.options by expanding out the unspecified
-        # options
         batch_requests: List[BatchRequest] = []
-
-        if not unspecified_options:
-            batch_requests.append(batch_request)
-        else:
-            # All options are defined by the splitter, so we look at its default values to fill
-            # in the option values.
-            default_option_values = []
-            for option in unspecified_options:
-                default_option_values.append(
-                    self.column_splitter.param_defaults(self)[option]
-                )
-            for option_values in itertools.product(*default_option_values):
-                # Add options from specified options
-                options = {
-                    name: batch_request.options[name] for name in specified_options
-                }
-                # Add options from unspecified options
-                for i, option_value in enumerate(option_values):
-                    options[unspecified_options[i]] = option_value
-                batch_requests.append(
-                    BatchRequest(
-                        datasource_name=batch_request.datasource_name,
-                        data_asset_name=batch_request.data_asset_name,
-                        options=options,
-                    )
+        # We iterate through all possible batches as determined by the column splitter
+        for params in self.column_splitter.param_defaults(self):
+            # If the params from the column splitter don't match the batch request options
+            # we don't create this batch.
+            if not _SQLAsset._does_matches_request_options(
+                params, batch_request.options
+            ):
+                continue
+            options = copy.deepcopy(batch_request.options)
+            options.update(params)
+            batch_requests.append(
+                BatchRequest(
+                    datasource_name=batch_request.datasource_name,
+                    data_asset_name=batch_request.data_asset_name,
+                    options=options,
                 )
+            )
         return batch_requests
 
     def get_batch_list_from_batch_request(
@@ -278,7 +457,7 @@ class _SQLAsset(DataAsset, Generic[_ColumnSplitterT]):
 
         Args:
             batch_request: A batch request for this asset. Usually obtained by calling
-                get_batch_request on the asset.
+                build_batch_request on the asset.
 
         Returns:
             A list of batches that match the options specified in the batch request.
@@ -293,13 +472,15 @@ class _SQLAsset(DataAsset, Generic[_ColumnSplitterT]):
             batch_spec_kwargs = self._create_batch_spec_kwargs()
             if column_splitter:
                 batch_spec_kwargs["splitter_method"] = column_splitter.method_name
-                batch_spec_kwargs["splitter_kwargs"] = {
-                    "column_name": column_splitter.column_name
-                }
+                batch_spec_kwargs[
+                    "splitter_kwargs"
+                ] = column_splitter.splitter_method_kwargs()
                 # mypy infers that batch_spec_kwargs["batch_identifiers"] is a collection, but
                 # it is hardcoded to a dict above, so we cast it here.
                 cast(Dict, batch_spec_kwargs["batch_identifiers"]).update(
-                    {column_splitter.column_name: request.options}
+                    column_splitter.batch_request_options_to_batch_spec_kwarg_identifiers(
+                        request.options
+                    )
                 )
             # Creating the batch_spec is our hook into the execution engine.
             batch_spec = SqlAlchemyDatasourceBatchSpec(**batch_spec_kwargs)
@@ -344,6 +525,56 @@ class _SQLAsset(DataAsset, Generic[_ColumnSplitterT]):
         self.sort_batches(batch_list)
         return batch_list
 
+    def build_batch_request(
+        self, options: Optional[BatchRequestOptions] = None
+    ) -> BatchRequest:
+        """A batch request that can be used to obtain batches for this DataAsset.
+
+        Args:
+            options: A dict that can be used to limit the number of batches returned from the asset.
+                The dict structure depends on the asset type. A template of the dict can be obtained by
+                calling batch_request_options_template.
+
+        Returns:
+            A BatchRequest object that can be used to obtain a batch list from a Datasource by calling the
+            get_batch_list_from_batch_request method.
+        """
+        if options is not None and not self._valid_batch_request_options(options):
+            allowed_keys = set(self.batch_request_options_template().keys())
+            actual_keys = set(options.keys())
+            raise gx_exceptions.InvalidBatchRequestError(
+                "Batch request options should only contain keys from the following set:\n"
+                f"{allowed_keys}\nbut your specified keys contain\n"
+                f"{actual_keys.difference(allowed_keys)}\nwhich is not valid.\n"
+            )
+        return BatchRequest(
+            datasource_name=self.datasource.name,
+            data_asset_name=self.name,
+            options=options or {},
+        )
+
+    def _validate_batch_request(self, batch_request: BatchRequest) -> None:
+        """Validates the batch_request has the correct form.
+
+        Args:
+            batch_request: A batch request object to be validated.
+        """
+        if not (
+            batch_request.datasource_name == self.datasource.name
+            and batch_request.data_asset_name == self.name
+            and self._valid_batch_request_options(batch_request.options)
+        ):
+            expect_batch_request_form = BatchRequest(
+                datasource_name=self.datasource.name,
+                data_asset_name=self.name,
+                options=self.batch_request_options_template(),
+            )
+            raise gx_exceptions.InvalidBatchRequestError(
+                "BatchRequest should have form:\n"
+                f"{pf(dataclasses.asdict(expect_batch_request_form))}\n"
+                f"but actually has form:\n{pf(dataclasses.asdict(batch_request))}\n"
+            )
+
     def _create_batch_spec_kwargs(self) -> dict[str, Any]:
         """Creates batch_spec_kwargs used to instantiate a SqlAlchemyDatasourceBatchSpec
 
@@ -365,12 +596,8 @@ class _SQLAsset(DataAsset, Generic[_ColumnSplitterT]):
 
 class QueryAsset(_SQLAsset):
     # Instance fields
-    type: Literal["query"] = "query"  # type: ignore[assignment]
+    type: Literal["query"] = "query"
     query: str
-    column_splitter: Optional[SqlYearMonthSplitter] = None
-
-    def test_connection(self) -> None:
-        pass
 
     @pydantic.validator("query")
     def query_must_start_with_select(cls, v: str):
@@ -379,23 +606,6 @@ class QueryAsset(_SQLAsset):
             raise ValueError("query must start with 'SELECT' followed by a whitespace.")
         return v
 
-    def add_year_and_month_splitter(
-        self,
-        column_name: str,
-    ) -> QueryAsset:
-        """Associates a year month splitter with this QueryAsset
-
-        Args:
-            column_name: A column name of the date column where year and month will be parsed out.
-
-        Returns:
-            This QueryAsset so we can use this method fluently.
-        """
-        self.column_splitter = SqlYearMonthSplitter(
-            column_name=column_name,
-        )
-        return self
-
     def as_selectable(self) -> sqlalchemy.sql.Selectable:
         """Returns the Selectable that is used to retrieve the data.
 
@@ -416,10 +626,9 @@ class QueryAsset(_SQLAsset):
 
 class TableAsset(_SQLAsset):
     # Instance fields
-    type: Literal["table"] = "table"  # type: ignore[assignment]
+    type: Literal["table"] = "table"
     table_name: str
     schema_name: Optional[str] = None
-    column_splitter: Optional[SqlYearMonthSplitter] = None
 
     @property
     def qualified_name(self) -> str:
@@ -435,10 +644,8 @@ class TableAsset(_SQLAsset):
         Raises:
             TestConnectionError: If the connection test fails.
         """
-        # A TypeVar for Datasource would get rid of this assertion,
-        # but circularity between Datasource <-> DataAsset is an issue.
-        assert isinstance(self.datasource, SQLDatasource)
-        engine: sqlalchemy.engine.Engine = self.datasource.get_engine()
+        datasource: SQLDatasource = self.datasource
+        engine: sqlalchemy.engine.Engine = datasource.get_engine()
         inspector: sqlalchemy.engine.Inspector = sqlalchemy.inspect(engine)
 
         if self.schema_name and self.schema_name not in inspector.get_schema_names():
@@ -457,24 +664,9 @@ class TableAsset(_SQLAsset):
                 f'"{self.table_name}" does not exist.'
             )
 
-    def add_year_and_month_splitter(
-        self,
-        column_name: str,
-    ) -> TableAsset:
-        """Associates a year month splitter with this TableAsset
-
-        Args:
-            column_name: A column name of the date column where year and month will be parsed out.
-
-        Returns:
-            This TableAsset so we can use this method fluently.
-        """
-        column_splitter = SqlYearMonthSplitter(
-            column_name=column_name,
-        )
-        column_splitter.test_connection(table_asset=self)
-        self.column_splitter = column_splitter
-        return self
+    def test_column_splitter_connection(self) -> None:
+        if self.column_splitter:
+            self.column_splitter.test_connection(table_asset=self)
 
     def as_selectable(self) -> sqlalchemy.sql.Selectable:
         """Returns the table as a sqlalchemy Selectable.
@@ -589,12 +781,14 @@ class SQLDatasource(Datasource):
         Returns:
             The TableAsset that is added to the datasource.
         """
+        order_by_sorters: list[BatchSorter] = self.parse_order_by_sorters(
+            order_by=order_by
+        )
         asset = TableAsset(
             name=name,
             table_name=table_name,
             schema_name=schema_name,
-            order_by=order_by or [],  # type: ignore[arg-type]  # coerce list[str]
-            # see DataAsset._parse_order_by_sorter()
+            order_by=order_by_sorters,
         )
         return self.add_asset(asset)
 
@@ -614,9 +808,12 @@ class SQLDatasource(Datasource):
         Returns:
             The QueryAsset that is added to the datasource.
         """
+        order_by_sorters: list[BatchSorter] = self.parse_order_by_sorters(
+            order_by=order_by
+        )
         asset = QueryAsset(
             name=name,
             query=query,
-            order_by=order_by or [],  # type: ignore[arg-type]  # coerce list[str]
+            order_by=order_by_sorters,
         )
         return self.add_asset(asset)
