@@ -1,31 +1,34 @@
 import logging
 import traceback
-from typing import Any, Callable, Optional, Union
+from typing import Any, Callable, Dict, Optional, Type, Union
 
-from great_expectations.core.expectation_configuration import ExpectationConfiguration
-from great_expectations.core.expectation_validation_result import (
+from great_expectations.alias_types import JSONValues  # noqa: TCH001
+from great_expectations.core import (
+    ExpectationConfiguration,
     ExpectationValidationResult,
 )
 from great_expectations.expectations.registry import (
     _registered_renderers,
     get_renderer_impl,
 )
-from great_expectations.render.renderer.renderer import Renderer
-from great_expectations.render.types import (
+from great_expectations.render import (
     CollapseContent,
+    LegacyRendererType,
+    RenderedComponentContent,
     RenderedMarkdownContent,
     RenderedStringTemplateContent,
     TextContent,
 )
+from great_expectations.render.renderer.renderer import Renderer
 
 logger = logging.getLogger(__name__)
 
 
 class ContentBlockRenderer(Renderer):
-    _rendered_component_type = TextContent
+    _rendered_component_type: Type[RenderedComponentContent] = TextContent
     _default_header = ""
 
-    _default_content_block_styling = {"classes": ["col-12"]}
+    _default_content_block_styling: Dict[str, JSONValues] = {"classes": ["col-12"]}
 
     _default_element_styling = {}
 
@@ -219,7 +222,7 @@ diagnose and repair the underlying issue.  Detailed information follows:
         expectation_type = cls._get_expectation_type(render_object)
 
         content_block_fn = get_renderer_impl(
-            object_name=expectation_type, renderer_type="renderer.prescriptive"
+            object_name=expectation_type, renderer_type=LegacyRendererType.PRESCRIPTIVE
         )
         content_block_fn = content_block_fn[1] if content_block_fn else None
         if content_block_fn is not None and not exception_list_content_block:
@@ -399,7 +402,7 @@ diagnose and repair the underlying issue.  Detailed information follows:
     @classmethod
     def _get_content_block_fn(cls, expectation_type):
         content_block_fn = get_renderer_impl(
-            object_name=expectation_type, renderer_type="renderer.prescriptive"
+            object_name=expectation_type, renderer_type=LegacyRendererType.PRESCRIPTIVE
         )
         return content_block_fn[1] if content_block_fn else None
 
@@ -415,10 +418,9 @@ diagnose and repair the underlying issue.  Detailed information follows:
     @classmethod
     def _missing_content_block_fn(
         cls,
-        configuration=None,
-        result=None,
-        language=None,
-        runtime_configuration=None,
+        configuration: Optional[ExpectationConfiguration] = None,
+        result: Optional[ExpectationValidationResult] = None,
+        runtime_configuration: Optional[dict] = None,
         **kwargs,
     ):
         return []
