@@ -1,10 +1,16 @@
-from great_expectations.render.renderer.content_block.content_block import (
-    ContentBlockRenderer,
+from typing import Optional
+
+from great_expectations.core import (
+    ExpectationConfiguration,  # noqa: TCH001
+    ExpectationValidationResult,  # noqa: TCH001
 )
-from great_expectations.render.types import (
+from great_expectations.render import (
     RenderedBulletListContent,
     RenderedStringTemplateContent,
 )
+from great_expectations.render.renderer.content_block.content_block import (
+    ContentBlockRenderer,
+)
 
 
 class ExceptionListContentBlockRenderer(ContentBlockRenderer):
@@ -56,16 +62,14 @@ class ExceptionListContentBlockRenderer(ContentBlockRenderer):
     @classmethod
     def _missing_content_block_fn(
         cls,
-        configuration=None,
-        result=None,
-        language=None,
-        runtime_configuration=None,
+        configuration: Optional[ExpectationConfiguration] = None,
+        result: Optional[ExpectationValidationResult] = None,
+        runtime_configuration: Optional[dict] = None,
         **kwargs,
     ):
         runtime_configuration = runtime_configuration or {}
-        include_column_name = runtime_configuration.get("include_column_name", True)
         include_column_name = (
-            include_column_name if include_column_name is not None else True
+            False if runtime_configuration.get("include_column_name") is False else True
         )
         styling = runtime_configuration.get("styling")
         # Only render EVR objects for which an exception was raised
