@@ -7,9 +7,7 @@ from typing import Any, List, Optional, Tuple
 import great_expectations.exceptions as exceptions
 from great_expectations.core import ExpectationSuite
 from great_expectations.core.util import nested_update
-from great_expectations.data_context.store.ge_cloud_store_backend import (
-    GeCloudRESTResource,
-)
+from great_expectations.data_context.cloud_constants import GXCloudRESTResource
 from great_expectations.data_context.store.html_site_store import (
     HtmlSiteStore,
     SiteSectionIdentifier,
@@ -17,7 +15,7 @@ from great_expectations.data_context.store.html_site_store import (
 from great_expectations.data_context.store.json_site_store import JsonSiteStore
 from great_expectations.data_context.types.resource_identifiers import (
     ExpectationSuiteIdentifier,
-    GeCloudIdentifier,
+    GXCloudIdentifier,
     ValidationResultIdentifier,
 )
 from great_expectations.data_context.util import instantiate_class_from_config
@@ -112,7 +110,7 @@ class SiteBuilder:
                         class_name: DefaultJinjaIndexPageView
     """
 
-    def __init__(
+    def __init__(  # noqa: C901 - 16
         self,
         data_context,
         store_backend,
@@ -121,6 +119,8 @@ class SiteBuilder:
         show_how_to_buttons=True,
         site_section_builders=None,
         runtime_environment=None,
+        cloud_mode=False,
+        # <GX_RENAME> Deprecated 0.15.37
         ge_cloud_mode=False,
         **kwargs,
     ) -> None:
@@ -128,7 +128,10 @@ class SiteBuilder:
         self.data_context = data_context
         self.store_backend = store_backend
         self.show_how_to_buttons = show_how_to_buttons
-        self.ge_cloud_mode = ge_cloud_mode
+        if ge_cloud_mode:
+            cloud_mode = ge_cloud_mode
+        self.cloud_mode = cloud_mode
+        self.ge_cloud_mode = cloud_mode
 
         usage_statistics_config = data_context.anonymous_usage_statistics
         data_context_id = None
@@ -167,7 +170,7 @@ class SiteBuilder:
         # three types of backends using the base
         # type of the configuration defined in the store_backend section
 
-        if ge_cloud_mode:
+        if cloud_mode:
             self.target_store = JsonSiteStore(
                 store_backend=store_backend, runtime_environment=runtime_environment
             )
@@ -235,7 +238,7 @@ class SiteBuilder:
                     "custom_views_directory": custom_views_directory,
                     "data_context_id": self.data_context_id,
                     "show_how_to_buttons": self.show_how_to_buttons,
-                    "ge_cloud_mode": self.ge_cloud_mode,
+                    "cloud_mode": self.cloud_mode,
                 },
                 config_defaults={"name": site_section_name, "module_name": module_name},
             )
@@ -267,7 +270,7 @@ class SiteBuilder:
                     if section_config not in FALSEY_YAML_STRINGS
                 },
                 "site_section_builders_config": site_section_builders,
-                "ge_cloud_mode": self.ge_cloud_mode,
+                "cloud_mode": self.cloud_mode,
             },
             config_defaults={
                 "name": "site_index_builder",
@@ -306,9 +309,9 @@ class SiteBuilder:
         for site_section_builder in self.site_section_builders.values():
             site_section_builder.build(resource_identifiers=resource_identifiers)
 
-        # GE Cloud supports JSON Site Data Docs
+        # GX Cloud supports JSON Site Data Docs
         # Skip static assets, indexing
-        if self.ge_cloud_mode:
+        if self.cloud_mode:
             return
 
         self.target_store.copy_static_assets()
@@ -351,6 +354,8 @@ class DefaultSiteSectionBuilder:
         renderer=None,
         view=None,
         data_context_id=None,
+        cloud_mode=False,
+        # <GX_RENAME> Deprecated 0.15.37
         ge_cloud_mode=False,
         **kwargs,
     ) -> None:
@@ -362,7 +367,10 @@ class DefaultSiteSectionBuilder:
         self.validation_results_limit = validation_results_limit
         self.data_context_id = data_context_id
         self.show_how_to_buttons = show_how_to_buttons
-        self.ge_cloud_mode = ge_cloud_mode
+        if ge_cloud_mode:
+            cloud_mode = ge_cloud_mode
+        self.cloud_mode = cloud_mode
+        self.ge_cloud_mode = cloud_mode
         if renderer is None:
             raise exceptions.InvalidConfigError(
                 "SiteSectionBuilder requires a renderer configuration "
@@ -421,7 +429,7 @@ class DefaultSiteSectionBuilder:
             if resource_identifiers and resource_key not in resource_identifiers:
                 continue
 
-            if self.run_name_filter and not isinstance(resource_key, GeCloudIdentifier):
+            if self.run_name_filter and not isinstance(resource_key, GXCloudIdentifier):
                 if not resource_key_passes_run_name_filter(
                     resource_key, self.run_name_filter
                 ):
@@ -463,14 +471,14 @@ class DefaultSiteSectionBuilder:
             try:
                 rendered_content = self.renderer_class.render(resource)
 
-                if self.ge_cloud_mode:
+                if self.cloud_mode:
                     self.target_store.set(
-                        GeCloudIdentifier(
-                            resource_type=GeCloudRESTResource.RENDERED_DATA_DOC
+                        GXCloudIdentifier(
+                            resource_type=GXCloudRESTResource.RENDERED_DATA_DOC
                         ),
                         rendered_content,
                         source_type=resource_key.resource_type,
-                        source_id=resource_key.ge_cloud_id,
+                        source_id=resource_key.cloud_id,
                     )
                 else:
                     viewable_content = self.view_class.render(
@@ -678,7 +686,7 @@ class DefaultSiteIndexBuilder:
             "How to Create Expectations",
             "https://docs.greatexpectations.io/docs/guides/expectations/how_to_create_and_edit_expectations_with_instant_feedback_from_a_sample_batch_of_data",
         )
-        see_glossary = CallToActionButton(
+        _ = CallToActionButton(
             "See More Kinds of Expectations",
             "https://greatexpectations.io/expectations",
         )
@@ -686,7 +694,7 @@ class DefaultSiteIndexBuilder:
             "How to Validate Data",
             "https://docs.greatexpectations.io/docs/guides/validation/checkpoints/how_to_create_a_new_checkpoint",
         )
-        customize_data_docs = CallToActionButton(
+        _ = CallToActionButton(
             "How to Customize Data Docs",
             "https://docs.greatexpectations.io/docs/reference/data_docs#customizing-html-documentation",
         )
