@@ -50,7 +50,7 @@ context = gx.get_context()
 expectation_suite_name = "{self.suite_name}"
 
 # Wipe the suite clean to prevent unwanted expectations in the batch
-suite = context.create_expectation_suite(expectation_suite_name, overwrite_existing=True)
+suite = context.add_or_update_expectation_suite(expectation_suite_name)
 
 batch_kwargs = {self.batch_kwargs}
 batch = context.get_batch(batch_kwargs, suite)
@@ -79,7 +79,7 @@ Let's save the scaffolded expectation suite as a JSON file in the
             "action_list_operator"
         ):
             code_cell = """\
-context.save_expectation_suite(suite, expectation_suite_name)
+context.update_expectation_suite(expectation_suite=suite)
 
 results = LegacyCheckpoint(
     name="_temp_checkpoint",
@@ -97,7 +97,7 @@ context.build_data_docs()
 context.open_data_docs(validation_result_identifier)"""
         else:
             code_cell = """\
-context.save_expectation_suite(suite, expectation_suite_name)
+context.update_expectation_suite(expectation_suite=suite)
 
 results = LegacyCheckpoint(
     name="_temp_checkpoint",
