@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 import json
 import logging
-from typing import Any, Dict, List, Optional, Type, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, Union
 
 from marshmallow import INCLUDE, Schema, ValidationError, fields, post_dump, post_load
 from ruamel.yaml.comments import CommentedMap
@@ -22,6 +24,12 @@ from great_expectations.util import (
     filter_properties_dict,
 )
 
+if TYPE_CHECKING:
+    from great_expectations.rule_based_profiler.rule.rule import Rule
+    from great_expectations.rule_based_profiler.rule_based_profiler import (
+        RuleBasedProfiler,
+    )
+
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
@@ -64,7 +72,7 @@ class NotNullSchema(Schema):
     # noinspection PyUnusedLocal
     @post_dump(pass_original=True)
     def remove_nulls_and_keep_unknowns(
-        self, output: dict, original: Type[DictDot], **kwargs
+        self, output: dict, original: DictDot, **kwargs
     ) -> dict:
         """Hook to clear the config object of any null values before being written as a dictionary.
         Additionally, it bypasses strict schema validation before writing to dict to ensure that dynamic
@@ -93,7 +101,7 @@ class NotNullSchema(Schema):
             clean_falsy=False,
         )
 
-        return cleaned_output
+        return cleaned_output  # type: ignore[return-value] # filter_properties_dict could return None
 
 
 class DomainBuilderConfig(SerializableDictDot):
@@ -498,16 +506,16 @@ class RuleBasedProfilerConfig(AbstractConfig, BaseYamlConfig):
         BaseYamlConfig.__init__(self, commented_map=commented_map)
 
     @classmethod
-    def from_commented_map(cls, commented_map: CommentedMap):  # type: ignore[no-untyped-def]
+    def from_commented_map(cls, commented_map: CommentedMap):  # type: ignore[override] # super type accepts Dict
         """Override parent implementation to pop unnecessary attrs from config.
 
         Please see parent BaseYamlConfig for more details.
         """
         try:
-            schema_instance: Any = cls._get_schema_instance()
+            schema_instance: Schema = cls._get_schema_instance()
             config: Union[dict, BaseYamlConfig] = schema_instance.load(commented_map)
-            config.pop("class_name", None)
-            config.pop("module_name", None)
+            config.pop("class_name", None)  # type: ignore[union-attr] # BaseYamlConfig has no `.pop()`
+            config.pop("module_name", None)  # type: ignore[union-attr] # BaseYamlConfig has no `.pop()`
             if isinstance(config, dict):
                 return cls.get_config_class()(commented_map=commented_map, **config)
 
@@ -519,11 +527,11 @@ class RuleBasedProfilerConfig(AbstractConfig, BaseYamlConfig):
             raise
 
     @classmethod
-    def get_config_class(cls) -> Type["RuleBasedProfilerConfig"]:  # noqa: F821
+    def get_config_class(cls) -> Type[RuleBasedProfilerConfig]:
         return cls
 
     @classmethod
-    def get_schema_class(cls) -> Type["RuleBasedProfilerConfigSchema"]:  # noqa: F821
+    def get_schema_class(cls) -> Type[RuleBasedProfilerConfigSchema]:
         return RuleBasedProfilerConfigSchema
 
     def to_json_dict(self) -> dict:
@@ -572,10 +580,10 @@ class RuleBasedProfilerConfig(AbstractConfig, BaseYamlConfig):
     @classmethod
     def resolve_config_using_acceptable_arguments(
         cls,
-        profiler: "RuleBasedProfiler",  # noqa: F821
+        profiler: RuleBasedProfiler,
         variables: Optional[Dict[str, Any]] = None,
         rules: Optional[Dict[str, Dict[str, Any]]] = None,
-    ) -> "RuleBasedProfilerConfig":  # noqa: F821
+    ) -> RuleBasedProfilerConfig:
         """Reconciles variables/rules by taking into account runtime overrides and variable substitution.
 
         Utilized in usage statistics to interact with the args provided in `RuleBasedProfiler.run()`.
@@ -599,24 +607,24 @@ class RuleBasedProfilerConfig(AbstractConfig, BaseYamlConfig):
             variables=effective_variables
         )
 
-        effective_rules: List["Rule"] = profiler.reconcile_profiler_rules(  # noqa: F821
+        effective_rules: List[Rule] = profiler.reconcile_profiler_rules(
             rules=rules,
         )
 
-        rule: "Rule"  # noqa: F821
-        effective_rules_dict: Dict[str, "Rule"] = {  # noqa: F821
+        rule: Rule
+        effective_rules_dict: Dict[str, Rule] = {
             rule.name: rule for rule in effective_rules
         }
         runtime_rules: Dict[str, dict] = {
             name: RuleBasedProfilerConfig._substitute_variables_in_config(
                 rule=rule,
-                variables_container=effective_variables,
+                variables_container=effective_variables,  # type: ignore[arg-type] # could be None
             )
             for name, rule in effective_rules_dict.items()
         }
 
         return cls(
-            name=profiler.config.name,
+            name=profiler.config.name,  # type: ignore[arg-type] # name could be None
             config_version=profiler.config.config_version,
             variables=runtime_variables,
             rules=runtime_rules,
@@ -624,7 +632,7 @@ class RuleBasedProfilerConfig(AbstractConfig, BaseYamlConfig):
 
     @staticmethod
     def _substitute_variables_in_config(
-        rule: "Rule",  # noqa: F821
+        rule: Rule,
         variables_container: ParameterContainer,
     ) -> dict:
         """Recursively updates a given rule to substitute $variable references.
