@@ -7,6 +7,12 @@ from great_expectations.rule_based_profiler.domain_builder.table_domain_builder
 from great_expectations.rule_based_profiler.domain_builder.column_domain_builder import (  # isort:skip
     ColumnDomainBuilder,
 )
+from great_expectations.rule_based_profiler.domain_builder.column_pair_domain_builder import (  # isort:skip
+    ColumnPairDomainBuilder,
+)
+from great_expectations.rule_based_profiler.domain_builder.multi_column_domain_builder import (  # isort:skip
+    MultiColumnDomainBuilder,
+)
 from great_expectations.rule_based_profiler.domain_builder.categorical_column_domain_builder import (  # isort:skip
     CategoricalColumnDomainBuilder,
 )
