@@ -1241,7 +1241,13 @@ class BaseRuleBasedProfiler(ConfigPeer):
                 configuration_key=config.name,
             )
 
-        response = persistence_fn(key=key, value=config)
+        try:
+            response = persistence_fn(key=key, value=config)
+        except gx_exceptions.StoreBackendError as e:
+            raise gx_exceptions.ProfilerError(
+                f"{e.message}; could not persist profiler"
+            ) from e
+
         if isinstance(response, GXCloudResourceRef):
             new_profiler.ge_cloud_id = response.cloud_id
 
