@@ -5,13 +5,13 @@ from typing import Dict, List, Optional, Union
 from marshmallow import Schema, fields, post_load, pre_dump
 
 from great_expectations.core.expectation_validation_result import (
-    ExpectationSuiteValidationResult,
+    ExpectationSuiteValidationResult,  # noqa: TCH001
 )
 from great_expectations.core.id_dict import BatchKwargs
 from great_expectations.core.run_identifier import RunIdentifier, RunIdentifierSchema
 from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.data_context.types.resource_identifiers import (
-    ValidationResultIdentifier,
+    ValidationResultIdentifier,  # noqa: TCH001
 )
 from great_expectations.types import DictDot
 
@@ -43,7 +43,7 @@ class ValidationOperatorResult(DictDot):
             Dict[str, Union[ExpectationSuiteValidationResult, dict, str]],
         ],
         validation_operator_config: dict,
-        evaluation_parameters: dict = None,
+        evaluation_parameters: Optional[dict] = None,
         success: Optional[bool] = None,
     ) -> None:
         self._run_id = run_id
@@ -194,7 +194,7 @@ class ValidationOperatorResult(DictDot):
         return self._validation_results_by_data_asset_name
 
     def list_data_assets_validated(
-        self, group_by: str = None
+        self, group_by: Optional[str] = None
     ) -> Union[List[dict], dict]:
         if group_by is None:
             if self._data_assets_validated is None:
