@@ -6,10 +6,13 @@ from great_expectations.core.expectation_validation_result import (
     ExpectationSuiteValidationResult,
     ExpectationValidationResult,
 )
-from great_expectations.core.metric import ValidationMetricIdentifier
+from great_expectations.core.metric_function_types import (
+    SummarizationMetricNameSuffixes,
+)
 from great_expectations.core.run_identifier import RunIdentifier
 from great_expectations.data_context.types.resource_identifiers import (
     ExpectationSuiteIdentifier,
+    ValidationMetricIdentifier,
     ValidationResultIdentifier,
 )
 
@@ -126,7 +129,7 @@ def test_StoreMetricsAction_column_metric(
                 {
                     "column": {
                         "provider_id": [
-                            "expect_column_values_to_be_unique.result.unexpected_count"
+                            f"expect_column_values_to_be_unique.result.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}"
                         ]
                     }
                 },
@@ -179,7 +182,7 @@ def test_StoreMetricsAction_column_metric(
                 run_id=run_id,
                 data_asset_name=None,
                 expectation_suite_identifier=ExpectationSuiteIdentifier("foo"),
-                metric_name="expect_column_values_to_be_unique.result.unexpected_count",
+                metric_name=f"expect_column_values_to_be_unique.result.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}",
                 metric_kwargs_id="column=provider_id",
             )
         )
