@@ -5,11 +5,17 @@ html_files = glob.glob("tests/**/output/**/*.html", recursive=True)
 
 html_list = ""
 for f_ in html_files:
-    html_list += '\t<li><a href="{}">{}</li>\n'.format(f_[6:], f_.split(".")[-2],)
+    html_list += '\t<li><a href="{}">{}</li>\n'.format(
+        f_[6:],
+        f_.split(".")[-2],
+    )
 
 json_list = ""
 for f_ in json_files:
-    json_list += '\t<li><a href="{}">{}</li>\n'.format(f_[6:], f_.split(".")[-2],)
+    json_list += '\t<li><a href="{}">{}</li>\n'.format(
+        f_[6:],
+        f_.split(".")[-2],
+    )
 
 html_file = """
 <html>
