@@ -411,7 +411,7 @@ def test_evaluation_parameters_for_between_expectations_parse_correctly(
     context = titanic_pandas_data_context_with_v013_datasource_with_checkpoints_v1_with_empty_store_stats_enabled
 
     expectation_suite_name = "test_suite"
-    context.create_expectation_suite(expectation_suite_name=expectation_suite_name)
+    context.add_expectation_suite(expectation_suite_name=expectation_suite_name)
 
     batch_request = RuntimeBatchRequest(
         datasource_name="my_datasource",
