@@ -6,7 +6,7 @@ import pytest
 from packaging import version
 
 from great_expectations.core.usage_statistics.execution_environment import (
-    GEExecutionEnvironment,
+    GXExecutionEnvironment,
     InstallEnvironment,
     PackageInfo,
 )
@@ -24,16 +24,16 @@ else:
     "input_version", ["8.8.8", "0.14.12+14.g8f54aa902.dirty", "0.1.0.post0"]
 )
 @mock.patch(
-    "great_expectations.core.usage_statistics.execution_environment.GEExecutionEnvironment._get_all_installed_packages",
+    "great_expectations.core.usage_statistics.execution_environment.GXExecutionEnvironment._get_all_installed_packages",
     return_value=True,
 )
 @mock.patch(METADATA_VERSION_PATCH, return_value=True)
 @mock.patch(
-    "great_expectations.core.usage_statistics.package_dependencies.GEDependencies.get_dev_dependency_names",
+    "great_expectations.core.usage_statistics.package_dependencies.GXDependencies.get_dev_dependency_names",
     return_value=True,
 )
 @mock.patch(
-    "great_expectations.core.usage_statistics.package_dependencies.GEDependencies.get_required_dependency_names",
+    "great_expectations.core.usage_statistics.package_dependencies.GXDependencies.get_required_dependency_names",
     return_value=True,
 )
 def test_get_installed_packages(
@@ -43,7 +43,7 @@ def test_get_installed_packages(
     get_all_installed_packages,
     input_version,
 ):
-    """Test that we are able to retrieve installed and not installed packages in the GE execution environment."""
+    """Test that we are able to retrieve installed and not installed packages in the GX execution environment."""
 
     get_required_dependency_names.return_value = [
         "req-package-1",
@@ -65,7 +65,7 @@ def test_get_installed_packages(
         "dev-package-2",
     ]
 
-    ge_execution_environment = GEExecutionEnvironment()
+    ge_execution_environment = GXExecutionEnvironment()
     expected_dependencies: List[PackageInfo] = [
         PackageInfo(
             package_name="req-package-1",
