@@ -181,8 +181,9 @@ def test_column_map_expectation_decorator():
             "unexpected_count": 0,
             "unexpected_index_list": [],
             "unexpected_list": [],
-            "unexpected_percent": 0.0,
+            "unexpected_percent": None,
             "unexpected_percent_nonmissing": None,
+            "unexpected_percent_total": None,
         },
         success=True,
     )
@@ -222,8 +223,8 @@ def test_column_map_expectation_decorator():
             "unexpected_count": 2,
             "unexpected_index_list": [5, 6],
             "unexpected_list": [2, 4],
-            "unexpected_percent": 20.0,
-            "unexpected_percent_nonmissing": (2 / 7 * 100),
+            "unexpected_percent": ((2.0 / 7) * 100),
+            "unexpected_percent_nonmissing": ((2.0 / 7) * 100),
         },
         success=False,
     )
@@ -335,10 +336,10 @@ def test_column_aggregate_expectation_decorator():
 
     assert df.expect_column_median_to_be_odd("all_odd") == ExpectationValidationResult(
         result={
-            "observed_value": 5,
+            "observed_value": 5.0,
             "element_count": 5,
-            "missing_count": 0,
-            "missing_percent": 0,
+            "missing_count": None,
+            "missing_percent": None,
         },
         success=True,
     )
@@ -347,8 +348,8 @@ def test_column_aggregate_expectation_decorator():
         result={
             "observed_value": 6,
             "element_count": 5,
-            "missing_count": 0,
-            "missing_percent": 0,
+            "missing_count": None,
+            "missing_percent": None,
         },
         success=False,
     )
@@ -357,10 +358,10 @@ def test_column_aggregate_expectation_decorator():
         "all_even", result_format="SUMMARY"
     ) == ExpectationValidationResult(
         result={
-            "observed_value": 6,
+            "observed_value": 6.0,
             "element_count": 5,
-            "missing_count": 0,
-            "missing_percent": 0,
+            "missing_count": None,
+            "missing_percent": None,
         },
         success=False,
     )
@@ -378,10 +379,10 @@ def test_column_aggregate_expectation_decorator():
         "all_even", result_format="BASIC"
     ) == ExpectationValidationResult(
         result={
-            "observed_value": 6,
+            "observed_value": 6.0,
             "element_count": 5,
-            "missing_count": 0,
-            "missing_percent": 0,
+            "missing_count": None,
+            "missing_percent": None,
         },
         success=False,
     )
@@ -518,7 +519,7 @@ def test_column_pair_map_expectation_decorator():
             "missing_count": 2,
             "unexpected_count": 3,
             "missing_percent": 40.0,
-            "unexpected_percent": 60.0,
+            "unexpected_percent": 100.0,
             "unexpected_percent_nonmissing": 100.0,
             "unexpected_list": [(1, 1.0), (3, 3.0), (5, 5.0)],
             "unexpected_index_list": [0, 1, 2],
