@@ -115,7 +115,7 @@ def test_profiler_save_with_existing_profiler_retrieves_obj_with_id_from_store(
 
     with mock.patch("requests.Session.put", autospec=True) as mock_put, mock.patch(
         "requests.Session.get", autospec=True, side_effect=mocked_get_response
-    ) as mock_get:
+    ) as mock_get, pytest.deprecated_call():
         return_profiler = context.save_profiler(profiler=profiler_with_id)
 
     profiler_id = profiler_with_id.ge_cloud_id
@@ -170,7 +170,7 @@ def test_profiler_save_with_new_profiler_retrieves_obj_with_id_from_store(
         "requests.Session.post", autospec=True, side_effect=mocked_post_response
     ) as mock_post, mock.patch(
         "requests.Session.get", autospec=True, side_effect=mocked_get_response
-    ) as mock_get:
+    ) as mock_get, pytest.deprecated_call():
         return_profiler = context.save_profiler(profiler=profiler_without_id)
 
     expected_profiler_config = ruleBasedProfilerConfigSchema.dump(
