@@ -1,8 +1,8 @@
 import pytest
 
-from great_expectations import DataContext
 from great_expectations.data_context.util import file_relative_path
 from great_expectations.exceptions import InvalidConfigError
+from great_expectations.util import get_context
 
 
 def test_incomplete_uncommitted():
@@ -12,8 +12,8 @@ def test_incomplete_uncommitted():
     variables are missing.
     """
     with pytest.raises(InvalidConfigError) as exc:
-        _ = DataContext(
-            file_relative_path(
+        _ = get_context(
+            context_root_dir=file_relative_path(
                 __file__,
                 "./fixtures/contexts/incomplete_uncommitted/great_expectations",
             )
