@@ -72,8 +72,14 @@ def s3_generator(mock_s3_bucket, basic_sparkdf_datasource):
                 "reader_options": {"sep": "\t"},
                 "max_keys": 1,
             },
-            "dir": {"prefix": "data/", "directory_assets": True,},
-            "dir_misconfigured": {"prefix": "data/", "directory_assets": False,},
+            "dir": {
+                "prefix": "data/",
+                "directory_assets": True,
+            },
+            "dir_misconfigured": {
+                "prefix": "data/",
+                "directory_assets": False,
+            },
         },
     )
     yield generator
@@ -148,7 +154,7 @@ def test_s3_generator_get_directories(s3_generator):
         kwargs for kwargs in s3_generator.get_iterator(data_asset_name="data_dirs")
     ]
     assert 3 == len(batch_kwargs_list)
-    paths = set([batch_kwargs["s3"] for batch_kwargs in batch_kwargs_list])
+    paths = {batch_kwargs["s3"] for batch_kwargs in batch_kwargs_list}
     assert {
         "s3a://test_bucket/data/for/",
         "s3a://test_bucket/data/to/",
