@@ -10,7 +10,7 @@ try:
 except ImportError:
     sqlalchemy = None
 
-import great_expectations.exceptions as ge_exceptions
+import great_expectations.exceptions as gx_exceptions
 from great_expectations.core.batch import (
     Batch,
     BatchDefinition,
@@ -187,7 +187,7 @@ def test_batch_data_pandas_execution_engine_incorrect_batch_identifiers(
     test_df: pd.DataFrame = pd.DataFrame(data={"col1": [1, 2], "col2": [3, 4]})
 
     # raised by _validate_batch_identifiers_configuration() in RuntimeDataConnector
-    with pytest.raises(ge_exceptions.DataConnectorError):
+    with pytest.raises(gx_exceptions.DataConnectorError):
         # runtime_parameters are not configured in the DataConnector
         batch_list: List[
             Batch
@@ -255,7 +255,7 @@ def test_batch_data_pandas_execution_engine_batch_identifiers_error_mostly_legal
     }
     batch_request: RuntimeBatchRequest = RuntimeBatchRequest(**batch_request)
 
-    with pytest.raises(ge_exceptions.DataConnectorError):
+    with pytest.raises(gx_exceptions.DataConnectorError):
         # noinspection PyUnusedLocal
         batch_list: List[
             Batch
@@ -283,7 +283,7 @@ def test_batch_data_pandas_execution_engine_batch_identifiers_error_one_illegal_
     }
     batch_request: RuntimeBatchRequest = RuntimeBatchRequest(**batch_request)
 
-    with pytest.raises(ge_exceptions.DataConnectorError):
+    with pytest.raises(gx_exceptions.DataConnectorError):
         # noinspection PyUnusedLocal
         batch_list: List[
             Batch
@@ -641,7 +641,7 @@ def test_file_path_pandas_execution_engine_batch_definition_list_from_batch_requ
     batch_request: RuntimeBatchRequest = RuntimeBatchRequest(**batch_request)
 
     # raised by guess_reader_method_from_path() in ExecutionEngine
-    with pytest.raises(ge_exceptions.ExecutionEngineError):
+    with pytest.raises(gx_exceptions.ExecutionEngineError):
         batch_list: List[
             Batch
         ] = datasource_with_runtime_data_connector_and_pandas_execution_engine.get_batch_list_from_batch_request(
@@ -668,7 +668,7 @@ def test_file_path_pandas_execution_engine_batch_definition_list_from_batch_requ
     batch_request: RuntimeBatchRequest = RuntimeBatchRequest(**batch_request)
 
     # raised by _get_reader_fn() in ExecutionEngine
-    with pytest.raises(ge_exceptions.ExecutionEngineError):
+    with pytest.raises(gx_exceptions.ExecutionEngineError):
         batch_list: List[
             Batch
         ] = datasource_with_runtime_data_connector_and_pandas_execution_engine.get_batch_list_from_batch_request(
@@ -709,6 +709,40 @@ def test_file_path_pandas_execution_engine_get_batch_list_with_named_asset(
     assert my_batch_1.batch_definition.batch_identifiers == batch_identifiers
 
 
+def test_file_path_pandas_execution_engine_get_batch_list_with_named_asset_with_file_endswith_upcase(
+    datasource_with_runtime_data_connector_and_pandas_execution_engine,
+    taxi_test_file_upcase,
+):
+    batch_identifiers = {"day": 1, "month": 12}
+    # Verify that all keys in batch_identifiers are acceptable as batch_identifiers (using batch count).
+    batch_request: dict = {
+        "datasource_name": datasource_with_runtime_data_connector_and_pandas_execution_engine.name,
+        "data_connector_name": "test_runtime_data_connector",
+        "data_asset_name": "asset_a",
+        "runtime_parameters": {
+            "path": taxi_test_file_upcase,
+        },
+        "batch_identifiers": batch_identifiers,
+    }
+    batch_request: RuntimeBatchRequest = RuntimeBatchRequest(**batch_request)
+    batch_list: List[
+        Batch
+    ] = datasource_with_runtime_data_connector_and_pandas_execution_engine.get_batch_list_from_batch_request(
+        batch_request=batch_request
+    )
+    assert len(batch_list) == 1
+    my_batch_1 = batch_list[0]
+    assert my_batch_1.batch_spec is not None
+    assert my_batch_1.batch_definition["data_asset_name"] == "asset_a"
+    assert isinstance(my_batch_1.data.dataframe, pd.DataFrame)
+    assert my_batch_1.data.dataframe.shape == (10000, 18)
+    assert (
+        my_batch_1.batch_markers["pandas_data_fingerprint"]
+        == "c4f929e6d4fab001fedc9e075bf4b612"
+    )
+    assert my_batch_1.batch_definition.batch_identifiers == batch_identifiers
+
+
 def test_file_path_pandas_execution_engine_get_batch_list_with_named_asset_two_batch_requests(
     datasource_with_runtime_data_connector_and_pandas_execution_engine, taxi_test_file
 ):
