@@ -2,7 +2,7 @@ import datetime
 
 import pytest
 
-import great_expectations.exceptions as ge_exceptions
+import great_expectations.exceptions as gx_exceptions
 from great_expectations.core.batch_spec import RuntimeDataBatchSpec
 
 try:
@@ -29,13 +29,13 @@ except ImportError:
             {},
             0,
             id="n missing from sampling_kwargs",
-            marks=pytest.mark.xfail(strict=True, raises=ge_exceptions.SamplerError),
+            marks=pytest.mark.xfail(strict=True, raises=gx_exceptions.SamplerError),
         ),
         pytest.param(
             None,
             0,
             id="sampling_kwargs are None",
-            marks=pytest.mark.xfail(strict=True, raises=ge_exceptions.SamplerError),
+            marks=pytest.mark.xfail(strict=True, raises=gx_exceptions.SamplerError),
         ),
     ],
 )
@@ -113,7 +113,7 @@ def test_sample_using_a_list(test_sparkdf, basic_spark_df_execution_engine):
 def test_sample_using_md5_wrong_hash_function_name(
     test_sparkdf, basic_spark_df_execution_engine
 ):
-    with pytest.raises(ge_exceptions.ExecutionEngineError):
+    with pytest.raises(gx_exceptions.ExecutionEngineError):
         # noinspection PyUnusedLocal
         sampled_df = basic_spark_df_execution_engine.get_batch_data(
             RuntimeDataBatchSpec(
