@@ -1,3 +1,5 @@
+from typing import Optional, cast
+
 import pandas as pd
 import pytest
 
@@ -7,7 +9,8 @@ from contrib.experimental.great_expectations_experimental.expectations.expect_qu
 )
 from great_expectations.core.batch import BatchRequest, RuntimeBatchRequest
 from great_expectations.data_context import DataContext
-from great_expectations.self_check.util import build_spark_validator_with_data
+from great_expectations.self_check.util import get_test_validator_with_data
+from great_expectations.util import build_in_memory_runtime_context
 from great_expectations.validator.validator import (
     ExpectationValidationResult,
     Validator,
@@ -114,6 +117,7 @@ def test_expect_queried_column_value_frequency_to_meet_threshold_override_query_
     )
 
 
+# noinspection PyUnusedLocal
 @pytest.mark.parametrize(
     "success,value,observed,row_condition",
     [
@@ -132,7 +136,14 @@ def test_expect_queried_column_value_frequency_to_meet_threshold_spark(
 ):
     df: pd.DataFrame = titanic_df
 
-    validator: Validator = build_spark_validator_with_data(df, spark_session)
+    context: Optional[DataContext] = cast(
+        DataContext, build_in_memory_runtime_context()
+    )
+    validator = get_test_validator_with_data(
+        execution_engine="spark",
+        data=df,
+        context=context,
+    )
 
     result: ExpectationValidationResult = (
         validator.expect_queried_table_row_count_to_be(
@@ -147,6 +158,7 @@ def test_expect_queried_column_value_frequency_to_meet_threshold_spark(
     )
 
 
+# noinspection PyUnusedLocal
 @pytest.mark.parametrize(
     "success,query,value,observed,row_condition",
     [
@@ -171,7 +183,14 @@ def test_expect_queried_column_value_frequency_to_meet_threshold_override_query_
 ):
     df: pd.DataFrame = titanic_df
 
-    validator: Validator = build_spark_validator_with_data(df, spark_session)
+    context: Optional[DataContext] = cast(
+        DataContext, build_in_memory_runtime_context()
+    )
+    validator = get_test_validator_with_data(
+        execution_engine="spark",
+        data=df,
+        context=context,
+    )
 
     result: ExpectationValidationResult = (
         validator.expect_queried_table_row_count_to_be(
