@@ -7,7 +7,7 @@ import pytest
 from great_expectations.core import ExpectationValidationResult
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
 from great_expectations.expectations.registry import get_renderer_impl
-from great_expectations.render.types import RenderedAtomicContent
+from great_expectations.render import RenderedAtomicContent
 
 
 @pytest.fixture
@@ -234,6 +234,52 @@ def test_atomic_diagnostic_observed_value_expect_column_kl_divergence_to_be_less
     snapshot.assert_match(res)
 
 
+def test_atomic_diagnostic_observed_value_with_boolean_columun_expect_column_kl_divergence_to_be_less_than(
+    snapshot, get_diagnostic_rendered_content
+):
+    # Please note that the vast majority of Expectations are calling `Expectation._atomic_diagnostic_observed_value()`
+    # As such, the specific expectation_type used here is irrelevant and is simply used to trigger the parent class.
+    expectation_config = {
+        "expectation_type": "expect_column_kl_divergence_to_be_less_than",
+        "kwargs": {
+            "column": "boolean_event",
+            "partition_object": {
+                "bins": [True, False],
+                "weights": [0.5, 0.5],
+            },
+            "threshold": 0.1,
+        },
+        "meta": {},
+        "ge_cloud_id": "4b53c4d5-90ba-467a-b7a7-379640bbd729",
+    }
+    update_dict = {
+        "expectation_config": ExpectationConfiguration(**expectation_config),
+        "result": {
+            "observed_value": 0.0,
+            "details": {
+                "observed_partition": {
+                    "values": [True, False],
+                    "weights": [0.5, 0.5],
+                },
+                "expected_partition": {
+                    "values": [True, False],
+                    "weights": [0.5, 0.5],
+                },
+            },
+        },
+    }
+    rendered_content = get_diagnostic_rendered_content(update_dict)
+
+    res = rendered_content.to_json_dict()
+    pprint(res)
+
+    # replace version of vega-lite in res to match snapshot test
+    res["value"]["graph"]["$schema"] = re.sub(
+        r"v\d*\.\d*\.\d*", "v4.8.1", res["value"]["graph"]["$schema"]
+    )
+    snapshot.assert_match(res)
+
+
 def test_atomic_prescriptive_summary_expect_column_max_to_be_between(
     snapshot, get_prescriptive_rendered_content
 ):
@@ -664,7 +710,7 @@ def test_atomic_prescriptive_summary_expect_column_values_to_be_decreasing(
             "column": "my_column",
             "mostly": 0.8,
             "parse_strings_as_datetimes": True,
-            "strictly": 50,
+            "strictly": True,
         },
     }
     rendered_content = get_prescriptive_rendered_content(update_dict)
@@ -722,7 +768,7 @@ def test_atomic_prescriptive_summary_expect_column_values_to_be_increasing(
         "expectation_type": "expect_column_values_to_be_increasing",
         "kwargs": {
             "column": "my_column",
-            "strictly": 10,
+            "strictly": True,
             "mostly": 0.8,
             "parse_strings_as_datetimes": True,
         },
