@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from contextlib import contextmanager
 from pprint import pprint
-from typing import Callable, ContextManager, Generator, Optional, Tuple
+from typing import Any, Callable, ContextManager, Dict, Generator, List, Optional, Tuple
 
 import pytest
 from pydantic import ValidationError
@@ -21,21 +21,19 @@ from great_expectations.experimental.datasources.postgres_datasource import (
     PostgresDatasource,
 )
 from great_expectations.experimental.datasources.sql_datasource import (
-    SqlYearMonthSplitter,
+    ColumnSplitter,
+    ColumnSplitterYearAndMonth,
     TableAsset,
 )
 from tests.experimental.datasources.conftest import (
-    DEFAULT_MAX_DT,
-    DEFAULT_MIN_DT,
     Dialect,
     MockSaEngine,
     MockSaInspector,
     sqlachemy_execution_engine_mock_cls,
 )
 
-# We set a default time range that we use for testing. We grab the years from the
-# mocks we use in tests. For months, we use every month.
-_DEFAULT_TEST_YEARS = list(range(DEFAULT_MIN_DT.year, DEFAULT_MAX_DT.year + 1))
+# We set a default time range that we use for testing.
+_DEFAULT_TEST_YEARS = list(range(2021, 2022 + 1))
 _DEFAULT_TEST_MONTHS = list(range(1, 13))
 
 
@@ -44,9 +42,20 @@ def _source(
     validate_batch_spec: Callable[[SqlAlchemyDatasourceBatchSpec], None],
     dialect: str,
     connection_string: str = "postgresql+psycopg2://postgres:@localhost/test_ci",
+    splitter_query_response: Optional[List[Dict[str, Any]]] = None,
 ) -> Generator[PostgresDatasource, None, None]:
+    splitter_response = splitter_query_response or (
+        [
+            {"year": year, "month": month}
+            for year in _DEFAULT_TEST_YEARS
+            for month in _DEFAULT_TEST_MONTHS
+        ]
+    )
+
     execution_eng_cls = sqlachemy_execution_engine_mock_cls(
-        validate_batch_spec=validate_batch_spec, dialect=dialect
+        validate_batch_spec=validate_batch_spec,
+        dialect=dialect,
+        splitter_query_response=splitter_response,
     )
     original_override = PostgresDatasource.execution_engine_override  # type: ignore[misc]
     try:
@@ -119,7 +128,7 @@ def test_add_table_asset_with_splitter(mocker, create_source: CreateSourceFixtur
         has_table.return_value = True
 
         asset = source.add_table_asset(name="my_asset", table_name="my_table")
-        asset.add_year_and_month_splitter(column_name="my_col")
+        asset.add_splitter_year_and_month(column_name="my_col")
         assert len(source.assets) == 1
         assert asset == list(source.assets.values())[0]
         assert_table_asset(
@@ -130,7 +139,7 @@ def test_add_table_asset_with_splitter(mocker, create_source: CreateSourceFixtur
             batch_request_template={"year": None, "month": None},
         )
         assert_batch_request(
-            batch_request=asset.get_batch_request({"year": 2021, "month": 10}),
+            batch_request=asset.build_batch_request({"year": 2021, "month": 10}),
             source_name="my_datasource",
             asset_name="my_asset",
             options={"year": 2021, "month": 10},
@@ -157,13 +166,13 @@ def test_add_table_asset_with_no_splitter(mocker, create_source: CreateSourceFix
             batch_request_template={},
         )
         assert_batch_request(
-            batch_request=asset.get_batch_request(),
+            batch_request=asset.build_batch_request(),
             source_name="my_datasource",
             asset_name="my_asset",
             options={},
         )
         assert_batch_request(
-            batch_request=asset.get_batch_request({}),
+            batch_request=asset.build_batch_request({}),
             source_name="my_datasource",
             asset_name="my_asset",
             options={},
@@ -177,14 +186,16 @@ def test_construct_table_asset_directly_with_no_splitter(create_source):
     ) as source:
         asset = TableAsset(name="my_asset", table_name="my_table")
         asset._datasource = source
-        assert_batch_request(asset.get_batch_request(), "my_datasource", "my_asset", {})
+        assert_batch_request(
+            asset.build_batch_request(), "my_datasource", "my_asset", {}
+        )
 
 
 def create_and_add_table_asset_without_testing_connection(
     source: PostgresDatasource,
     name: str,
     table_name: str,
-    column_splitter: Optional[SqlYearMonthSplitter] = None,
+    column_splitter: Optional[ColumnSplitter] = None,
 ) -> Tuple[PostgresDatasource, TableAsset]:
     table_asset = TableAsset(
         name=name,
@@ -197,6 +208,13 @@ def create_and_add_table_asset_without_testing_connection(
     return source, table_asset
 
 
+def year_month_splitter(column_name: str) -> ColumnSplitterYearAndMonth:
+    return ColumnSplitterYearAndMonth(
+        column_name=column_name,
+        method_name="split_on_year_and_month",
+    )
+
+
 @pytest.mark.unit
 def test_construct_table_asset_directly_with_splitter(create_source):
     with create_source(
@@ -206,7 +224,7 @@ def test_construct_table_asset_directly_with_splitter(create_source):
             source=source,
             name="my_asset",
             table_name="my_table",
-            column_splitter=SqlYearMonthSplitter(column_name="col"),
+            column_splitter=year_month_splitter(column_name="col"),
         )
         assert_table_asset(
             asset,
@@ -217,7 +235,7 @@ def test_construct_table_asset_directly_with_splitter(create_source):
         )
         batch_request_options = {"year": 2022, "month": 10}
         assert_batch_request(
-            asset.get_batch_request(batch_request_options),
+            asset.build_batch_request(batch_request_options),
             "my_datasource",
             "my_asset",
             batch_request_options,
@@ -241,7 +259,7 @@ def test_datasource_gets_batch_list_no_splitter(create_source):
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        source.get_batch_list_from_batch_request(asset.get_batch_request())
+        source.get_batch_list_from_batch_request(asset.build_batch_request())
 
 
 def assert_batch_specs_correct_with_year_month_splitter_defaults(batch_specs):
@@ -287,8 +305,8 @@ def test_datasource_gets_batch_list_splitter_with_unspecified_batch_request_opti
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
-        empty_batch_request = asset.get_batch_request()
+        asset.column_splitter = year_month_splitter(column_name="my_col")
+        empty_batch_request = asset.build_batch_request()
         assert empty_batch_request.options == {}
         batches = source.get_batch_list_from_batch_request(empty_batch_request)
         assert_batch_specs_correct_with_year_month_splitter_defaults(batch_specs)
@@ -310,8 +328,8 @@ def test_datasource_gets_batch_list_splitter_with_batch_request_options_set_to_n
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
-        batch_request_with_none = asset.get_batch_request(
+        asset.column_splitter = year_month_splitter(column_name="my_col")
+        batch_request_with_none = asset.build_batch_request(
             asset.batch_request_options_template()
         )
         assert batch_request_with_none.options == {"year": None, "month": None}
@@ -326,19 +344,24 @@ def test_datasource_gets_batch_list_splitter_with_partially_specified_batch_requ
     create_source: CreateSourceFixture,
 ):
     batch_specs = []
+    year = 2022
 
     def collect_batch_spec(spec: SqlAlchemyDatasourceBatchSpec) -> None:
         batch_specs.append(spec)
 
     with create_source(
-        validate_batch_spec=collect_batch_spec, dialect="postgresql"
+        validate_batch_spec=collect_batch_spec,
+        dialect="postgresql",
+        splitter_query_response=[
+            {"year": year, "month": month} for month in list(range(1, 13))
+        ],
     ) as source:
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
+        asset.column_splitter = year_month_splitter(column_name="my_col")
         batches = source.get_batch_list_from_batch_request(
-            asset.get_batch_request({"year": 2022})
+            asset.build_batch_request({"year": year})
         )
         assert len(batch_specs) == len(_DEFAULT_TEST_MONTHS)
         for month in _DEFAULT_TEST_MONTHS:
@@ -347,7 +370,7 @@ def test_datasource_gets_batch_list_splitter_with_partially_specified_batch_requ
                 "data_asset_name": "my_asset",
                 "table_name": "my_table",
                 "schema_name": None,
-                "batch_identifiers": {"my_col": {"year": 2022, "month": month}},
+                "batch_identifiers": {"my_col": {"year": year, "month": month}},
                 "splitter_method": "split_on_year_and_month",
                 "splitter_kwargs": {"column_name": "my_col"},
             }
@@ -356,7 +379,7 @@ def test_datasource_gets_batch_list_splitter_with_partially_specified_batch_requ
         assert len(batches) == len(_DEFAULT_TEST_MONTHS)
         metadatas = [batch.metadata for batch in batches]
         for month in _DEFAULT_TEST_MONTHS:
-            expected_metadata = {"month": month, "year": 2022}
+            expected_metadata = {"month": month, "year": year}
             assert expected_metadata in metadatas
 
 
@@ -364,6 +387,9 @@ def test_datasource_gets_batch_list_splitter_with_partially_specified_batch_requ
 def test_datasource_gets_batch_list_with_fully_specified_batch_request_options(
     create_source: CreateSourceFixture,
 ):
+    year = 2022
+    month = 1
+
     def validate_batch_spec(spec: SqlAlchemyDatasourceBatchSpec) -> None:
         assert spec == {
             "batch_identifiers": {"my_col": {"month": 1, "year": 2022}},
@@ -376,17 +402,19 @@ def test_datasource_gets_batch_list_with_fully_specified_batch_request_options(
         }
 
     with create_source(
-        validate_batch_spec=validate_batch_spec, dialect="postgresql"
+        validate_batch_spec=validate_batch_spec,
+        dialect="postgresql",
+        splitter_query_response=[{"month": month, "year": year}],
     ) as source:
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
+        asset.column_splitter = year_month_splitter(column_name="my_col")
         batches = source.get_batch_list_from_batch_request(
-            asset.get_batch_request({"month": 1, "year": 2022})
+            asset.build_batch_request({"month": month, "year": year})
         )
         assert 1 == len(batches)
-        assert batches[0].metadata == {"month": 1, "year": 2022}
+        assert batches[0].metadata == {"month": month, "year": year}
 
 
 @pytest.mark.unit
@@ -400,25 +428,61 @@ def test_datasource_gets_nonexistent_asset(create_source: CreateSourceFixture):
 
 @pytest.mark.unit
 @pytest.mark.parametrize(
-    "batch_request_args",
     [
-        ("bad", None, None),
-        (None, "bad", None),
-        (None, None, {"bad": None}),
-        ("bad", "bad", None),
+        "add_splitter",
+        "add_splitter_kwargs",
+        "batch_request_args",
+    ],
+    [
+        # These bad parameters do not occur in the batch request params
+        ("add_splitter_year", {"column_name": "my_col"}, ("bad", None, None)),
+        ("add_splitter_year", {"column_name": "my_col"}, (None, "bad", None)),
+        ("add_splitter_year", {"column_name": "my_col"}, ("bad", "bad", None)),
+        # These bad parameters are request option parameters which depend on the splitter.
+        ("add_splitter_year", {"column_name": "my_col"}, (None, None, {"bad": None})),
+        (
+            "add_splitter_year_and_month",
+            {"column_name": "my_col"},
+            (None, None, {"bad": None}),
+        ),
+        (
+            "add_splitter_year_and_month_and_day",
+            {"column_name": "my_col"},
+            (None, None, {"bad": None}),
+        ),
+        (
+            "add_splitter_datetime_part",
+            {"column_name": "my_col", "datetime_parts": ["year"]},
+            (None, None, {"bad": None}),
+        ),
+        (
+            "add_splitter_column_value",
+            {"column_name": "my_col"},
+            (None, None, {"bad": None}),
+        ),
+        (
+            "add_splitter_divided_integer",
+            {"column_name": "my_col", "divisor": 3},
+            (None, None, {"bad": None}),
+        ),
     ],
 )
 def test_bad_batch_request_passed_into_get_batch_list_from_batch_request(
     create_source: CreateSourceFixture,
+    add_splitter,
+    add_splitter_kwargs,
     batch_request_args,
 ):
     with create_source(
         validate_batch_spec=lambda _: None, dialect="postgresql"
     ) as source:
-        source, asset = create_and_add_table_asset_without_testing_connection(
-            source=source, name="my_asset", table_name="my_table"
+        # We use a QueryAsset so no database connection checks are done.
+        # We are mocking the database so these would fail without monkeypatching the
+        # TableAsset
+        asset = source.add_query_asset(
+            name="query_asset", query="SELECT * FROM my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
+        getattr(asset, add_splitter)(**add_splitter_kwargs)
 
         src, ast, op = batch_request_args
         batch_request = BatchRequest(
@@ -449,7 +513,7 @@ def test_get_batch_list_from_batch_request_with_good_batch_request(
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
+        asset.column_splitter = year_month_splitter(column_name="my_col")
         batch_request = BatchRequest(
             datasource_name=source.name,
             data_asset_name=asset.name,
@@ -478,7 +542,7 @@ def test_get_batch_list_from_batch_request_with_malformed_batch_request(
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
+        asset.column_splitter = year_month_splitter(column_name="my_col")
         src, ast, op = batch_request_args
         batch_request = BatchRequest(
             datasource_name=src or source.name,
@@ -496,9 +560,9 @@ def test_get_bad_batch_request(create_source: CreateSourceFixture):
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
+        asset.column_splitter = year_month_splitter(column_name="my_col")
         with pytest.raises(ge_exceptions.InvalidBatchRequestError):
-            asset.get_batch_request({"invalid_key": None})
+            asset.build_batch_request({"invalid_key": None})
 
 
 @pytest.mark.unit
@@ -565,7 +629,7 @@ def test_sort_batch_list_by_metadata(sort_info, create_source: CreateSourceFixtu
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
+        asset.column_splitter = year_month_splitter(column_name="my_col")
         asset.add_sorters(sort_keys)
         batch_request = BatchRequest(
             datasource_name=source.name,
@@ -594,7 +658,7 @@ def test_sort_batch_list_by_unknown_key(create_source: CreateSourceFixture):
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
+        asset.column_splitter = year_month_splitter(column_name="my_col")
         asset.add_sorters(["yr", "month"])
         batch_request = BatchRequest(
             datasource_name=source.name,
@@ -637,7 +701,7 @@ def test_data_source_json_has_properties(create_source: CreateSourceFixture):
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
+        asset.column_splitter = year_month_splitter(column_name="my_col")
         asset.add_sorters(["year", "month"])
         source_json = source.json(indent=4, sort_keys=True)
         print(source_json)
@@ -654,7 +718,7 @@ def test_data_source_yaml_has_properties(create_source: CreateSourceFixture):
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
+        asset.column_splitter = year_month_splitter(column_name="my_col")
         asset.add_sorters(["year", "month"])
         source_str = source.__str__()
         assert "order_by:" in source_str
@@ -670,7 +734,7 @@ def test_datasource_dict_has_properties(create_source):
         source, asset = create_and_add_table_asset_without_testing_connection(
             source=source, name="my_asset", table_name="my_table"
         )
-        asset.column_splitter = SqlYearMonthSplitter(column_name="my_col")
+        asset.column_splitter = year_month_splitter(column_name="my_col")
         asset.add_sorters(["year", "month"])
         source_dict = source.dict()
         pprint(source_dict)
@@ -831,7 +895,7 @@ def test_query_data_asset(create_source):
         )
         assert asset.name == "query_asset"
         assert asset.query.lower() == query.lower()
-        source.get_batch_list_from_batch_request(asset.get_batch_request())
+        source.get_batch_list_from_batch_request(asset.build_batch_request())
 
 
 @pytest.mark.unit
@@ -841,3 +905,270 @@ def test_non_select_query_data_asset(create_source):
     ) as source:
         with pytest.raises(ValueError):
             source.add_query_asset(name="query_asset", query="* FROM my_table")
+
+
+@pytest.mark.unit
+def test_splitter_year(
+    create_source: CreateSourceFixture,
+):
+    years = [2020, 2021]
+    batch_specs = []
+
+    def collect_batch_spec(spec: SqlAlchemyDatasourceBatchSpec) -> None:
+        batch_specs.append(spec)
+
+    with create_source(
+        validate_batch_spec=collect_batch_spec,
+        dialect="postgresql",
+        splitter_query_response=[{"year": year} for year in years],
+    ) as source:
+        # We use a query asset because then we don't have to mock out db connection tests
+        # in this unit test.
+        asset = source.add_query_asset(
+            name="my_asset", query="select * from table", order_by=["year"]
+        )
+        asset.add_splitter_year(column_name="my_col")
+        batches = source.get_batch_list_from_batch_request(asset.build_batch_request())
+        assert len(batches) == len(years)
+        for i, year in enumerate(years):
+            assert "year" in batches[i].metadata
+            assert batches[i].metadata["year"] == year
+
+        assert len(batch_specs) == len(years)
+        for spec in batch_specs:
+            assert "splitter_method" in spec
+            assert spec["splitter_method"] == "split_on_year"
+
+
+@pytest.mark.unit
+def test_splitter_year_and_month(
+    create_source: CreateSourceFixture,
+):
+    years = [2020, 2021]
+    months = [6, 8, 9]
+    batch_specs = []
+
+    def collect_batch_spec(spec: SqlAlchemyDatasourceBatchSpec) -> None:
+        batch_specs.append(spec)
+
+    with create_source(
+        validate_batch_spec=collect_batch_spec,
+        dialect="postgresql",
+        splitter_query_response=[
+            {"year": year, "month": month} for year in years for month in months
+        ],
+    ) as source:
+        # We use a query asset because then we don't have to mock out db connection tests
+        # in this unit test.
+        asset = source.add_query_asset(
+            name="my_asset", query="select * from table", order_by=["year", "month"]
+        )
+        asset.add_splitter_year_and_month(column_name="my_col")
+        batches = source.get_batch_list_from_batch_request(asset.build_batch_request())
+        assert len(batches) == len(years) * len(months)
+        for i, year in enumerate(years):
+            for j, month in enumerate(months):
+                batch_index = i * len(months) + j
+                assert "year" in batches[batch_index].metadata
+                assert "month" in batches[batch_index].metadata
+                assert batches[batch_index].metadata["year"] == year
+                assert batches[batch_index].metadata["month"] == month
+
+        assert len(batch_specs) == len(years) * len(months)
+        for spec in batch_specs:
+            assert "splitter_method" in spec
+            assert spec["splitter_method"] == "split_on_year_and_month"
+
+
+@pytest.mark.unit
+def test_splitter_year_and_month_and_day(
+    create_source: CreateSourceFixture,
+):
+    years = [2020, 2021]
+    months = [6, 8, 9]
+    days = [1, 23, 24, 30]
+    batch_specs = []
+
+    def collect_batch_spec(spec: SqlAlchemyDatasourceBatchSpec) -> None:
+        batch_specs.append(spec)
+
+    with create_source(
+        validate_batch_spec=collect_batch_spec,
+        dialect="postgresql",
+        splitter_query_response=[
+            {"year": year, "month": month, "day": day}
+            for year in years
+            for month in months
+            for day in days
+        ],
+    ) as source:
+        # We use a query asset because then we don't have to mock out db connection tests
+        # in this unit test.
+        asset = source.add_query_asset(
+            name="my_asset",
+            query="select * from table",
+            order_by=["year", "month", "day"],
+        )
+        asset.add_splitter_year_and_month_and_day(column_name="my_col")
+        batches = source.get_batch_list_from_batch_request(asset.build_batch_request())
+        assert len(batches) == len(years) * len(months) * len(days)
+        for i, year in enumerate(years):
+            for j, month in enumerate(months):
+                for k, day in enumerate(days):
+                    batch_index = i * len(months) * len(days) + j * len(days) + k
+                    assert "year" in batches[batch_index].metadata
+                    assert "month" in batches[batch_index].metadata
+                    assert "day" in batches[batch_index].metadata
+                    assert batches[batch_index].metadata["year"] == year
+                    assert batches[batch_index].metadata["month"] == month
+                    assert batches[batch_index].metadata["day"] == day
+
+        assert len(batch_specs) == len(years) * len(months) * len(days)
+        for spec in batch_specs:
+            assert "splitter_method" in spec
+            assert spec["splitter_method"] == "split_on_year_and_month_and_day"
+
+
+@pytest.mark.unit
+@pytest.mark.parametrize(
+    [
+        "splitter_name",
+        "splitter_kwargs",
+        "splitter_query_responses",
+        "sorter_args",
+        "all_batches_cnt",
+        "specified_batch_request",
+        "specified_batch_cnt",
+        "last_specified_batch_metadata",
+    ],
+    [
+        pytest.param(
+            "add_splitter_year",
+            {"column_name": "pickup_datetime"},
+            [{"year": 2020}],
+            ["year"],
+            1,
+            {"year": 2020},
+            1,
+            {"year": 2020},
+            id="year",
+        ),
+        pytest.param(
+            "add_splitter_year_and_month",
+            {"column_name": "pickup_datetime"},
+            [{"year": 2020, "month": 1}, {"year": 2020, "month": 2}],
+            ["year", "month"],
+            2,
+            {"year": 2020, "month": 1},
+            1,
+            {"year": 2020, "month": 1},
+            id="year_and_month",
+        ),
+        pytest.param(
+            "add_splitter_year_and_month_and_day",
+            {"column_name": "pickup_datetime"},
+            [
+                {"year": 2020, "month": 2, "day": 10},
+                {"year": 2020, "month": 2, "day": 12},
+            ],
+            ["year", "month", "day"],
+            2,
+            {"year": 2020, "month": 2, "day": 10},
+            1,
+            {"year": 2020, "month": 2, "day": 10},
+            id="year_and_month_and_day",
+        ),
+        pytest.param(
+            "add_splitter_datetime_part",
+            {
+                "column_name": "pickup_datetime",
+                "datetime_parts": ["year", "month", "day"],
+            },
+            [
+                {"year": 2020, "month": 2, "day": 10},
+                {"year": 2020, "month": 2, "day": 12},
+            ],
+            ["year", "month", "day"],
+            2,
+            {"year": 2020, "month": 2},
+            2,
+            {"year": 2020, "month": 2, "day": 12},
+            id="datetime_part",
+        ),
+        pytest.param(
+            "add_splitter_column_value",
+            {"column_name": "passenger_count"},
+            [(1,), (None,), (2,)],
+            ["passenger_count"],
+            3,
+            {"passenger_count": 2},
+            1,
+            {"passenger_count": 2},
+            id="column_value",
+        ),
+        pytest.param(
+            "add_splitter_divided_integer",
+            {"column_name": "passenger_count", "divisor": 3},
+            [(1,), (2,)],
+            ["quotient"],
+            2,
+            {"quotient": 2},
+            1,
+            {"quotient": 2},
+            id="divisor",
+        ),
+    ],
+)
+def test_column_splitter(
+    create_source: CreateSourceFixture,
+    splitter_name,
+    splitter_kwargs,
+    splitter_query_responses,
+    sorter_args,
+    all_batches_cnt,
+    specified_batch_request,
+    specified_batch_cnt,
+    last_specified_batch_metadata,
+):
+    with create_source(
+        validate_batch_spec=lambda _: None,
+        dialect="postgresql",
+        splitter_query_response=[response for response in splitter_query_responses],
+    ) as source:
+        asset = source.add_query_asset(name="query_asset", query="SELECT * from table")
+        getattr(asset, splitter_name)(**splitter_kwargs)
+        asset.add_sorters(sorter_args)
+        # Test getting all batches
+        all_batches = asset.get_batch_list_from_batch_request(
+            asset.build_batch_request()
+        )
+        assert len(all_batches) == all_batches_cnt
+        # Test getting specified batches
+        specified_batches = asset.get_batch_list_from_batch_request(
+            asset.build_batch_request(specified_batch_request)
+        )
+        assert len(specified_batches) == specified_batch_cnt
+        assert specified_batches[-1].metadata == last_specified_batch_metadata
+
+
+@pytest.mark.unit
+def test_sorting_none_in_metadata(
+    create_source: CreateSourceFixture,
+):
+    years = [None, 2020, 2021]
+
+    with create_source(
+        validate_batch_spec=lambda _: None,
+        dialect="postgresql",
+        splitter_query_response=[{"year": year} for year in years],
+    ) as source:
+        # We use a query asset because then we don't have to mock out db connection tests
+        # in this unit test.
+        asset = source.add_query_asset(
+            name="my_asset", query="select * from table", order_by=["year"]
+        )
+        asset.add_splitter_year(column_name="my_col")
+        asset.add_sorters(["-year"])
+        batches = source.get_batch_list_from_batch_request(asset.build_batch_request())
+        assert len(batches) == len(years)
+        assert batches[-1].metadata["year"] is None
