@@ -10,6 +10,7 @@ CREDENTIAL = os.getenv("AZURE_CREDENTIAL", "")
 
 context = gx.get_context()
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/cloud/azure/pandas/inferred_and_runtime_python_example.py datasource config">
 datasource_config = {
     "name": "my_azure_datasource",
     "class_name": "Datasource",
@@ -36,6 +37,7 @@ datasource_config = {
         },
     },
 }
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the yaml above.
@@ -56,9 +58,13 @@ datasource_config["data_connectors"]["default_inferred_data_connector_name"][
     "name_starts_with"
 ] = "data/taxi_yellow_tripdata_samples/"
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/cloud/azure/pandas/inferred_and_runtime_python_example.py test datasource">
 context.test_yaml_config(yaml.dump(datasource_config))
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/cloud/azure/pandas/inferred_and_runtime_python_example.py add datasource">
 context.add_datasource(**datasource_config)
+# </snippet>
 
 # Here is a BatchRequest naming a data_asset
 batch_request = BatchRequest(
@@ -73,9 +79,7 @@ batch_request.data_asset_name = (
     "data/taxi_yellow_tripdata_samples/yellow_tripdata_sample_2019-01"
 )
 
-context.create_expectation_suite(
-    expectation_suite_name="test_suite", overwrite_existing=True
-)
+context.add_or_update_expectation_suite(expectation_suite_name="test_suite")
 validator = context.get_validator(
     batch_request=batch_request, expectation_suite_name="test_suite"
 )
