@@ -1,10 +1,13 @@
 import os
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/mssql_yaml_example.py imports">
 from ruamel import yaml
 
 import great_expectations as gx
 from great_expectations.core.batch import BatchRequest, RuntimeBatchRequest
 
+# </snippet>
+
 db_hostname = os.getenv("GE_TEST_LOCAL_DB_HOSTNAME", "localhost")
 CONNECTION_STRING = f"mssql+pyodbc://sa:ReallyStrongPwd1234%^&*@{db_hostname}:1433/test_ci?driver=ODBC Driver 17 for SQL Server&charset=utf8&autocommit=true"
 
@@ -17,9 +20,12 @@ load_data_into_test_database(
     connection_string=CONNECTION_STRING,
 )
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/mssql_yaml_example.py get_context">
 context = gx.get_context()
+# </snippet>
 
 datasource_yaml = r"""
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/mssql_yaml_example.py datasource config">
 name: my_mssql_datasource
 class_name: Datasource
 execution_engine:
@@ -33,6 +39,7 @@ data_connectors:
    default_inferred_data_connector_name:
        class_name: InferredAssetSqlDataConnector
        include_schema_name: true
+# </snippet>
 """
 
 # Please note this override is only to provide good UX for docs and tests.
@@ -42,11 +49,16 @@ datasource_yaml = datasource_yaml.replace(
     CONNECTION_STRING,
 )
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/mssql_yaml_example.py test datasource config">
 context.test_yaml_config(datasource_yaml)
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/mssql_yaml_example.py add datasource config">
 context.add_datasource(**yaml.load(datasource_yaml))
+# </snippet>
 
 # Here is a RuntimeBatchRequest using a query
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/mssql_yaml_example.py load data with query">
 batch_request = RuntimeBatchRequest(
     datasource_name="my_mssql_datasource",
     data_connector_name="default_runtime_data_connector_name",
@@ -54,30 +66,29 @@ batch_request = RuntimeBatchRequest(
     runtime_parameters={"query": "SELECT TOP 10 * from dbo.taxi_data"},
     batch_identifiers={"default_identifier_name": "default_identifier"},
 )
-context.create_expectation_suite(
-    expectation_suite_name="test_suite", overwrite_existing=True
-)
+context.add_or_update_expectation_suite(expectation_suite_name="test_suite")
 validator = context.get_validator(
     batch_request=batch_request, expectation_suite_name="test_suite"
 )
 print(validator.head())
+# </snippet>
 
 # NOTE: The following code is only for testing and can be ignored by users.
 assert isinstance(validator, gx.validator.validator.Validator)
 
 # Here is a BatchRequest naming a table
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/mssql_yaml_example.py load data with table name">
 batch_request = BatchRequest(
     datasource_name="my_mssql_datasource",
     data_connector_name="default_inferred_data_connector_name",
     data_asset_name="dbo.taxi_data",  # this is the name of the table you want to retrieve
 )
-context.create_expectation_suite(
-    expectation_suite_name="test_suite", overwrite_existing=True
-)
+context.add_or_update_expectation_suite(expectation_suite_name="test_suite")
 validator = context.get_validator(
     batch_request=batch_request, expectation_suite_name="test_suite"
 )
 print(validator.head())
+# </snippet>
 
 # NOTE: The following code is only for testing and can be ignored by users.
 assert isinstance(validator, gx.validator.validator.Validator)
