@@ -1,8 +1,11 @@
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/postgres_yaml_example.py imports">
 from ruamel import yaml
 
 import great_expectations as gx
 from great_expectations.core.batch import BatchRequest, RuntimeBatchRequest
 
+# </snippet>
+
 CONNECTION_STRING = "postgresql+psycopg2://postgres:@localhost/test_ci"
 
 # This utility is not for general use. It is only to support testing.
@@ -14,8 +17,11 @@ load_data_into_test_database(
     connection_string=CONNECTION_STRING,
 )
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/postgres_yaml_example.py get_context">
 context = gx.get_context()
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/postgres_yaml_example.py datasource_yaml">
 datasource_yaml = r"""
 name: my_postgres_datasource
 class_name: Datasource
@@ -31,6 +37,7 @@ data_connectors:
        class_name: InferredAssetSqlDataConnector
        include_schema_name: true
 """
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the yaml above.
@@ -39,11 +46,16 @@ datasource_yaml = datasource_yaml.replace(
     CONNECTION_STRING,
 )
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/postgres_yaml_example.py test_yaml_config">
 context.test_yaml_config(datasource_yaml)
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/postgres_yaml_example.py add_datasource">
 context.add_datasource(**yaml.load(datasource_yaml))
+# </snippet>
 
 # Here is a RuntimeBatchRequest using a query
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/postgres_yaml_example.py batch_request with query">
 batch_request = RuntimeBatchRequest(
     datasource_name="my_postgres_datasource",
     data_connector_name="default_runtime_data_connector_name",
@@ -51,30 +63,29 @@ batch_request = RuntimeBatchRequest(
     runtime_parameters={"query": "SELECT * from public.taxi_data LIMIT 10"},
     batch_identifiers={"default_identifier_name": "default_identifier"},
 )
-context.create_expectation_suite(
-    expectation_suite_name="test_suite", overwrite_existing=True
-)
+context.add_or_update_expectation_suite(expectation_suite_name="test_suite")
 validator = context.get_validator(
     batch_request=batch_request, expectation_suite_name="test_suite"
 )
 print(validator.head())
+# </snippet>
 
 # NOTE: The following code is only for testing and can be ignored by users.
 assert isinstance(validator, gx.validator.validator.Validator)
 
 # Here is a BatchRequest naming a table
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/postgres_yaml_example.py batch_request with table">
 batch_request = BatchRequest(
     datasource_name="my_postgres_datasource",
     data_connector_name="default_inferred_data_connector_name",
     data_asset_name="public.taxi_data",  # this is the name of the table you want to retrieve
 )
-context.create_expectation_suite(
-    expectation_suite_name="test_suite", overwrite_existing=True
-)
+context.add_or_update_expectation_suite(expectation_suite_name="test_suite")
 validator = context.get_validator(
     batch_request=batch_request, expectation_suite_name="test_suite"
 )
 print(validator.head())
+# </snippet>
 
 # NOTE: The following code is only for testing and can be ignored by users.
 assert isinstance(validator, gx.validator.validator.Validator)
