@@ -16,6 +16,7 @@ CONNECTION_STRING = f"snowflake://{sfUser}:{sfPswd}@{sfAccount}/{sfDatabase}/{sf
 
 context = gx.get_context()
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/snowflake_python_example.py datasource_config">
 datasource_config = {
     "name": "my_snowflake_datasource",
     "class_name": "Datasource",
@@ -34,14 +35,19 @@ datasource_config = {
         },
     },
 }
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the yaml above.
 datasource_config["execution_engine"]["connection_string"] = CONNECTION_STRING
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/snowflake_python_example.py test_yaml_config">
 context.test_yaml_config(yaml.dump(datasource_config))
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/snowflake_python_example.py add_datasource">
 context.add_datasource(**datasource_config)
+# </snippet>
 
 # First test for RuntimeBatchRequest using a query
 batch_request = RuntimeBatchRequest(
@@ -54,9 +60,7 @@ batch_request = RuntimeBatchRequest(
     batch_identifiers={"default_identifier_name": "default_identifier"},
 )
 
-context.create_expectation_suite(
-    expectation_suite_name="test_suite", overwrite_existing=True
-)
+context.add_or_update_expectation_suite(expectation_suite_name="test_suite")
 validator = context.get_validator(
     batch_request=batch_request, expectation_suite_name="test_suite"
 )
@@ -66,18 +70,18 @@ print(validator.head())
 assert isinstance(validator, gx.validator.validator.Validator)
 
 # Second test for BatchRequest naming a table
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/snowflake_python_example.py python batch_request name table">
 batch_request = BatchRequest(
     datasource_name="my_snowflake_datasource",
     data_connector_name="default_inferred_data_connector_name",
     data_asset_name=f"{sfSchema.lower()}.taxi_data",  # this is the name of the table you want to retrieve
 )
-context.create_expectation_suite(
-    expectation_suite_name="test_suite", overwrite_existing=True
-)
+context.add_or_update_expectation_suite(expectation_suite_name="test_suite")
 validator = context.get_validator(
     batch_request=batch_request, expectation_suite_name="test_suite"
 )
 print(validator.head())
+# </snippet>
 
 # NOTE: The following code is only for testing and can be ignored by users.
 assert isinstance(validator, gx.validator.validator.Validator)
