@@ -1,11 +1,17 @@
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py imports">
 from ruamel import yaml
 
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py imports no yaml">
 import great_expectations as gx
 from great_expectations.core.batch import BatchRequest
 
+# </snippet>
+# </snippet>
+
 context = gx.get_context()
 
 # YAML
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py yaml datasource">
 datasource_yaml = r"""
 name: taxi_datasource
 class_name: Datasource
@@ -23,6 +29,7 @@ data_connectors:
         group_names:
           - month
 """
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the yaml above.
@@ -33,6 +40,7 @@ datasource_yaml = datasource_yaml.replace(
 test_yaml = context.test_yaml_config(datasource_yaml, return_mode="report_object")
 
 # Python
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py python datasource">
 datasource_config = {
     "name": "taxi_datasource",
     "class_name": "Datasource",
@@ -54,6 +62,7 @@ datasource_config = {
         },
     },
 }
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the code above.
@@ -69,14 +78,15 @@ assert test_yaml == test_python
 
 context.add_datasource(**datasource_config)
 
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py basic datasource workthrough">
 batch_request = BatchRequest(
     datasource_name="taxi_datasource",
     data_connector_name="default_configured_data_connector_name",
     data_asset_name="yellow_tripdata",
 )
 
-context.create_expectation_suite(
-    expectation_suite_name="<MY EXPECTATION SUITE NAME>", overwrite_existing=True
+context.add_or_update_expectation_suite(
+    expectation_suite_name="<MY EXPECTATION SUITE NAME>"
 )
 
 validator = context.get_validator(
@@ -85,6 +95,7 @@ validator = context.get_validator(
     batch_identifiers={"month": "2019-02"},
 )
 print(validator.head())
+# </snippet>
 
 # NOTE: The following code is only for testing and can be ignored by users.
 assert isinstance(validator, gx.validator.validator.Validator)
@@ -96,6 +107,7 @@ assert "yellow_tripdata" in set(
 )
 
 # YAML
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py yaml datasource s3">
 datasource_yaml = r"""
 name: taxi_datasource
 class_name: Datasource
@@ -114,6 +126,7 @@ data_connectors:
         group_names:
           - month
 """
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the yaml above.
@@ -127,6 +140,7 @@ datasource_yaml = datasource_yaml.replace(
 test_yaml = context.test_yaml_config(datasource_yaml, return_mode="report_object")
 
 # Python
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py python datasource s3">
 datasource_config = {
     "name": "taxi_datasource",
     "class_name": "Datasource",
@@ -149,6 +163,7 @@ datasource_config = {
         },
     },
 }
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the code above.
@@ -175,6 +190,7 @@ assert "yellow_tripdata" in set(
 )
 
 # YAML
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py basic single asset yaml">
 datasource_yaml = r"""
 name: taxi_datasource
 class_name: Datasource
@@ -192,7 +208,7 @@ data_connectors:
         group_names:
           - month
 """
-
+# </snippet>
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the yaml above.
 datasource_yaml = datasource_yaml.replace(
@@ -202,6 +218,7 @@ datasource_yaml = datasource_yaml.replace(
 test_yaml = context.test_yaml_config(datasource_yaml, return_mode="report_object")
 
 # Python
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py basic single asset python">
 datasource_config = {
     "name": "taxi_datasource",
     "class_name": "Datasource",
@@ -223,7 +240,7 @@ datasource_config = {
         },
     },
 }
-
+# </snippet>
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the code above.
 datasource_config["data_connectors"]["default_configured_data_connector_name"][
@@ -236,6 +253,7 @@ test_python = context.test_yaml_config(
 
 assert test_yaml == test_python
 
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py basic single asset output">
 context.add_datasource(**datasource_config)
 
 batch_request = BatchRequest(
@@ -249,6 +267,7 @@ validator = context.get_validator(
     expectation_suite_name="<MY EXPECTATION SUITE NAME>",
     batch_identifiers={"month": "2019-02"},
 )
+# </snippet>
 
 # NOTE: The following code is only for testing and can be ignored by users.
 assert isinstance(validator, gx.validator.validator.Validator)
@@ -260,6 +279,7 @@ assert "yellow_tripdata" in set(
 )
 
 # YAML
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py basic single asset yaml no regex">
 datasource_yaml = r"""
 name: taxi_datasource
 class_name: Datasource
@@ -277,6 +297,7 @@ data_connectors:
         group_names:
           - month
 """
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the yaml above.
@@ -287,6 +308,7 @@ datasource_yaml = datasource_yaml.replace(
 test_yaml = context.test_yaml_config(datasource_yaml, return_mode="report_object")
 
 # Python
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py basic single asset python no regex">
 datasource_config = {
     "name": "taxi_datasource",
     "class_name": "Datasource",
@@ -308,6 +330,7 @@ datasource_config = {
         },
     },
 }
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the code above.
@@ -329,6 +352,7 @@ assert "yellow_tripdata" in set(
 )
 
 # YAML
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py example 2 yaml">
 datasource_yaml = r"""
 name: taxi_datasource
 class_name: Datasource
@@ -352,6 +376,7 @@ data_connectors:
           - year
           - month
 """
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the yaml above.
@@ -362,6 +387,7 @@ datasource_yaml = datasource_yaml.replace(
 test_yaml = context.test_yaml_config(datasource_yaml, return_mode="report_object")
 
 # Python
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py example 2 python">
 datasource_config = {
     "name": "taxi_datasource",
     "class_name": "Datasource",
@@ -387,6 +413,7 @@ datasource_config = {
         },
     },
 }
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the code above.
@@ -414,6 +441,7 @@ assert "green_tripdata" in set(
 )
 
 # YAML
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py example 3 yaml">
 datasource_yaml = r"""
 name: taxi_datasource
 class_name: Datasource
@@ -439,6 +467,7 @@ data_connectors:
           - year
           - month
 """
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the yaml above.
@@ -449,6 +478,7 @@ datasource_yaml = datasource_yaml.replace(
 test_yaml = context.test_yaml_config(datasource_yaml, return_mode="report_object")
 
 # Python
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py example 3 python">
 datasource_config = {
     "name": "taxi_datasource",
     "class_name": "Datasource",
@@ -476,6 +506,7 @@ datasource_config = {
         },
     },
 }
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the code above.
@@ -502,6 +533,7 @@ assert "green_tripdata" in set(
 )
 
 # YAML
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py example 4 yaml">
 datasource_yaml = r"""
 name: taxi_datasource
 class_name: Datasource
@@ -527,6 +559,7 @@ data_connectors:
         base_directory: green_tripdata/
         glob_directive: "*.csv"
 """
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the yaml above.
@@ -537,6 +570,7 @@ datasource_yaml = datasource_yaml.replace(
 test_yaml = context.test_yaml_config(datasource_yaml, return_mode="report_object")
 
 # Python
+# <snippet name ="tests/integration/docusaurus/connecting_to_your_data/how_to_configure_a_configuredassetdataconnector.py example 4 python">
 datasource_config = {
     "name": "taxi_datasource",
     "class_name": "Datasource",
@@ -566,6 +600,7 @@ datasource_config = {
         },
     },
 }
+# </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 # In normal usage you'd set your path directly in the code above.
