@@ -21,7 +21,7 @@ spark_session: pyspark.sql.session.SparkSession = (
 
 # create and load Expectation Suite
 # <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_spark_dataframe.py create_expectation_suite">
-context.create_expectation_suite(
+context.add_expectation_suite(
     expectation_suite_name="insert_your_expectation_suite_name_here"
 )
 # </snippet>
