@@ -1,3 +1,4 @@
+# <snippet name="tests/integration/docusaurus/deployment_patterns/aws_emr_serverless_deployment_patterns.py imports">
 import boto3
 import yaml
 from pyspark import SQLContext
@@ -10,6 +11,9 @@ from great_expectations.data_context.types.base import (
 )
 from great_expectations.util import get_context
 
+# </snippet>
+
+# <snippet name="tests/integration/docusaurus/deployment_patterns/aws_emr_serverless_deployment_patterns.py initialize spark">
 if __name__ == "__main__":
     ### critical part to reinitialize spark context
     sc = gx.core.util.get_or_create_spark_application()
@@ -24,6 +28,8 @@ if __name__ == "__main__":
         Key="bucket_name/great_expectations/great_expectations.yml",
     )
     config_file = yaml.safe_load(response["Body"])
+    # </snippet>
+    # <snippet name="tests/integration/docusaurus/deployment_patterns/aws_emr_serverless_deployment_patterns.py connect to data">
     df_spark = spark.read.parquet("s3://bucket_name/data_folder/" + spark_file)
 
     config = DataContextConfig(
@@ -46,7 +52,9 @@ if __name__ == "__main__":
     )
 
     context_gx = get_context(project_config=config)
+    # </snippet>
 
+    # <snippet name="tests/integration/docusaurus/deployment_patterns/aws_emr_serverless_deployment_patterns.py create expectations">
     expectation_suite_name = suite_name
     suite = context_gx.get_expectation_suite(suite_name)
 
@@ -66,7 +74,9 @@ if __name__ == "__main__":
         column="passenger_count"
     )  ## add some test
     validator.save_expectation_suite(discard_failed_expectations=False)
+    # </snippet>
 
+    # <snippet name="tests/integration/docusaurus/deployment_patterns/aws_emr_serverless_deployment_patterns.py validate">
     my_checkpoint_name = "in_memory_checkpoint"
     python_config = {
         "name": my_checkpoint_name,
@@ -94,7 +104,7 @@ if __name__ == "__main__":
             }
         ],
     }
-    context_gx.add_checkpoint(**python_config)
+    context_gx.add_or_update_checkpoint(**python_config)
 
     results = context_gx.run_checkpoint(
         checkpoint_name=my_checkpoint_name,
@@ -109,3 +119,4 @@ if __name__ == "__main__":
 
     validation_result_identifier = results.list_validation_result_identifiers()[0]
     context_gx.build_data_docs()
+    # </snippet>
