@@ -1,3 +1,4 @@
+# <snippet name="tests/integration/docusaurus/deployment_patterns/aws_glue_deployment_patterns.py imports">
 import boto3
 import yaml
 from awsglue.context import GlueContext
@@ -12,6 +13,9 @@ from great_expectations.data_context.types.base import (
 )
 from great_expectations.util import get_context
 
+# </snippet>
+
+# <snippet name="tests/integration/docusaurus/deployment_patterns/aws_glue_deployment_patterns.py set up gx">
 sc = SparkContext.getOrCreate()
 glueContext = GlueContext(sc)
 spark = glueContext.spark_session
@@ -20,7 +24,9 @@ response = s3_client.get_object(
     Bucket="bucket", Key="bucket/great_expectations/great_expectations.yml"
 )
 config_file = yaml.safe_load(response["Body"])
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/deployment_patterns/aws_glue_deployment_patterns.py connect to data">
 config = DataContextConfig(
     config_version=config_file["config_version"],
     datasources=config_file["datasources"],
@@ -41,9 +47,11 @@ config = DataContextConfig(
     ),
 )
 context_gx = get_context(project_config=config)
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/deployment_patterns/aws_glue_deployment_patterns.py create expectations">
 expectation_suite_name = "suite_name"
-suite = context_gx.create_expectation_suite(expectation_suite_name)
+suite = context_gx.add_expectation_suite(expectation_suite_name)
 batch_request = RuntimeBatchRequest(
     datasource_name="spark_s3",
     data_asset_name="datafile_name",
@@ -60,7 +68,9 @@ validator.expect_column_values_to_not_be_null(
     column="passenger_count"
 )  ## add some test
 validator.save_expectation_suite(discard_failed_expectations=False)
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/deployment_patterns/aws_glue_deployment_patterns.py validate your data">
 checkpoint_config = {
     "class_name": "SimpleCheckpoint",
     "validations": [
@@ -76,3 +86,4 @@ checkpoint = SimpleCheckpoint(
 )
 results = checkpoint.run(result_format="SUMMARY", run_name="test")
 validation_result_identifier = results.list_validation_result_identifiers()[0]
+# </snippet>
