@@ -1,5 +1,7 @@
 # isort:skip_file
 import os
+
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py imports">
 import datetime
 
 import pandas as pd
@@ -12,6 +14,8 @@ from great_expectations.data_context.types.base import (
     FilesystemStoreBackendDefaults,
 )
 
+# </snippet>
+
 from great_expectations.core.util import get_or_create_spark_application
 
 spark = get_or_create_spark_application()
@@ -29,17 +33,21 @@ spark = get_or_create_spark_application()
 
 # CODE vvvvv vvvvv
 # This root directory is for use in Databricks
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py root directory">
 root_directory = "/dbfs/great_expectations/"
+# </snippet>
 
 # For testing purposes only, we change the root_directory to an ephemeral location created by our test runner
 root_directory = os.path.join(os.getcwd(), "dbfs_temp_directory")
 
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py set up context">
 data_context_config = DataContextConfig(
     store_backend_defaults=FilesystemStoreBackendDefaults(
         root_directory=root_directory
     ),
 )
 context = get_context(project_config=data_context_config)
+# </snippet>
 # CODE ^^^^^ ^^^^^
 
 # ASSERTIONS vvvvv vvvvv
@@ -69,6 +77,7 @@ assert len(pandas_df.columns) == len(df.columns) == 18
 # 4. Connect to your data
 
 # CODE vvvvv vvvvv
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py datasource config">
 my_spark_datasource_config = {
     "name": "insert_your_datasource_name_here",
     "class_name": "Datasource",
@@ -84,11 +93,17 @@ my_spark_datasource_config = {
         }
     },
 }
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py test datasource config">
 context.test_yaml_config(yaml.dump(my_spark_datasource_config))
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py add datasource config">
 context.add_datasource(**my_spark_datasource_config)
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py create batch request">
 batch_request = RuntimeBatchRequest(
     datasource_name="insert_your_datasource_name_here",
     data_connector_name="insert_your_data_connector_name_here",
@@ -99,6 +114,7 @@ batch_request = RuntimeBatchRequest(
     },
     runtime_parameters={"batch_data": df},  # Your dataframe goes here
 )
+# </snippet>
 # CODE ^^^^^ ^^^^^
 
 # ASSERTIONS vvvvv vvvvv
@@ -117,24 +133,28 @@ assert sorted(
 
 # 5. Create expectations
 # CODE vvvvv vvvvv
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py get validator">
 expectation_suite_name = "insert_your_expectation_suite_name_here"
-context.create_expectation_suite(
-    expectation_suite_name=expectation_suite_name, overwrite_existing=True
-)
+context.add_or_update_expectation_suite(expectation_suite_name=expectation_suite_name)
 validator = context.get_validator(
     batch_request=batch_request,
     expectation_suite_name=expectation_suite_name,
 )
 
 print(validator.head())
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py add expectations">
 validator.expect_column_values_to_not_be_null(column="passenger_count")
 
 validator.expect_column_values_to_be_between(
     column="congestion_surcharge", min_value=0, max_value=1000
 )
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py save suite">
 validator.save_expectation_suite(discard_failed_expectations=False)
+# </snippet>
 # CODE ^^^^^ ^^^^^
 
 # ASSERTIONS vvvvv vvvvv
@@ -145,6 +165,7 @@ assert len(suite.expectations) == 2
 
 # 6. Validate your data (Dataframe)
 # CODE vvvvv vvvvv
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py checkpoint config">
 my_checkpoint_name = "insert_your_checkpoint_name_here"
 checkpoint_config = {
     "name": my_checkpoint_name,
@@ -152,11 +173,17 @@ checkpoint_config = {
     "class_name": "SimpleCheckpoint",
     "run_name_template": "%Y%m%d-%H%M%S-my-run-name-template",
 }
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py test checkpoint config">
 my_checkpoint = context.test_yaml_config(yaml.dump(checkpoint_config))
+# </snippet>
 
-context.add_checkpoint(**checkpoint_config)
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py add checkpoint config">
+context.add_or_update_checkpoint(**checkpoint_config)
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/deployment_patterns/databricks_deployment_patterns_dataframe_python_configs.py run checkpoint">
 checkpoint_result = context.run_checkpoint(
     checkpoint_name=my_checkpoint_name,
     validations=[
@@ -166,6 +193,7 @@ checkpoint_result = context.run_checkpoint(
         }
     ],
 )
+# </snippet>
 # CODE ^^^^^ ^^^^^
 
 # ASSERTIONS vvvvv vvvvv
