@@ -8,20 +8,29 @@ from great_expectations.rule_based_profiler import RuleBasedProfilerResult
 from great_expectations.rule_based_profiler.rule_based_profiler import RuleBasedProfiler
 
 profiler_config = r"""
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py full profiler_config">
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py full row_count_rule">
 # This profiler is meant to be used on the NYC taxi data (yellow_tripdata_sample_<YEAR>-<MONTH>.csv)
 # located in tests/test_sets/taxi_yellow_tripdata_samples/
 
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py name and config_version">
 name: My Profiler
 config_version: 1.0
+# </snippet>
 
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py variables and rule name">
 variables:
   false_positive_rate: 0.01
   mostly: 1.0
 
 rules:
   row_count_rule:
+# </snippet>
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py row_count_rule domain_builder">
     domain_builder:
         class_name: TableDomainBuilder
+# </snippet>
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py row_count_rule parameter_builders">
     parameter_builders:
       - name: row_count_range
         class_name: NumericMetricRangeMultiBatchParameterBuilder
@@ -31,6 +40,8 @@ rules:
         truncate_values:
           lower_bound: 0
         round_decimals: 0
+# </snippet>
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py row_count_rule expectation_configuration_builders">
     expectation_configuration_builders:
       - expectation_type: expect_table_row_count_to_be_between
         class_name: DefaultExpectationConfigurationBuilder
@@ -40,11 +51,16 @@ rules:
         mostly: $variables.mostly
         meta:
           profiler_details: $parameter.row_count_range.details
+# </snippet>
+# </snippet>
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py column_ranges_rule domain_builder">
   column_ranges_rule:
     domain_builder:
       class_name: ColumnDomainBuilder
       include_semantic_types:
         - numeric
+# </snippet>
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py column_ranges_rule parameter_builders">
     parameter_builders:
       - name: min_range
         class_name: NumericMetricRangeMultiBatchParameterBuilder
@@ -58,6 +74,8 @@ rules:
         metric_domain_kwargs: $domain.domain_kwargs
         false_positive_rate: $variables.false_positive_rate
         round_decimals: 2
+# </snippet>
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py column_ranges_rule expectation_configuration_builders">
     expectation_configuration_builders:
       - expectation_type: expect_column_min_to_be_between
         class_name: DefaultExpectationConfigurationBuilder
@@ -77,12 +95,19 @@ rules:
         mostly: $variables.mostly
         meta:
           profiler_details: $parameter.max_range.details
+# </snippet>
+# </snippet>
 """
 
+
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py set up">
 data_context = DataContext()
 
-# Instantiate RuleBasedProfiler
 full_profiler_config_dict: dict = yaml.load(profiler_config)
+# </snippet>
+
+# Instantiate RuleBasedProfiler
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py instantiate">
 rule_based_profiler: RuleBasedProfiler = RuleBasedProfiler(
     name=full_profiler_config_dict["name"],
     config_version=full_profiler_config_dict["config_version"],
@@ -90,7 +115,10 @@ rule_based_profiler: RuleBasedProfiler = RuleBasedProfiler(
     variables=full_profiler_config_dict["variables"],
     data_context=data_context,
 )
+# </snippet>
 
+
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py run">
 batch_request: dict = {
     "datasource_name": "taxi_pandas",
     "data_connector_name": "monthly",
@@ -101,6 +129,8 @@ batch_request: dict = {
 }
 
 result: RuleBasedProfilerResult = rule_based_profiler.run(batch_request=batch_request)
+# </snippet>
+
 expectation_configurations: List[
     ExpectationConfiguration
 ] = result.expectation_configurations
@@ -108,7 +138,8 @@ expectation_configurations: List[
 print(expectation_configurations)
 
 # Please note that this docstring is here to demonstrate output for docs. It is not needed for normal use.
-first_rule_suite = """
+# <snippet name="tests/integration/docusaurus/expectations/advanced/multi_batch_rule_based_profiler_example.py row_count_rule_suite">
+row_count_rule_suite = """
     {
         "meta": {"great_expectations_version": "0.13.19+58.gf8a650720.dirty"},
         "data_asset_type": None,
@@ -129,3 +160,4 @@ first_rule_suite = """
         "expectation_suite_name": "tmp_suite_Profiler_e66f7cbb",
     }
 """
+# </snippet>
