@@ -37,7 +37,7 @@ data_connectors:
 datasource = context.add_datasource(**yaml.safe_load(datasource_config))
 
 expectation_suite_name = "my_expectation_suite"
-context.create_expectation_suite(expectation_suite_name=expectation_suite_name)
+context.add_or_update_expectation_suite(expectation_suite_name=expectation_suite_name)
 
 checkpoint_name = "my_checkpoint"
 checkpoint_config = f"""
@@ -51,7 +51,7 @@ validations:
       data_asset_name: yellow_tripdata_sample_2019-01
     expectation_suite_name: {expectation_suite_name}
 """
-context.add_checkpoint(**yaml.safe_load(checkpoint_config))
+context.add_or_update_checkpoint(**yaml.safe_load(checkpoint_config))
 
 # run the checkpoint twice to create two validations
 context.run_checkpoint(checkpoint_name=checkpoint_name)
@@ -76,6 +76,7 @@ actual_existing_validations_store["validations_store_name"] = great_expectations
 ]
 
 expected_existing_validations_store_yaml = """
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_a_validation_result_store_in_gcs.py expected_existing_validations_store_yaml">
 stores:
   validations_store:
     class_name: ValidationsStore
@@ -84,6 +85,7 @@ stores:
       base_directory: uncommitted/validations/
 
 validations_store_name: validations_store
+# </snippet>
 """
 
 assert actual_existing_validations_store == yaml.safe_load(
@@ -91,6 +93,7 @@ assert actual_existing_validations_store == yaml.safe_load(
 )
 
 configured_validations_store_yaml = """
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_a_validation_result_store_in_gcs.py configured_validations_store_yaml">
 stores:
   validations_GCS_store:
     class_name: ValidationsStore
@@ -101,6 +104,7 @@ stores:
       prefix: <YOUR GCS PREFIX NAME>
 
 validations_store_name: validations_GCS_store
+# </snippet>
 """
 
 # replace example code with integration test configuration
@@ -143,6 +147,14 @@ great_expectations_yaml["stores"]["validations_GCS_store"]["store_backend"].pop(
 with open(great_expectations_yaml_file_path, "w") as f:
     yaml.dump(great_expectations_yaml, f, default_flow_style=False)
 
+"""
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_a_validation_result_store_in_gcs.py copy_validation_command">
+gsutil cp uncommitted/validations/my_expectation_suite/validation_1.json gs://<YOUR GCS BUCKET NAME>/<YOUR GCS PREFIX NAME>/validation_1.json
+gsutil cp uncommitted/validations/my_expectation_suite/validation_2.json gs://<YOUR GCS BUCKET NAME>/<YOUR GCS PREFIX NAME>/validation_2.json
+# </snippet>
+"""
+
+# Override without snippet tag
 # try gsutil cp command
 copy_validation_command = """
 gsutil cp uncommitted/validations/my_expectation_suite/validation_1.json gs://<YOUR GCS BUCKET NAME>/<YOUR GCS PREFIX NAME>/validation_1.json
@@ -201,9 +213,18 @@ stderr = result.stderr.decode("utf-8")
 assert "Operation completed over 1 objects" in stderr
 
 copy_validation_output = """
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_a_validation_result_store_in_gcs.py copy_validation_output">
 Operation completed over 2 objects
+# </snippet>
 """
 
+"""
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_a_validation_result_store_in_gcs.py list_validation_stores_command">
+great_expectations store list
+# </snippet>
+"""
+
+# Override without snippet tag
 # list validation stores
 list_validation_stores_command = """
 great_expectations store list
@@ -217,6 +238,7 @@ result = subprocess.run(
 stdout = result.stdout.decode("utf-8")
 
 list_validation_stores_output = """
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_a_validation_result_store_in_gcs.py list_validation_stores_output">
   - name: validations_GCS_store
     class_name: ValidationsStore
     store_backend:
@@ -224,6 +246,7 @@ list_validation_stores_output = """
       project: <YOUR GCP PROJECT NAME>
       bucket: <YOUR GCS BUCKET NAME>
       prefix: <YOUR GCS PREFIX NAME>
+# </snippet>
 """
 
 assert "validations_GCS_store" in list_validation_stores_output
