@@ -35,6 +35,7 @@ actual_existing_expectations_store["expectations_store_name"] = great_expectatio
 ]
 
 expected_existing_expectations_store_yaml = """
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_an_expectation_store_in_gcs.py expected_existing_expectations_store_yaml">
 stores:
   expectations_store:
     class_name: ExpectationsStore
@@ -43,6 +44,7 @@ stores:
       base_directory: expectations/
 
 expectations_store_name: expectations_store
+# </snippet>
 """
 
 assert actual_existing_expectations_store == yaml.safe_load(
@@ -50,6 +52,7 @@ assert actual_existing_expectations_store == yaml.safe_load(
 )
 
 configured_expectations_store_yaml = """
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_an_expectation_store_in_gcs.py configured_expectations_store_yaml">
 stores:
   expectations_GCS_store:
     class_name: ExpectationsStore
@@ -60,6 +63,7 @@ stores:
       prefix: <YOUR GCS PREFIX NAME>
 
 expectations_store_name: expectations_GCS_store
+# </snippet>
 """
 
 # replace example code with integration test configuration
@@ -99,8 +103,16 @@ with open(great_expectations_yaml_file_path, "w") as f:
     yaml.dump(great_expectations_yaml, f, default_flow_style=False)
 
 expectation_suite_name = "my_expectation_suite"
-context.create_expectation_suite(expectation_suite_name=expectation_suite_name)
+context.add_or_update_expectation_suite(expectation_suite_name=expectation_suite_name)
 
+
+"""
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_an_expectation_store_in_gcs.py copy_expectation_command">
+gsutil cp expectations/my_expectation_suite.json gs://<YOUR GCS BUCKET NAME>/<YOUR GCS PREFIX NAME>/my_expectation_suite.json
+# </snippet>
+"""
+
+# Override without snippet tag
 # try gsutil cp command
 copy_expectation_command = """
 gsutil cp expectations/my_expectation_suite.json gs://<YOUR GCS BUCKET NAME>/<YOUR GCS PREFIX NAME>/my_expectation_suite.json
@@ -133,6 +145,13 @@ result = subprocess.run(
 )
 stderr = result.stderr.decode("utf-8")
 
+"""
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_an_expectation_store_in_gcs.py copy_expectation_output">
+Operation completed over 1 objects
+# </snippet>
+"""
+
+# Override without snippet tag
 copy_expectation_output = """
 Operation completed over 1 objects
 """
@@ -140,6 +159,13 @@ Operation completed over 1 objects
 assert copy_expectation_output.strip() in stderr
 
 # list expectation stores
+"""
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_an_expectation_store_in_gcs.py list_expectation_stores_command">
+great_expectations store list
+# </snippet>
+"""
+
+# Override without snippet tag
 list_expectation_stores_command = """
 great_expectations store list
 """
@@ -152,6 +178,7 @@ result = subprocess.run(
 stdout = result.stdout.decode("utf-8")
 
 list_expectation_stores_output = """
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_an_expectation_store_in_gcs.py list_expectation_stores_output">
   - name: expectations_GCS_store
     class_name: ExpectationsStore
     store_backend:
@@ -159,6 +186,7 @@ list_expectation_stores_output = """
       project: <YOUR GCP PROJECT NAME>
       bucket: <YOUR GCS BUCKET NAME>
       prefix: <YOUR GCS PREFIX NAME>
+# </snippet>
 """
 
 assert "expectations_GCS_store" in list_expectation_stores_output
@@ -167,6 +195,13 @@ assert "TupleGCSStoreBackend" in list_expectation_stores_output
 assert "TupleGCSStoreBackend" in stdout
 
 # list expectation suites
+"""
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_an_expectation_store_in_gcs.py list_expectation_suites_command">
+great_expectations suite list
+# </snippet>
+"""
+
+# Override without snippet tag
 list_expectation_suites_command = """
 great_expectations suite list
 """
@@ -179,8 +214,10 @@ result = subprocess.run(
 stdout = result.stdout.decode("utf-8")
 
 list_expectation_suites_output = """
+# <snippet name="tests/integration/docusaurus/setup/configuring_metadata_stores/how_to_configure_an_expectation_store_in_gcs.py list_expectation_suites_output">
 1 Expectation Suite found:
  - my_expectation_suite
+# </snippet>
 """
 
 assert "1 Expectation Suite found:" in list_expectation_suites_output
