@@ -16,6 +16,7 @@ from ruamel.yaml.comments import CommentedMap
 # To support python 3.7 we must import Protocol from typing_extensions instead of typing
 from typing_extensions import Protocol
 
+import great_expectations.exceptions as gx_exceptions
 from great_expectations import DataContext
 from great_expectations.core import (
     ExpectationConfiguration,
@@ -23,6 +24,11 @@ from great_expectations.core import (
     ExpectationValidationResult,
 )
 from great_expectations.core.batch import BatchRequest
+from great_expectations.core.domain import (
+    INFERRED_SEMANTIC_TYPE_KEY,
+    Domain,
+    SemanticDomainTypes,
+)
 from great_expectations.core.metric_domain_types import MetricDomainTypes
 from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.datasource import DataConnector, Datasource
@@ -36,11 +42,6 @@ from great_expectations.rule_based_profiler.config.base import (
     RuleBasedProfilerConfig,
     ruleBasedProfilerConfigSchema,
 )
-from great_expectations.rule_based_profiler.domain import (
-    INFERRED_SEMANTIC_TYPE_KEY,
-    Domain,
-    SemanticDomainTypes,
-)
 from great_expectations.rule_based_profiler.helpers.util import (
     get_validator_with_expectation_suite,
 )
@@ -416,7 +417,7 @@ def test_alice_profiler_user_workflow_single_batch(
 
 
 @freeze_time(TIMESTAMP)
-@pytest.mark.slow  # 1.39s
+@pytest.mark.slow  # 0.86s
 @pytest.mark.integration
 def test_alice_expect_column_values_to_match_regex_auto_yes_default_profiler_config_yes_custom_profiler_config_no(
     alice_validator: Validator,
@@ -433,19 +434,26 @@ def test_alice_expect_column_values_to_match_regex_auto_yes_default_profiler_con
     assert result.success
 
     expectation_config_kwargs: dict = result.expectation_config.kwargs
+
+    assert expectation_config_kwargs["regex"] in [
+        r"\d+",
+        r"-?\d+",
+        r"-?\d+(?:\.\d*)?",
+        r"[A-Za-z0-9\.,;:!?()\"'%\-]+",
+    ]
+
+    expectation_config_kwargs.pop("regex")
     assert expectation_config_kwargs == {
         "auto": True,
         "batch_id": "cf28d8229c247275c8cc0f41b4ceb62d",
         "column": "id",
         "include_config": True,
         "mostly": 1.0,
-        "regex": "(?:[A-Fa-f0-9]){0,4}(?: ?:? ?(?:[A-Fa-f0-9]){0,4}){0,7}",
         "result_format": "SUMMARY",
     }
 
 
 @freeze_time(TIMESTAMP)
-@pytest.mark.slow  # 1.33s
 @pytest.mark.integration
 def test_alice_expect_column_values_to_not_match_regex_auto_yes_default_profiler_config_yes_custom_profiler_config_no(
     alice_validator: Validator,
@@ -464,13 +472,21 @@ def test_alice_expect_column_values_to_not_match_regex_auto_yes_default_profiler
     assert not result.success
 
     expectation_config_kwargs: dict = result.expectation_config.kwargs
+
+    assert expectation_config_kwargs["regex"] in [
+        r"\d+",
+        r"-?\d+",
+        r"-?\d+(?:\.\d*)?",
+        r"[A-Za-z0-9\.,;:!?()\"'%\-]+",
+    ]
+
+    expectation_config_kwargs.pop("regex")
     assert expectation_config_kwargs == {
         "auto": True,
         "batch_id": "cf28d8229c247275c8cc0f41b4ceb62d",
         "column": "id",
         "include_config": True,
         "mostly": 1.0,
-        "regex": "(?:[A-Fa-f0-9]){0,4}(?: ?:? ?(?:[A-Fa-f0-9]){0,4}){0,7}",
         "result_format": "SUMMARY",
     }
 
@@ -596,7 +612,6 @@ def test_bobby_columnar_table_multi_batch_batches_are_accessible(
             "batch_id": validator_latest.active_batch_id,
         },
         "metric_value_kwargs": None,
-        "metric_dependencies": None,
     }
     metric_value: int = validator_latest.get_metric(
         metric=MetricConfiguration(**metric_configuration_arguments)
@@ -975,7 +990,7 @@ def test_bobby_expect_column_values_to_be_between_auto_yes_default_profiler_conf
         "batch_id": "90bb41c1fbd7c71c05dbc8695320af71",
     }
 
-    with pytest.raises(AssertionError) as e:
+    with pytest.raises(gx_exceptions.InvalidExpectationConfigurationError) as e:
         # noinspection PyUnusedLocal
         result = validator.expect_column_values_to_be_between(
             column=column_name,
@@ -1155,7 +1170,7 @@ def test_bobby_expect_column_values_to_be_between_auto_yes_default_profiler_conf
             "batch_id": "90bb41c1fbd7c71c05dbc8695320af71",
         }
 
-        with pytest.raises(AssertionError) as e:
+        with pytest.raises(gx_exceptions.InvalidExpectationConfigurationError) as e:
             # noinspection PyUnusedLocal
             result = validator.expect_column_values_to_be_between(
                 column=column_name,
@@ -1408,7 +1423,7 @@ def test_bobby_expect_column_values_to_be_between_auto_yes_default_profiler_conf
             "batch_id": "90bb41c1fbd7c71c05dbc8695320af71",
         }
 
-        with pytest.raises(AssertionError) as e:
+        with pytest.raises(gx_exceptions.InvalidExpectationConfigurationError) as e:
             # noinspection PyUnusedLocal
             result = validator.expect_column_values_to_be_between(
                 column=column_name,
