@@ -1,9 +1,10 @@
 import json
+import warnings
 from collections import OrderedDict
 
 import pytest
 
-import great_expectations as ge
+import great_expectations as gx
 from great_expectations import DataContext
 from great_expectations.core import ExpectationSuite
 from great_expectations.data_context.util import file_relative_path
@@ -19,6 +20,7 @@ from great_expectations.render.renderer import (
 from great_expectations.render.renderer.content_block import (
     ValidationResultsTableContentBlockRenderer,
 )
+from great_expectations.render.types import CollapseContent, RenderedContent
 from great_expectations.render.view import DefaultJinjaPageView
 from great_expectations.self_check.util import (
     expectationSuiteSchema,
@@ -95,7 +97,9 @@ def test_smoke_render_profiling_results_page_renderer(titanic_profiled_evrs_1):
     rendered = ProfilingResultsPageRenderer().render(titanic_profiled_evrs_1)
     with open(
         file_relative_path(
-            __file__, "./output/test_render_profiling_results_page_renderer.json"
+            __file__,
+            "./output/test_render_profiling_results_page_renderer.json",
+            strict=False,
         ),
         "w",
     ) as outfile:
@@ -125,6 +129,7 @@ def test_render_profiling_results_column_section_renderer(titanic_profiled_evrs_
                 "./output/test_render_profiling_results_column_section_renderer__"
                 + column
                 + ".json",
+                strict=False,
             ),
             "w",
         ) as outfile:
@@ -143,7 +148,9 @@ def test_smoke_render_validation_results_page_renderer(titanic_profiler_evrs):
     rendered = ValidationResultsPageRenderer().render(titanic_profiler_evrs)
     with open(
         file_relative_path(
-            __file__, "./output/test_render_validation_results_page_renderer.json"
+            __file__,
+            "./output/test_render_validation_results_page_renderer.json",
+            strict=False,
         ),
         "w",
     ) as outfile:
@@ -172,6 +179,7 @@ def test_render_validation_results_column_section_renderer(titanic_profiler_evrs
                 "./output/test_render_validation_results_column_section_renderer__"
                 + column
                 + ".json",
+                strict=False,
             ),
             "w",
         ) as outfile:
@@ -208,6 +216,7 @@ def test_render_expectation_suite_column_section_renderer(
                 "./output/test_render_expectation_suite_column_section_renderer"
                 + column
                 + ".json",
+                strict=False,
             ),
             "w",
         ) as outfile:
@@ -289,7 +298,9 @@ def test_render_profiled_fixture_expectation_suite(
 
     with open(
         file_relative_path(
-            __file__, "./output/test_render_profiled_fixture_expectation_suite.html"
+            __file__,
+            "./output/test_render_profiled_fixture_expectation_suite.html",
+            strict=False,
         ),
         "wb",
     ) as f:
@@ -314,6 +325,7 @@ def test_render_profiled_fixture_expectation_suite_with_distribution(
         file_relative_path(
             __file__,
             "./output/titanic_dataset_profiler_expectation_suite_with_distribution.html",
+            strict=False,
         ),
         "wb",
     ) as f:
@@ -330,7 +342,9 @@ def test_render_profiling_results(titanic_profiled_evrs_1):
     rendered_page = DefaultJinjaPageView().render(rendered_content)
 
     with open(
-        file_relative_path(__file__, "./output/test_render_profiling_results.html"),
+        file_relative_path(
+            __file__, "./output/test_render_profiling_results.html", strict=False
+        ),
         "wb",
     ) as f:
         f.write(rendered_page.encode("utf-8"))
@@ -346,7 +360,9 @@ def test_render_validation_results(titanic_profiled_evrs_1):
     rendered_page = DefaultJinjaPageView().render(rendered_content)
 
     with open(
-        file_relative_path(__file__, "./output/test_render_validation_results.html"),
+        file_relative_path(
+            __file__, "./output/test_render_validation_results.html", strict=False
+        ),
         "wb",
     ) as f:
         f.write(rendered_page.encode("utf-8"))
@@ -376,6 +392,7 @@ def test_smoke_render_profiling_results_page_renderer_with_exception(
         file_relative_path(
             __file__,
             "./output/test_render_profiling_results_column_section_renderer_with_exception.html",
+            strict=False,
         ),
         "wb",
     ) as outfile:
@@ -389,7 +406,7 @@ def test_smoke_render_profiling_results_page_renderer_with_exception(
 @pytest.mark.smoketest
 @pytest.mark.rendered_output
 def test_full_oobe_flow():
-    df = ge.read_csv(file_relative_path(__file__, "../../examples/data/Titanic.csv"))
+    df = gx.read_csv(file_relative_path(__file__, "../../examples/data/Titanic.csv"))
     df.data_asset_name = "my_datasource/my_generator/my_asset"
     df.profile(BasicDatasetProfiler)
     evrs = df.validate()  # results
@@ -398,7 +415,8 @@ def test_full_oobe_flow():
     rendered_page = DefaultJinjaPageView().render(rendered_content)
 
     with open(
-        file_relative_path(__file__, "./output/test_full_oobe_flow.html"), "wb"
+        file_relative_path(__file__, "./output/test_full_oobe_flow.html", strict=False),
+        "wb",
     ) as f:
         f.write(rendered_page.encode("utf-8"))
 
@@ -477,3 +495,20 @@ def test_render_string_template():
     )
 
     assert res == expected
+
+
+def test_render_types_module_deprecation_warning():
+    with warnings.catch_warnings(record=True) as w:
+        CollapseContent(collapse=True)
+        RenderedContent()
+    assert len(w) == 2
+    assert str(w[0].message) == (
+        "Importing the class CollapseContent from great_expectations.render.types is "
+        "deprecated as of v0.15.32 in v0.18. Please import class CollapseContent from "
+        "great_expectations.render."
+    )
+    assert str(w[1].message) == (
+        "Importing the class RenderedContent from great_expectations.render.types is "
+        "deprecated as of v0.15.32 in v0.18. Please import class RenderedContent from "
+        "great_expectations.render."
+    )
