@@ -132,8 +132,8 @@ def run_onboarding_data_assistant_result_jupyter_notebook_with_new_cell(
     root_dir: str = context.root_directory
 
     expectation_suite_name: str = "test_suite"
-    context.create_expectation_suite(
-        expectation_suite_name=expectation_suite_name, overwrite_existing=True
+    context.add_or_update_expectation_suite(
+        expectation_suite_name=expectation_suite_name
     )
 
     notebook_path: str = os.path.join(root_dir, f"run_onboarding_data_assistant.ipynb")
