@@ -2,11 +2,12 @@ from typing import Optional
 
 import pytest
 
-from great_expectations.rule_based_profiler.domain import (
+from great_expectations.core.domain import (
     INFERRED_SEMANTIC_TYPE_KEY,
     Domain,
     SemanticDomainTypes,
 )
+from great_expectations.core.metric_domain_types import MetricDomainTypes
 from great_expectations.rule_based_profiler.helpers.util import (
     integer_semantic_domain_type,
 )
@@ -240,6 +241,49 @@ def test_semantic_domain_comparisons_inclusion():
     domain_a: Optional[Domain]
     domain_b: Optional[Domain]
 
+    domain_a = Domain(
+        domain_type=MetricDomainTypes.TABLE,
+        domain_kwargs={
+            "table": "animal_names",
+        },
+        rule_name="my_rule",
+    )
+
+    domain_b = Domain(
+        domain_type="table",
+    )
+    assert domain_a.is_superset(other=domain_b)
+
+    domain_a = Domain(
+        domain_type="column_pair",
+        domain_kwargs={"column_A": "w", "column_B": "x"},
+        details={
+            INFERRED_SEMANTIC_TYPE_KEY: {
+                "w": SemanticDomainTypes.NUMERIC,
+                "x": SemanticDomainTypes.NUMERIC,
+            },
+        },
+        rule_name="my_rule",
+    )
+
+    domain_b = Domain(
+        domain_type="column_pair",
+        domain_kwargs={
+            "column_A": "w",
+            "column_B": "x",
+        },
+    )
+    assert domain_a.is_superset(other=domain_b)
+
+    domain_b = Domain(
+        domain_type="column_pair",
+        domain_kwargs={
+            "column_B": "x",
+            "column_A": "w",
+        },
+    )
+    assert domain_a.is_superset(other=domain_b)
+
     domain_a = Domain(
         domain_type="column",
         domain_kwargs={"column": "passenger_count"},
