@@ -4,18 +4,18 @@ from unittest import mock
 import pandas as pd
 import pytest
 
-import great_expectations.exceptions as ge_exceptions
+import great_expectations.exceptions as gx_exceptions
 from great_expectations.core.batch import (
     Batch,
     BatchDefinition,
     BatchMarkers,
     BatchRequest,
 )
+from great_expectations.core.domain import Domain
 from great_expectations.core.id_dict import BatchSpec, IDDict
 from great_expectations.core.metric_domain_types import MetricDomainTypes
 from great_expectations.data_context import DataContext
 from great_expectations.execution_engine import PandasExecutionEngine
-from great_expectations.rule_based_profiler.domain import Domain
 from great_expectations.rule_based_profiler.helpers.util import (
     get_parameter_value_and_validate_return_type,
 )
@@ -24,7 +24,10 @@ from great_expectations.rule_based_profiler.parameter_builder import (
     RegexPatternStringParameterBuilder,
 )
 from great_expectations.rule_based_profiler.parameter_container import (
+    FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY,
+    FULLY_QUALIFIED_PARAMETER_NAME_VALUE_KEY,
     ParameterContainer,
+    ParameterNode,
     get_parameter_value_by_fully_qualified_parameter_name,
 )
 from great_expectations.validator.validator import Validator
@@ -79,7 +82,6 @@ def test_regex_pattern_string_parameter_builder_instantiation_with_defaults(
         r"https?:\/\/(?:www\.)?[-a-zA-Z0-9@:%._\+~#=]{2,255}\.[a-z]{2,6}\b(?:[-a-zA-Z0-9@:%_\+.~#()?&//=]*)",  #  Matching URL (including http(s) protocol)
         r"<\/?(?:p|a|b|img)(?: \/)?>",  # HTML tags
         r"(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})(?:.(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})){3}",  # IPv4 IP address
-        r"(?:[A-Fa-f0-9]){0,4}(?: ?:? ?(?:[A-Fa-f0-9]){0,4}){0,7}",  # IPv6 IP address,
         r"\b[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}-[0-5][0-9a-fA-F]{3}-[089ab][0-9a-fA-F]{3}-\b[0-9a-fA-F]{12}\b ",  # UUID
     }
 
@@ -164,11 +166,12 @@ def test_regex_pattern_string_parameter_builder_alice(
         domain=domain,
         parameters=parameters,
         batch_request=batch_request,
+        runtime_configuration=None,
     )
     fully_qualified_parameter_name_for_value: str = (
         "$parameter.my_regex_pattern_string_parameter_builder"
     )
-    expected_value: dict = {
+    expected_parameter_node_as_dict: dict = {
         "value": r"^\S{8}-\S{4}-\S{4}-\S{4}-\S{12}$",
         "details": {
             "evaluated_regexes": {
@@ -186,7 +189,7 @@ def test_regex_pattern_string_parameter_builder_alice(
             domain=domain,
             parameters=parameters,
         )
-        == expected_value
+        == expected_parameter_node_as_dict
     )
 
 
@@ -244,12 +247,13 @@ def test_regex_pattern_string_parameter_builder_bobby_multiple_matches(
         domain=domain,
         parameters=parameters,
         batch_request=batch_request,
+        runtime_configuration=None,
     )
 
     fully_qualified_parameter_name_for_value: str = (
         "$parameter.my_regex_pattern_string_parameter_builder"
     )
-    expected_value: dict = {
+    expected_parameter_node_as_dict: dict = {
         "value": r"^\d{1}$",
         "details": {
             "evaluated_regexes": {
@@ -267,8 +271,8 @@ def test_regex_pattern_string_parameter_builder_bobby_multiple_matches(
         parameters=parameters,
     )
     assert results is not None
-    assert sorted(results["value"]) == sorted(expected_value["value"])
-    assert results["details"] == expected_value["details"]
+    assert sorted(results["value"]) == sorted(expected_parameter_node_as_dict["value"])
+    assert results["details"] == expected_parameter_node_as_dict["details"]
 
 
 @pytest.mark.integration
@@ -316,13 +320,14 @@ def test_regex_pattern_string_parameter_builder_bobby_no_match(
         domain=domain,
         parameters=parameters,
         batch_request=batch_request,
+        runtime_configuration=None,
     )
 
     fully_qualified_parameter_name_for_value: str = (
         "$parameter.my_regex_pattern_string_parameter_builder"
     )
-    expected_value: dict = {
-        "value": "(?:[A-Fa-f0-9]){0,4}(?: ?:? ?(?:[A-Fa-f0-9]){0,4}){0,7}",
+    expected_parameter_node_as_dict: dict = {
+        "value": "-?\\d+",
         "details": {
             "evaluated_regexes": {
                 r"\d+": 1.0,
@@ -334,20 +339,37 @@ def test_regex_pattern_string_parameter_builder_bobby_no_match(
                 r"https?:\/\/(?:www\.)?[-a-zA-Z0-9@:%._\+~#=]{2,255}\.[a-z]{2,6}\b(?:[-a-zA-Z0-9@:%_\+.~#()?&//=]*)": 0.0,
                 r"<\/?(?:p|a|b|img)(?: \/)?>": 0.0,
                 r"(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})(?:.(?:25[0-5]|2[0-4]\d|[01]\d{2}|\d{1,2})){3}": 0.0,
-                r"(?:[A-Fa-f0-9]){0,4}(?: ?:? ?(?:[A-Fa-f0-9]){0,4}){0,7}": 1.0,
                 r"\b[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}-[0-5][0-9a-fA-F]{3}-[089ab][0-9a-fA-F]{3}-\b[0-9a-fA-F]{12}\b ": 0.0,
             },
             "success_ratio": 1.0,
         },
     }
 
-    assert (
+    parameter_node: ParameterNode = (
         get_parameter_value_by_fully_qualified_parameter_name(
             fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
             domain=domain,
             parameters=parameters,
         )
-        == expected_value
+    )
+
+    assert parameter_node[FULLY_QUALIFIED_PARAMETER_NAME_VALUE_KEY] in [
+        r"\d+",
+        r"-?\d+",
+        r"-?\d+(?:\.\d*)?",
+        r"[A-Za-z0-9\.,;:!?()\"'%\-]+",
+    ]
+    assert (
+        parameter_node[FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY].items()
+        == expected_parameter_node_as_dict[
+            FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY
+        ].items()
+    )
+    assert (
+        parameter_node[FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY].success_ratio
+        == expected_parameter_node_as_dict[FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY][
+            "success_ratio"
+        ]
     )
 
 
@@ -356,7 +378,7 @@ def test_regex_pattern_string_parameter_builder_bobby_no_match(
 def test_regex_wrong_domain(mock_data_context: mock.MagicMock, batch_fixture: Batch):
     batch: Batch = batch_fixture
     mock_data_context.get_batch_list.return_value = [batch]
-    mock_data_context.get_validator_using_batch_list.return_value = Validator(
+    mock_data_context.get_validator.return_value = Validator(
         execution_engine=PandasExecutionEngine(), batches=[batch]
     )
 
@@ -385,11 +407,12 @@ def test_regex_wrong_domain(mock_data_context: mock.MagicMock, batch_fixture: Ba
         domain.id: parameter_container,
     }
 
-    with pytest.raises(ge_exceptions.ProfilerExecutionError) as e:
+    with pytest.raises(gx_exceptions.ProfilerExecutionError) as e:
         regex_pattern_string_parameter_builder.build_parameters(
             domain=domain,
             parameters=parameters,
             batch_list=[batch],
+            runtime_configuration=None,
         )
 
     assert (
@@ -442,6 +465,7 @@ def test_regex_single_candidate(
         domain=domain,
         parameters=parameters,
         batch_list=[batch],
+        runtime_configuration=None,
     )
     fully_qualified_parameter_name_for_value: str = (
         "$parameter.my_regex_pattern_string_parameter_builder.value"
@@ -512,6 +536,7 @@ def test_regex_two_candidates(mock_data_context: mock.MagicMock, batch_fixture:
         domain=domain,
         parameters=parameters,
         batch_list=[batch],
+        runtime_configuration=None,
     )
     fully_qualified_parameter_name_for_value: str = (
         "$parameter.my_regex_pattern_string_parameter_builder.value"
