@@ -3,11 +3,12 @@ from typing import Any, Collection, Dict, List, Optional, Set, cast
 import pytest
 
 from great_expectations import DataContext
+from great_expectations.core.domain import Domain
 from great_expectations.core.metric_domain_types import MetricDomainTypes
-from great_expectations.rule_based_profiler.domain import Domain
 from great_expectations.rule_based_profiler.helpers.util import (
     get_parameter_value_and_validate_return_type,
 )
+from great_expectations.rule_based_profiler.parameter_builder import ParameterBuilder
 from great_expectations.rule_based_profiler.parameter_builder.value_set_multi_batch_parameter_builder import (
     ValueSetMultiBatchParameterBuilder,
     _get_unique_values_from_nested_collection_of_sets,
@@ -26,11 +27,9 @@ def test_instantiation_value_set_multi_batch_parameter_builder(
     data_context: DataContext = alice_columnar_table_single_batch_context
 
     # noinspection PyUnusedLocal
-    parameter_builder: ValueSetMultiBatchParameterBuilder = (
-        ValueSetMultiBatchParameterBuilder(
-            name="my_name",
-            data_context=data_context,
-        )
+    parameter_builder: ParameterBuilder = ValueSetMultiBatchParameterBuilder(
+        name="my_name",
+        data_context=data_context,
     )
 
 
@@ -43,10 +42,8 @@ def test_instantiation_value_set_multi_batch_parameter_builder_no_name(
 
     with pytest.raises(TypeError) as excinfo:
         # noinspection PyUnusedLocal,PyArgumentList
-        parameter_builder: ValueSetMultiBatchParameterBuilder = (
-            ValueSetMultiBatchParameterBuilder(
-                data_context=data_context,
-            )
+        parameter_builder: ParameterBuilder = ValueSetMultiBatchParameterBuilder(
+            data_context=data_context,
         )
     assert "__init__() missing 1 required positional argument: 'name'" in str(
         excinfo.value
@@ -77,7 +74,7 @@ def test_value_set_multi_batch_parameter_builder_alice_single_batch_numeric(
         domain.id: parameter_container,
     }
 
-    value_set_multi_batch_parameter_builder: ValueSetMultiBatchParameterBuilder = (
+    value_set_multi_batch_parameter_builder: ParameterBuilder = (
         ValueSetMultiBatchParameterBuilder(
             name="my_event_type_value_set",
             metric_domain_kwargs=metric_domain_kwargs,
@@ -93,6 +90,7 @@ def test_value_set_multi_batch_parameter_builder_alice_single_batch_numeric(
         variables=variables,
         parameters=parameters,
         batch_request=batch_request,
+        runtime_configuration=None,
     )
 
     assert (
@@ -101,7 +99,7 @@ def test_value_set_multi_batch_parameter_builder_alice_single_batch_numeric(
     )
 
     expected_value_set: List[int] = [19, 22, 73]
-    expected_parameter_value: dict = {
+    expected_parameter_node_as_dict: dict = {
         "value": expected_value_set,
         "details": {
             "parse_strings_as_datetimes": False,
@@ -109,7 +107,6 @@ def test_value_set_multi_batch_parameter_builder_alice_single_batch_numeric(
                 "domain_kwargs": {"column": "event_type"},
                 "metric_name": "column.distinct_values",
                 "metric_value_kwargs": None,
-                "metric_dependencies": None,
             },
             "num_batches": 1,
         },
@@ -124,8 +121,8 @@ def test_value_set_multi_batch_parameter_builder_alice_single_batch_numeric(
         parameters=parameters,
     )
 
-    assert sorted(parameter_node.value) == expected_parameter_value["value"]
-    assert parameter_node.details == expected_parameter_value["details"]
+    assert sorted(parameter_node.value) == expected_parameter_node_as_dict["value"]
+    assert parameter_node.details == expected_parameter_node_as_dict["details"]
 
 
 @pytest.mark.integration
@@ -156,7 +153,7 @@ def test_value_set_multi_batch_parameter_builder_alice_single_batch_string(
         domain.id: parameter_container,
     }
 
-    value_set_multi_batch_parameter_builder: ValueSetMultiBatchParameterBuilder = (
+    value_set_multi_batch_parameter_builder: ParameterBuilder = (
         ValueSetMultiBatchParameterBuilder(
             name="my_user_agent_value_set",
             metric_domain_kwargs=metric_domain_kwargs,
@@ -172,6 +169,7 @@ def test_value_set_multi_batch_parameter_builder_alice_single_batch_string(
         variables=variables,
         parameters=parameters,
         batch_request=batch_request,
+        runtime_configuration=None,
     )
 
     assert (
@@ -182,7 +180,7 @@ def test_value_set_multi_batch_parameter_builder_alice_single_batch_string(
     expected_value_set: List[str] = [
         "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36",
     ]
-    expected_parameter_value: dict = {
+    expected_parameter_node_as_dict: dict = {
         "value": expected_value_set,
         "details": {
             "parse_strings_as_datetimes": False,
@@ -190,7 +188,6 @@ def test_value_set_multi_batch_parameter_builder_alice_single_batch_string(
                 "domain_kwargs": {"column": "user_agent"},
                 "metric_name": "column.distinct_values",
                 "metric_value_kwargs": None,
-                "metric_dependencies": None,
             },
             "num_batches": 1,
         },
@@ -205,8 +202,8 @@ def test_value_set_multi_batch_parameter_builder_alice_single_batch_string(
         parameters=parameters,
     )
 
-    assert sorted(parameter_node.value) == expected_parameter_value["value"]
-    assert parameter_node.details == expected_parameter_value["details"]
+    assert sorted(parameter_node.value) == expected_parameter_node_as_dict["value"]
+    assert parameter_node.details == expected_parameter_node_as_dict["details"]
 
 
 @pytest.mark.integration
@@ -224,7 +221,7 @@ def test_value_set_multi_batch_parameter_builder_bobby_numeric(
     }
 
     metric_domain_kwargs_for_parameter_builder: str = "$domain.domain_kwargs"
-    value_set_multi_batch_parameter_builder: ValueSetMultiBatchParameterBuilder = (
+    value_set_multi_batch_parameter_builder: ParameterBuilder = (
         ValueSetMultiBatchParameterBuilder(
             name="my_passenger_count_value_set",
             metric_domain_kwargs=metric_domain_kwargs_for_parameter_builder,
@@ -251,6 +248,7 @@ def test_value_set_multi_batch_parameter_builder_bobby_numeric(
         variables=variables,
         parameters=parameters,
         batch_request=batch_request,
+        runtime_configuration=None,
     )
 
     assert (
@@ -259,7 +257,7 @@ def test_value_set_multi_batch_parameter_builder_bobby_numeric(
     )
 
     expected_value_set: List[int] = [0, 1, 2, 3, 4, 5, 6]
-    expected_parameter_value: dict = {
+    expected_parameter_node_as_dict: dict = {
         "value": expected_value_set,
         "details": {
             "parse_strings_as_datetimes": False,
@@ -267,7 +265,6 @@ def test_value_set_multi_batch_parameter_builder_bobby_numeric(
                 "metric_name": "column.distinct_values",
                 "domain_kwargs": {"column": "passenger_count"},
                 "metric_value_kwargs": None,
-                "metric_dependencies": None,
             },
             "num_batches": 3,
         },
@@ -284,8 +281,8 @@ def test_value_set_multi_batch_parameter_builder_bobby_numeric(
         parameters=parameters,
     )
 
-    assert sorted(parameter_node.value) == expected_parameter_value["value"]
-    assert parameter_node.details == expected_parameter_value["details"]
+    assert sorted(parameter_node.value) == expected_parameter_node_as_dict["value"]
+    assert parameter_node.details == expected_parameter_node_as_dict["details"]
 
 
 @pytest.mark.integration
@@ -303,7 +300,7 @@ def test_value_set_multi_batch_parameter_builder_bobby_string(
     }
 
     metric_domain_kwargs_for_parameter_builder: str = "$domain.domain_kwargs"
-    value_set_multi_batch_parameter_builder: ValueSetMultiBatchParameterBuilder = (
+    value_set_multi_batch_parameter_builder: ParameterBuilder = (
         ValueSetMultiBatchParameterBuilder(
             name="my_store_and_fwd_flag_value_set",
             metric_domain_kwargs=metric_domain_kwargs_for_parameter_builder,
@@ -330,6 +327,7 @@ def test_value_set_multi_batch_parameter_builder_bobby_string(
         variables=variables,
         parameters=parameters,
         batch_request=batch_request,
+        runtime_configuration=None,
     )
 
     assert (
@@ -338,7 +336,7 @@ def test_value_set_multi_batch_parameter_builder_bobby_string(
     )
 
     expected_value_set: List[str] = ["N", "Y"]
-    expected_parameter_value: dict = {
+    expected_parameter_node_as_dict: dict = {
         "value": expected_value_set,
         "details": {
             "parse_strings_as_datetimes": False,
@@ -346,7 +344,6 @@ def test_value_set_multi_batch_parameter_builder_bobby_string(
                 "metric_name": "column.distinct_values",
                 "domain_kwargs": {"column": "store_and_fwd_flag"},
                 "metric_value_kwargs": None,
-                "metric_dependencies": None,
             },
             "num_batches": 3,
         },
@@ -363,8 +360,8 @@ def test_value_set_multi_batch_parameter_builder_bobby_string(
         parameters=parameters,
     )
 
-    assert sorted(parameter_node.value) == expected_parameter_value["value"]
-    assert parameter_node.details == expected_parameter_value["details"]
+    assert sorted(parameter_node.value) == expected_parameter_node_as_dict["value"]
+    assert parameter_node.details == expected_parameter_node_as_dict["details"]
 
 
 @pytest.mark.parametrize(
