@@ -257,7 +257,7 @@ def multi_batch_taxi_validator(
 ) -> Validator:
     context = yellow_trip_pandas_data_context
 
-    suite: ExpectationSuite = context.create_expectation_suite("validating_taxi_data")
+    suite: ExpectationSuite = context.add_expectation_suite("validating_taxi_data")
 
     multi_batch_request: BatchRequest = BatchRequest(
         datasource_name="taxi_pandas",
@@ -407,7 +407,7 @@ def test_validator_with_bad_batchrequest(
 ):
     context = yellow_trip_pandas_data_context
 
-    suite: ExpectationSuite = context.create_expectation_suite("validating_taxi_data")
+    suite: ExpectationSuite = context.add_expectation_suite("validating_taxi_data")
 
     multi_batch_request: BatchRequest = BatchRequest(
         datasource_name="taxi_pandas",
@@ -570,7 +570,7 @@ def test_validator_load_additional_batch_to_validator(
 ):
     context = yellow_trip_pandas_data_context
 
-    suite: ExpectationSuite = context.create_expectation_suite("validating_taxi_data")
+    suite: ExpectationSuite = context.add_expectation_suite("validating_taxi_data")
 
     jan_batch_request: BatchRequest = BatchRequest(
         datasource_name="taxi_pandas",
@@ -618,7 +618,7 @@ def test_instantiate_validator_with_a_list_of_batch_requests(
     yellow_trip_pandas_data_context,
 ):
     context = yellow_trip_pandas_data_context
-    suite: ExpectationSuite = context.create_expectation_suite("validating_taxi_data")
+    suite: ExpectationSuite = context.add_expectation_suite("validating_taxi_data")
 
     jan_batch_request: BatchRequest = BatchRequest(
         datasource_name="taxi_pandas",
@@ -950,7 +950,7 @@ def test_validator_include_rendered_content(
         data_connector_name="monthly",
         data_asset_name="my_reports",
     )
-    suite: ExpectationSuite = context.create_expectation_suite("validating_taxi_data")
+    suite: ExpectationSuite = context.add_expectation_suite("validating_taxi_data")
 
     column: str = "fare_amount"
     partition_object: Dict[str, List[float]] = {
